/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __USB_TASK_HANDLER_H
#define __USB_TASK_HANDLER_H

#include <stdint.h>


#define USB_HSS_PAYLOAD_SIZE 4
#define USB_HSS_QUEUE_LENGTH 16

/* Class event for USB handler for HSS command */
#define USB_EVENT_HSS (USBD_DFU_EVENT_BASE + 0xA5)

typedef __packed struct sUSBHostCommand
{
    uint8_t opcode;
    uint8_t payload[USB_HSS_PAYLOAD_SIZE];
} tUSBHostCommand;

/* USB Command definitions */
#define USB_HSS_NO_EVENT 0x00

/* Connect events */
#define USB_HSS_CONNECT_EVENT 0x01
#define USB_HSS_CONNECT_CON 0x01
#define USB_HSS_CONNECT_DISCON 0x02


/* Connect events */
#define USB_HSS_SUS_EVENT 0x02
#define USB_HSS_SUS_SUSPEND 0x01
#define USB_HSS_SUS_RESUME 0x02

/* HSS Control event */
#define USB_HSS_CONTROL_EVENT 0x03


#endif
