/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#pragma once
#include <stdint.h>
#include <string>

class HSSCommand
{

	/* Constants*/
public: 
	static const uint8_t MAX_PAYLOAD_SIZE = 128;

	/* TPS274C65 Commands */
	static const uint8_t HSS_TPS274C65_CMD_ENABLE = 0x01;
	static const uint8_t HSS_TPS274C65_LED_ENABLE = 0x02;
	static const uint8_t HSS_TPS274C65_UPDATE_CONFIG = 0x03;
	static const uint8_t HSS_TPS274C65_UPDATE_CONFIG_RESP_SIZE = 20;
	static const uint8_t HSS_TPS274C65_SENSE_STATE_CONFIG = 0x04;
	static const uint8_t HSS_TPS274C65_SENSE_STATE_CONFIG_RESP_SIZE = 10;
	static const uint8_t HSS_TPS274C65_FAULT_STATE_CONFIG = 0x05;
	static const uint8_t HSS_TPS274C65_FAULT_STATE_CONFIG_RESP_SIZE = 12;
	static const uint8_t HSS_TPS274C65_RAW_READ = 0x06;
	static const uint8_t HSS_TPS274C65_RAW_READ_RESP_SIZE = 3;
	static const uint8_t HSS_TPS274C65_RAW_WRITE = 0x07;
	static const uint8_t HSS_TPS274C65_ENTER_WRITE = 0x08;

	/* Alpha2HC Commands */
	static const uint8_t HSS_A2HC_ENTER_TEST_MODE = 0x01;
	static const uint8_t HSS_A2HC_EXIT_TEST_MODE = 0x02;
	static const uint8_t HSS_A2HC_RAW_WRITE = 0x03;
	static const uint8_t HSS_A2HC_RAW_READ = 0x04;

public:
	HSSCommand(uint8_t opCode, uint8_t* payload, uint8_t size);
	HSSCommand(uint8_t opCode, uint8_t addr, uint8_t* payload, uint8_t size);
	~HSSCommand();
	uint8_t* getBufferData();
	uint8_t getCommandSize(void);
	void setCommandCode(uint8_t opcode);

private:
	uint8_t featureID;
	uint32_t usbCommand;
	uint8_t opCode;
	uint8_t payload[HSSCommand::MAX_PAYLOAD_SIZE];
	uint8_t commandBuffer[HSSCommand::MAX_PAYLOAD_SIZE + 5];
	uint8_t payloadSize;
	uint8_t commandSize;
};

