/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "CondorConfiguration.h"

CondorConfiguration::CondorConfiguration()
{

}

CondorConfiguration::CondorConfiguration(uint8_t addr)
{
    this->address = addr;
}

void CondorConfiguration::updateFromBuffer(uint8_t buffer[])
{
    /* Grab all of the data */
    this->config1 = buffer[0];
    this->config2 = buffer[1];
    this->config3 = buffer[2];
    this->config4 = buffer[3];
    this->config5 = buffer[4];
    this->config6 = buffer[5];
    this->enable = buffer[6];
    this->led1 = buffer[7];
    this->led2 = buffer[8];
    this->faultMask = buffer[9];
    this->wbOffMask = buffer[10];
    this->wbOnMask = buffer[11];
    this->shrtVsMask = buffer[12];
    this->isnsDis = buffer[13];
    this->tsnsDis = buffer[14];
    this->vsnsDis = buffer[15];
    this->adcConf = buffer[16];
    this->wdFaultChannels = buffer[17];
}

uint8_t CondorConfiguration::getDeviceAddress(void)
{
    return this->address;
}

uint8_t CondorConfiguration::getConfig1(void)
{
    return this->config1;
}

uint8_t CondorConfiguration::getConfig2(void)
{
    return this->config2;
}

uint8_t CondorConfiguration::getConfig3(void)
{
    return this->config3;
}

uint8_t CondorConfiguration::getConfig4(void)
{
    return this->config4;
}

uint8_t CondorConfiguration::getConfig5(void)
{
    return this->config5;
}

uint8_t CondorConfiguration::getConfig6(void)
{
    return this->config6;
}

uint8_t CondorConfiguration::getEnable(void)
{
    return this->enable;
}

uint8_t CondorConfiguration::getLED1(void)
{
    return this->led1;
}

uint8_t CondorConfiguration::getLED2(void)
{
    return this->led2;
}

uint8_t CondorConfiguration::getWireBreakOff(void)
{
    return this->wbOffMask;
}

uint8_t CondorConfiguration::getWireBreakOn(void)
{
    return this->wbOnMask;
}

uint8_t CondorConfiguration::getVSShort(void)
{
    return this->shrtVsMask;
}

uint8_t CondorConfiguration::getISNSConf(void)
{
    return this->isnsDis;
}

uint8_t CondorConfiguration::getTSNSConf(void)
{
    return this->tsnsDis;
}

uint8_t CondorConfiguration::getVSNSConf(void)
{
    return this->vsnsDis;
}

uint8_t CondorConfiguration::getADCConf(void)
{
    return this->adcConf;
}

uint8_t CondorConfiguration::getWDFaultChannels(void)
{
    return this->wdFaultChannels;
}

void CondorConfiguration::setDeviceAddress(uint8_t addr)
{
    this->address = addr;
}

void CondorConfiguration::setConfig1(uint8_t config)
{
    this->config1 = config;
}

void CondorConfiguration::setConfig2(uint8_t config)
{
    this->config2 = config;
}

void CondorConfiguration::setConfig3(uint8_t config)
{
    this->config3 = config;
}

void CondorConfiguration::setConfig4(uint8_t config)
{
    this->config4 = config;
}

void CondorConfiguration::setConfig5(uint8_t config)
{
    this->config5 = config;
}

void CondorConfiguration::setConfig6(uint8_t config)
{
    this->config6 = config;
}

void CondorConfiguration::setEnable(uint8_t enable)
{
    this->enable = enable;
}

void CondorConfiguration::setLED1(uint8_t led1)
{
    this->led1 = led1;
}

void CondorConfiguration::setLED2(uint8_t led2)
{
    this->led2 = led2;
}

void CondorConfiguration::setFaultStatus(uint8_t* faultBuffer)
{
    this->faultType = faultBuffer[0];
    this->channelFault = faultBuffer[1];
    this->globalFault = faultBuffer[2];
    this->shortFault = faultBuffer[3];
    this->wireOffStateFault = faultBuffer[4];
    this->wireOnStateFault = faultBuffer[5];
    this->ilimFault = faultBuffer[6];
    this->thermalFault = faultBuffer[7];
    this->overTempWarning = faultBuffer[8];
    this->revCurrentFault = faultBuffer[9];
}

void CondorConfiguration::setFaultMask(uint8_t mask)
{
    this->faultMask = mask;
}

uint8_t CondorConfiguration::getFaultTypeStatus()
{
    return this->faultType;
}

uint8_t CondorConfiguration::getChannelFaultStatus()
{
    return this->channelFault;
}

uint8_t CondorConfiguration::getGlobalFaultStatus()
{
    return this->globalFault;
}

uint8_t CondorConfiguration::getShortFaultStatus()
{
    return this->shortFault;
}

uint8_t CondorConfiguration::getWireBreakOffStatus()
{
    return this->wireOffStateFault;
}

uint8_t CondorConfiguration::getWireBreakOnStatus()
{
    return this->wireOnStateFault;
}

uint8_t CondorConfiguration::getCurrentLimitStatus()
{
    return this->ilimFault;
}

uint8_t CondorConfiguration::getThermalFaultStatus()
{
    return this->thermalFault;
}

uint8_t CondorConfiguration::getOverTempWarningStatus()
{
    return this->overTempWarning;
}

uint8_t CondorConfiguration::getReverseCurrentStatus()
{
    return this->revCurrentFault;
}

uint8_t CondorConfiguration::getFaultMask(void)
{
    return this->faultMask;
}

void CondorConfiguration::setWireBreakOff(uint8_t wbOff)
{
    this->wbOffMask = wbOff;
}

void CondorConfiguration::setWireBreakOn(uint8_t wbOn)
{
    this->wbOnMask = wbOn;
}

void CondorConfiguration::setVsShort(uint8_t vsShort)
{
    this->shrtVsMask = vsShort;
}

void CondorConfiguration::setISNSConf(uint8_t isns)
{
    this->isnsDis = isns;
}

void CondorConfiguration::setVSNSConf(uint8_t vsns)
{
    this->vsnsDis = vsns;
}

void CondorConfiguration::setTSNSConf(uint8_t tsns)
{
    this->tsnsDis = tsns;
}

void CondorConfiguration::setADCConf(uint8_t adcConf)
{
    this->adcConf = adcConf;
}

void CondorConfiguration::setWDFaultChannels(uint8_t faultChannels)
{
    this->wdFaultChannels = faultChannels;
}
