/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <stdint.h>
#include "tps274c65.h"

ref class CondorConfiguration
{
public:
    CondorConfiguration();
    CondorConfiguration(uint8_t addr);
    void updateFromBuffer(uint8_t buffer[]);
    uint8_t getDeviceAddress(void);
    uint8_t getConfig1(void);
    uint8_t getConfig2(void);
    uint8_t getConfig3(void);
    uint8_t getConfig4(void);
    uint8_t getConfig5(void);
    uint8_t getConfig6(void);
    uint8_t getEnable(void);
    uint8_t getLED1(void);
    uint8_t getLED2(void);
    uint8_t getFaultTypeStatus(void);
    uint8_t getChannelFaultStatus(void);
    uint8_t getGlobalFaultStatus(void);
    uint8_t getShortFaultStatus(void);
    uint8_t getWireBreakOffStatus(void);
    uint8_t getWireBreakOnStatus(void);
    uint8_t getCurrentLimitStatus(void);
    uint8_t getThermalFaultStatus(void);
    uint8_t getOverTempWarningStatus(void);
    uint8_t getReverseCurrentStatus(void);
    uint8_t getFaultMask(void);
    uint8_t getWireBreakOff(void);
    uint8_t getWireBreakOn(void);
    uint8_t getVSShort(void);
    uint8_t getISNSConf(void);
    uint8_t getTSNSConf(void);
    uint8_t getVSNSConf(void);
    uint8_t getADCConf(void);
    uint8_t getWDFaultChannels(void);
    void setDeviceAddress(uint8_t addr);
    void setConfig1(uint8_t config);
    void setConfig2(uint8_t config);
    void setConfig3(uint8_t config);
    void setConfig4(uint8_t config);
    void setConfig5(uint8_t config);
    void setConfig6(uint8_t config);
    void setEnable(uint8_t enable);
    void setLED1(uint8_t led1);
    void setLED2(uint8_t led2);
    void setFaultStatus(uint8_t* faultBuffer);
    void setFaultMask(uint8_t mask);
    void setWireBreakOff(uint8_t wbOff);
    void setWireBreakOn(uint8_t wbOn);
    void setVsShort(uint8_t vsShort);
    void setISNSConf(uint8_t isns);
    void setVSNSConf(uint8_t vsns);
    void setTSNSConf(uint8_t tsns);
    void setADCConf(uint8_t adcConf);
    void setWDFaultChannels(uint8_t faultChannels);

private:
    /* Configuration Registers */
    uint8_t address;
    uint8_t config1;
    uint8_t config2;
    uint8_t config3;
    uint8_t config4;
    uint8_t config5;
    uint8_t config6;
    uint8_t enable;
    uint8_t led1;
    uint8_t led2;
    uint8_t wdFaultChannels;
    uint8_t faultMask;
    uint8_t wbOffMask;
    uint8_t wbOnMask;
    uint8_t shrtVsMask;
    uint8_t isnsDis;
    uint8_t vsnsDis;
    uint8_t tsnsDis;
    uint8_t adcConf;

    /* Fault Registers */
    uint8_t faultType;
    uint8_t channelFault;
    uint8_t globalFault;
    uint8_t shortFault;
    uint8_t wireOffStateFault;
    uint8_t wireOnStateFault;
    uint8_t ilimFault;
    uint8_t thermalFault;
    uint8_t overTempWarning;
    uint8_t revCurrentFault;
};
