/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#pragma once
#include "HSSCommunicationManager.h"
#include "CondorConfiguration.h"
#include "HSSFault.h"
#include "tps274c65_defines.h"


namespace tps274c65configurator {

    using namespace System;
    using namespace System::ComponentModel;
    using namespace System::Collections;
    using namespace System::Collections::Generic;
    using namespace System::Windows::Forms;
    using namespace System::Data;
    using namespace System::Drawing;

    /// <summary>
    /// Summary for ConfigurationGui
    /// </summary>
    public ref class ConfigurationGui : public System::Windows::Forms::Form
    {
    public:
        ConfigurationGui(void)
        {
            InitializeComponent();
            //
            //TODO: Add the constructor code here
            //
        }

    protected:
        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        ~ConfigurationGui()
        {
            if (components)
            {
                delete components;
            }
        }
    private: System::Windows::Forms::StatusStrip^ statusStrip1;
    protected:
    private: System::Windows::Forms::ToolStripStatusLabel^ toolStripStatusLabel1;
    private: System::Windows::Forms::ToolStripStatusLabel^ connectionLabel;
    private: System::Windows::Forms::MenuStrip^ menuStrip1;
    private: System::Windows::Forms::ToolStripMenuItem^ fileToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ saveMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ loadConfigMenuItem;


    private: System::Windows::Forms::ToolStripMenuItem^ exitToolStripMenuItem1;
    private: System::Windows::Forms::ToolStripMenuItem^ helpToolStripMenuItem;
    private: System::Windows::Forms::TabControl^ mainTabControl;

    private: System::Windows::Forms::TabPage^ tabPage1;
    private: System::Windows::Forms::TabPage^ tabPage2;
    private: System::Windows::Forms::DataVisualization::Charting::Chart^ senseChart;

    private: System::Windows::Forms::ComboBox^ deviceSelectorCombo;

    private: System::Windows::Forms::Label^ label1;
    private: System::Windows::Forms::GroupBox^ groupBox3;
    private: System::Windows::Forms::GroupBox^ groupBox2;
    private: System::Windows::Forms::GroupBox^ groupBox1;
    private: System::Windows::Forms::CheckedListBox^ ledToggleBoxGroup;

    private: System::Windows::Forms::CheckedListBox^ chanEnableBoxGroup;

    private: System::Windows::Forms::TabPage^ tabPage3;
    private: System::Windows::Forms::TabPage^ tabPage4;
    private: System::Windows::Forms::TextBox^ maxSamplesBox;


    private: System::Windows::Forms::Label^ label3;
    private: System::Windows::Forms::CheckedListBox^ senseChannelBox;

    private: System::Windows::Forms::ComboBox^ senseSourceSelBox;

    private: System::Windows::Forms::Label^ label2;
    private: System::Windows::Forms::Label^ label6;
    private: System::Windows::Forms::CheckBox^ senseChannelAll;

    private: System::Windows::Forms::CheckBox^ toggleAllChannelsBox;

    private: System::Windows::Forms::Label^ label5;
    private: System::Windows::Forms::Label^ label4;
    private: System::Windows::Forms::CheckBox^ toggleAllLEDChannelsBox;

    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel4;
    private: System::Windows::Forms::Label^ label13;
    private: System::Windows::Forms::PictureBox^ faultBox4;

    private: System::Windows::Forms::Label^ channelFourLabel;


    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel3;
    private: System::Windows::Forms::Label^ label11;
    private: System::Windows::Forms::PictureBox^ faultBox3;

    private: System::Windows::Forms::Label^ channelThreeLabel;


    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel2;
    private: System::Windows::Forms::Label^ label9;
    private: System::Windows::Forms::PictureBox^ faultBox2;

    private: System::Windows::Forms::Label^ channelTwoLabel;

    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel1;
    private: System::Windows::Forms::Label^ label7;
    private: System::Windows::Forms::PictureBox^ faultBox1;

    private: System::Windows::Forms::Label^ channelOneLabel;
    private: System::Windows::Forms::Label^ channelOneFaultLabel;
    private: System::Windows::Forms::Label^ channelFourFaultLabel;
    private: System::Windows::Forms::Label^ channelThreeFaultLabel;
    private: System::Windows::Forms::Label^ channelTwoFaultLabel;
    private: System::Windows::Forms::TextBox^ logTextBox;
    private: System::Windows::Forms::Label^ label12;
    private: System::Windows::Forms::Label^ label10;
    private: System::Windows::Forms::TextBox^ commandBox;

    private: System::Windows::Forms::Button^ sendCommandButton;

    private: System::Windows::Forms::Label^ label8;
private: System::Windows::Forms::TextBox^ commandLogBox;

private: System::Windows::Forms::GroupBox^ groupBox6;
private: System::Windows::Forms::GroupBox^ groupBox5;
private: System::Windows::Forms::GroupBox^ groupBox4;

private: System::Windows::Forms::Label^ label15;

private: System::Windows::Forms::Label^ label14;
private: System::Windows::Forms::ComboBox^ inrushLimitBox;






private: System::Windows::Forms::Label^ label21;
private: System::Windows::Forms::ComboBox^ ilimBehaviorBox;

private: System::Windows::Forms::Label^ label20;
private: System::Windows::Forms::CheckBox^ separateIlimBox;

private: System::Windows::Forms::ComboBox^ chan34CurrentLimitBox;
private: System::Windows::Forms::ComboBox^ chan34DurationBox;


private: System::Windows::Forms::Label^ label17;
private: System::Windows::Forms::Label^ label19;
private: System::Windows::Forms::Label^ label18;
private: System::Windows::Forms::ComboBox^ chan12CurrentLimitBox;
private: System::Windows::Forms::ComboBox^ chan12DurationBox;


private: System::Windows::Forms::Label^ label16;
private: System::Windows::Forms::GroupBox^ groupBox7;



private: System::Windows::Forms::CheckBox^ curDisBox1;
private: System::Windows::Forms::CheckBox^ curDisBox2;


private: System::Windows::Forms::Label^ label38;
private: System::Windows::Forms::CheckBox^ curDisBox3;
private: System::Windows::Forms::CheckBox^ curDisBox4;


private: System::Windows::Forms::CheckBox^ voutDisBox1;
private: System::Windows::Forms::CheckBox^ voutDisBox2;


private: System::Windows::Forms::Label^ label37;
private: System::Windows::Forms::CheckBox^ voutDisBox3;
private: System::Windows::Forms::CheckBox^ voutDisBox4;


private: System::Windows::Forms::CheckBox^ tsnsDisBox1;
private: System::Windows::Forms::CheckBox^ tsnsDisBox2;




private: System::Windows::Forms::Label^ label36;
private: System::Windows::Forms::CheckBox^ tsnsDisBox3;
private: System::Windows::Forms::CheckBox^ tsnsDisBox4;


private: System::Windows::Forms::Label^ label35;
private: System::Windows::Forms::RadioButton^ greater800mABox;

private: System::Windows::Forms::RadioButton^ less800mABox;

private: System::Windows::Forms::Label^ label44;
private: System::Windows::Forms::CheckBox^ rc1Box;
private: System::Windows::Forms::CheckBox^ rc2Box;
private: System::Windows::Forms::CheckBox^ rc3Box;
private: System::Windows::Forms::CheckBox^ rc4Box;






private: System::Windows::Forms::Label^ label30;
private: System::Windows::Forms::CheckBox^ latchDisableBox;

private: System::Windows::Forms::Label^ label29;
private: System::Windows::Forms::ComboBox^ wbOnThreshBox;

private: System::Windows::Forms::Label^ label28;
private: System::Windows::Forms::CheckBox^ rcbCheckBox;

private: System::Windows::Forms::Label^ label27;
private: System::Windows::Forms::Label^ label25;
private: System::Windows::Forms::ComboBox^ wdTimeoutDurationBox;
private: System::Windows::Forms::CheckBox^ wdEnableBox;


private: System::Windows::Forms::Label^ label24;
private: System::Windows::Forms::CheckBox^ parallel34CheckBox;

private: System::Windows::Forms::CheckBox^ parallel12CheckBox;
private: System::Windows::Forms::ComboBox^ wbOffCurrrentBox;


private: System::Windows::Forms::Label^ label23;
private: System::Windows::Forms::Label^ label22;
private: System::Windows::Forms::CheckBox^ uvloMaskBox;

private: System::Windows::Forms::CheckBox^ wbOnMaskBox;

private: System::Windows::Forms::CheckBox^ wbOffMaskBox;

private: System::Windows::Forms::CheckBox^ vsShortMaskBox;

private: System::Windows::Forms::CheckBox^ rcbMaskBox;

private: System::Windows::Forms::CheckBox^ ilimMaskBox;

private: System::Windows::Forms::CheckBox^ wdErrorMaskBox;


private: System::Windows::Forms::CheckBox^ spiMaskBox;

private: System::Windows::Forms::Label^ label34;
private: System::Windows::Forms::CheckBox^ shtVsCh1;
private: System::Windows::Forms::CheckBox^ shtVsCh2;


private: System::Windows::Forms::Label^ label33;
private: System::Windows::Forms::CheckBox^ shtVsCh3;
private: System::Windows::Forms::CheckBox^ shtVsCh4;


private: System::Windows::Forms::CheckBox^ wbOffCh1;
private: System::Windows::Forms::CheckBox^ wbOffCh2;


private: System::Windows::Forms::Label^ label32;
private: System::Windows::Forms::CheckBox^ wbOffCh3;
private: System::Windows::Forms::CheckBox^ wbOffCh4;
private: System::Windows::Forms::CheckBox^ wbOnCh1;
private: System::Windows::Forms::CheckBox^ wbOnCh2;




private: System::Windows::Forms::Label^ label31;
private: System::Windows::Forms::CheckBox^ wbOnCh3;
private: System::Windows::Forms::CheckBox^ wbOnCh4;


private: System::Windows::Forms::Label^ label26;
private: System::Windows::Forms::Label^ label41;
private: System::Windows::Forms::CheckBox^ adcEnableBox;

private: System::Windows::Forms::RadioButton^ retryRadioButton;

private: System::Windows::Forms::RadioButton^ latchRadioButton;

private: System::Windows::Forms::Label^ label42;
private: System::Windows::Forms::ComboBox^ wbBlankBox;

private: System::Windows::Forms::Label^ label40;
private: System::Windows::Forms::Label^ label45;
private: System::Windows::Forms::CheckBox^ fsKeepBox;

private: System::Windows::Forms::Label^ label43;
private: System::Windows::Forms::CheckBox^ keepStateBox1;
private: System::Windows::Forms::CheckBox^ keepStateBox2;
private: System::Windows::Forms::CheckBox^ keepStateBox3;
private: System::Windows::Forms::CheckBox^ keepStateBox4;




private: System::Windows::Forms::CheckBox^ adcTempEanableBox;

private: System::Windows::Forms::CheckBox^ adcOutVoltageEnableBox;

private: System::Windows::Forms::CheckBox^ adcInVoltageEnableBox;

private: System::Windows::Forms::CheckBox^ adcCurEnableBox;
private: System::Windows::Forms::Label^ label39;
private: System::Windows::Forms::TabPage^ tabPage5;
private: System::Windows::Forms::Label^ label46;
private: System::Windows::Forms::GroupBox^ groupBox10;
private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel5;
private: System::Windows::Forms::Label^ label54;
private: System::Windows::Forms::Label^ label55;
private: System::Windows::Forms::Label^ label56;
private: System::Windows::Forms::Label^ label57;
private: System::Windows::Forms::Label^ label58;
private: System::Windows::Forms::Label^ label59;
private: System::Windows::Forms::Label^ label60;
private: System::Windows::Forms::Label^ label61;
private: System::Windows::Forms::PictureBox^ shtsFaultBoxCh1;
private: System::Windows::Forms::PictureBox^ shtsFaultBoxCh2;
private: System::Windows::Forms::PictureBox^ shtsFaultBoxCh3;
private: System::Windows::Forms::PictureBox^ shtsFaultBoxCh4;







private: System::Windows::Forms::PictureBox^ wbOffFaultCh1;
private: System::Windows::Forms::PictureBox^ wbOffFaultCh2;
private: System::Windows::Forms::PictureBox^ wbOffFaultCh3;
private: System::Windows::Forms::PictureBox^ wbOffFaultCh4;
private: System::Windows::Forms::PictureBox^ wbOnFaultCh1;
private: System::Windows::Forms::PictureBox^ wbOnFaultCh2;
private: System::Windows::Forms::PictureBox^ wbOnFaultCh3;
private: System::Windows::Forms::PictureBox^ wbOnFaultCh4;
private: System::Windows::Forms::PictureBox^ ilimFaultBoxCh1;
private: System::Windows::Forms::PictureBox^ ilimFaultBoxCh2;
private: System::Windows::Forms::PictureBox^ ilimFaultBoxCh3;
private: System::Windows::Forms::PictureBox^ ilimFaultBoxCh4;













private: System::Windows::Forms::Label^ label62;
private: System::Windows::Forms::PictureBox^ tsdFaultBoxCh1;
private: System::Windows::Forms::PictureBox^ tsdFaultBoxCh2;
private: System::Windows::Forms::PictureBox^ tsdFaultBoxCh3;
private: System::Windows::Forms::PictureBox^ tsdFaultBoxCh4;




private: System::Windows::Forms::Label^ label63;
private: System::Windows::Forms::PictureBox^ tWarnBoxCh1;
private: System::Windows::Forms::PictureBox^ tWarnBoxCh2;
private: System::Windows::Forms::PictureBox^ tWarnBoxCh3;
private: System::Windows::Forms::PictureBox^ tWarnBoxCh4;




private: System::Windows::Forms::Label^ label64;
private: System::Windows::Forms::PictureBox^ rvsrBoxCh1;
private: System::Windows::Forms::PictureBox^ rvsrBoxCh2;
private: System::Windows::Forms::PictureBox^ rvsrBoxCh3;
private: System::Windows::Forms::PictureBox^ rvsrBoxCh4;




private: System::Windows::Forms::GroupBox^ groupBox9;
private: System::Windows::Forms::GroupBox^ groupBox8;
private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel6;
private: System::Windows::Forms::Label^ label53;
private: System::Windows::Forms::PictureBox^ porFaultBox;
private: System::Windows::Forms::PictureBox^ thermalFaultBox;
private: System::Windows::Forms::PictureBox^ spiFaultBox;



private: System::Windows::Forms::Label^ label49;
private: System::Windows::Forms::Label^ label50;
private: System::Windows::Forms::Label^ label47;
private: System::Windows::Forms::PictureBox^ wdtFaultBox;
private: System::Windows::Forms::PictureBox^ vddUVFaultBox;


private: System::Windows::Forms::Label^ label51;
private: System::Windows::Forms::PictureBox^ uvWarnBox;

private: System::Windows::Forms::Label^ label52;
private: System::Windows::Forms::PictureBox^ uvFaultBox;

private: System::Windows::Forms::Label^ label48;
private: System::Windows::Forms::Button^ clearAllStatsButton;
private: System::Windows::Forms::Button^ manualUpdateButton;


private: System::Windows::Forms::ComboBox^ faultUpdateStatus;





private: System::Windows::Forms::Label^ dateFaultLabel;
private: System::Windows::Forms::Label^ numberFaultLabel;
private: System::Windows::Forms::Label^ faultDescriptionLabel;



private: System::Windows::Forms::Label^ faultNameLabel;
private: System::Windows::Forms::Label^ label66;
private: System::Windows::Forms::Button^ resetStatButton;

private: System::Windows::Forms::Label^ currentFaultLabelStatus;
private: System::Windows::Forms::Label^ label71;
private: System::Windows::Forms::Label^ label67;
private: System::Windows::Forms::Label^ label65;
private: System::Windows::Forms::ToolStripStatusLabel^ inputVoltageLabel;
private: System::Windows::Forms::ToolStripStatusLabel^ inputVoltageValueLabel;
private: System::Windows::Forms::ToolStripMenuItem^ aboutSoftwareToolStripMenuItem;
private: System::Windows::Forms::ToolStripMenuItem^ toolsToolStripMenuItem;
private: System::Windows::Forms::ToolStripMenuItem^ enterDFUModeToolStripMenuItem;









    private:
        /// <summary>
        /// Required designer variable.
        /// </summary>
        System::ComponentModel::Container ^components;

#pragma region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        void InitializeComponent(void)
        {
            System::ComponentModel::ComponentResourceManager^ resources = (gcnew System::ComponentModel::ComponentResourceManager(ConfigurationGui::typeid));
            System::Windows::Forms::DataVisualization::Charting::ChartArea^ chartArea1 = (gcnew System::Windows::Forms::DataVisualization::Charting::ChartArea());
            System::Windows::Forms::DataVisualization::Charting::CustomLabel^ customLabel1 = (gcnew System::Windows::Forms::DataVisualization::Charting::CustomLabel());
            System::Windows::Forms::DataVisualization::Charting::Legend^ legend1 = (gcnew System::Windows::Forms::DataVisualization::Charting::Legend());
            System::Windows::Forms::DataVisualization::Charting::Series^ series1 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series2 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series3 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series4 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Title^ title1 = (gcnew System::Windows::Forms::DataVisualization::Charting::Title());
            this->statusStrip1 = (gcnew System::Windows::Forms::StatusStrip());
            this->toolStripStatusLabel1 = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->connectionLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->inputVoltageLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->inputVoltageValueLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->menuStrip1 = (gcnew System::Windows::Forms::MenuStrip());
            this->fileToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->saveMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->loadConfigMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->exitToolStripMenuItem1 = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->toolsToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->enterDFUModeToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->helpToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->aboutSoftwareToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->mainTabControl = (gcnew System::Windows::Forms::TabControl());
            this->tabPage1 = (gcnew System::Windows::Forms::TabPage());
            this->groupBox3 = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel4 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label13 = (gcnew System::Windows::Forms::Label());
            this->faultBox4 = (gcnew System::Windows::Forms::PictureBox());
            this->channelFourLabel = (gcnew System::Windows::Forms::Label());
            this->channelFourFaultLabel = (gcnew System::Windows::Forms::Label());
            this->tableLayoutPanel3 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label11 = (gcnew System::Windows::Forms::Label());
            this->faultBox3 = (gcnew System::Windows::Forms::PictureBox());
            this->channelThreeLabel = (gcnew System::Windows::Forms::Label());
            this->channelThreeFaultLabel = (gcnew System::Windows::Forms::Label());
            this->tableLayoutPanel2 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label9 = (gcnew System::Windows::Forms::Label());
            this->faultBox2 = (gcnew System::Windows::Forms::PictureBox());
            this->channelTwoLabel = (gcnew System::Windows::Forms::Label());
            this->channelTwoFaultLabel = (gcnew System::Windows::Forms::Label());
            this->tableLayoutPanel1 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label7 = (gcnew System::Windows::Forms::Label());
            this->faultBox1 = (gcnew System::Windows::Forms::PictureBox());
            this->channelOneLabel = (gcnew System::Windows::Forms::Label());
            this->channelOneFaultLabel = (gcnew System::Windows::Forms::Label());
            this->groupBox2 = (gcnew System::Windows::Forms::GroupBox());
            this->label6 = (gcnew System::Windows::Forms::Label());
            this->senseChannelAll = (gcnew System::Windows::Forms::CheckBox());
            this->maxSamplesBox = (gcnew System::Windows::Forms::TextBox());
            this->label3 = (gcnew System::Windows::Forms::Label());
            this->senseChannelBox = (gcnew System::Windows::Forms::CheckedListBox());
            this->senseSourceSelBox = (gcnew System::Windows::Forms::ComboBox());
            this->label2 = (gcnew System::Windows::Forms::Label());
            this->groupBox1 = (gcnew System::Windows::Forms::GroupBox());
            this->toggleAllChannelsBox = (gcnew System::Windows::Forms::CheckBox());
            this->label5 = (gcnew System::Windows::Forms::Label());
            this->label4 = (gcnew System::Windows::Forms::Label());
            this->toggleAllLEDChannelsBox = (gcnew System::Windows::Forms::CheckBox());
            this->ledToggleBoxGroup = (gcnew System::Windows::Forms::CheckedListBox());
            this->chanEnableBoxGroup = (gcnew System::Windows::Forms::CheckedListBox());
            this->senseChart = (gcnew System::Windows::Forms::DataVisualization::Charting::Chart());
            this->tabPage5 = (gcnew System::Windows::Forms::TabPage());
            this->clearAllStatsButton = (gcnew System::Windows::Forms::Button());
            this->manualUpdateButton = (gcnew System::Windows::Forms::Button());
            this->faultUpdateStatus = (gcnew System::Windows::Forms::ComboBox());
            this->label46 = (gcnew System::Windows::Forms::Label());
            this->groupBox10 = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel5 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label54 = (gcnew System::Windows::Forms::Label());
            this->label55 = (gcnew System::Windows::Forms::Label());
            this->label56 = (gcnew System::Windows::Forms::Label());
            this->label57 = (gcnew System::Windows::Forms::Label());
            this->label58 = (gcnew System::Windows::Forms::Label());
            this->label59 = (gcnew System::Windows::Forms::Label());
            this->label60 = (gcnew System::Windows::Forms::Label());
            this->label61 = (gcnew System::Windows::Forms::Label());
            this->shtsFaultBoxCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->shtsFaultBoxCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->shtsFaultBoxCh3 = (gcnew System::Windows::Forms::PictureBox());
            this->shtsFaultBoxCh4 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOffFaultCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOffFaultCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOffFaultCh3 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOffFaultCh4 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOnFaultCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOnFaultCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOnFaultCh3 = (gcnew System::Windows::Forms::PictureBox());
            this->wbOnFaultCh4 = (gcnew System::Windows::Forms::PictureBox());
            this->ilimFaultBoxCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->ilimFaultBoxCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->ilimFaultBoxCh3 = (gcnew System::Windows::Forms::PictureBox());
            this->ilimFaultBoxCh4 = (gcnew System::Windows::Forms::PictureBox());
            this->label62 = (gcnew System::Windows::Forms::Label());
            this->tsdFaultBoxCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->tsdFaultBoxCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->tsdFaultBoxCh3 = (gcnew System::Windows::Forms::PictureBox());
            this->tsdFaultBoxCh4 = (gcnew System::Windows::Forms::PictureBox());
            this->label63 = (gcnew System::Windows::Forms::Label());
            this->tWarnBoxCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->tWarnBoxCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->tWarnBoxCh3 = (gcnew System::Windows::Forms::PictureBox());
            this->tWarnBoxCh4 = (gcnew System::Windows::Forms::PictureBox());
            this->label64 = (gcnew System::Windows::Forms::Label());
            this->rvsrBoxCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->rvsrBoxCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->rvsrBoxCh3 = (gcnew System::Windows::Forms::PictureBox());
            this->rvsrBoxCh4 = (gcnew System::Windows::Forms::PictureBox());
            this->groupBox9 = (gcnew System::Windows::Forms::GroupBox());
            this->label67 = (gcnew System::Windows::Forms::Label());
            this->label65 = (gcnew System::Windows::Forms::Label());
            this->currentFaultLabelStatus = (gcnew System::Windows::Forms::Label());
            this->label71 = (gcnew System::Windows::Forms::Label());
            this->dateFaultLabel = (gcnew System::Windows::Forms::Label());
            this->numberFaultLabel = (gcnew System::Windows::Forms::Label());
            this->faultDescriptionLabel = (gcnew System::Windows::Forms::Label());
            this->faultNameLabel = (gcnew System::Windows::Forms::Label());
            this->label66 = (gcnew System::Windows::Forms::Label());
            this->resetStatButton = (gcnew System::Windows::Forms::Button());
            this->groupBox8 = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel6 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label53 = (gcnew System::Windows::Forms::Label());
            this->porFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->thermalFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->spiFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->label49 = (gcnew System::Windows::Forms::Label());
            this->label50 = (gcnew System::Windows::Forms::Label());
            this->label47 = (gcnew System::Windows::Forms::Label());
            this->wdtFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->vddUVFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->label51 = (gcnew System::Windows::Forms::Label());
            this->uvWarnBox = (gcnew System::Windows::Forms::PictureBox());
            this->label52 = (gcnew System::Windows::Forms::Label());
            this->uvFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->label48 = (gcnew System::Windows::Forms::Label());
            this->tabPage2 = (gcnew System::Windows::Forms::TabPage());
            this->groupBox7 = (gcnew System::Windows::Forms::GroupBox());
            this->label39 = (gcnew System::Windows::Forms::Label());
            this->adcTempEanableBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcOutVoltageEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcInVoltageEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcCurEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->label41 = (gcnew System::Windows::Forms::Label());
            this->adcEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->curDisBox1 = (gcnew System::Windows::Forms::CheckBox());
            this->curDisBox2 = (gcnew System::Windows::Forms::CheckBox());
            this->label38 = (gcnew System::Windows::Forms::Label());
            this->curDisBox3 = (gcnew System::Windows::Forms::CheckBox());
            this->curDisBox4 = (gcnew System::Windows::Forms::CheckBox());
            this->voutDisBox1 = (gcnew System::Windows::Forms::CheckBox());
            this->voutDisBox2 = (gcnew System::Windows::Forms::CheckBox());
            this->label37 = (gcnew System::Windows::Forms::Label());
            this->voutDisBox3 = (gcnew System::Windows::Forms::CheckBox());
            this->voutDisBox4 = (gcnew System::Windows::Forms::CheckBox());
            this->tsnsDisBox1 = (gcnew System::Windows::Forms::CheckBox());
            this->tsnsDisBox2 = (gcnew System::Windows::Forms::CheckBox());
            this->label36 = (gcnew System::Windows::Forms::Label());
            this->tsnsDisBox3 = (gcnew System::Windows::Forms::CheckBox());
            this->tsnsDisBox4 = (gcnew System::Windows::Forms::CheckBox());
            this->label35 = (gcnew System::Windows::Forms::Label());
            this->greater800mABox = (gcnew System::Windows::Forms::RadioButton());
            this->less800mABox = (gcnew System::Windows::Forms::RadioButton());
            this->label44 = (gcnew System::Windows::Forms::Label());
            this->groupBox6 = (gcnew System::Windows::Forms::GroupBox());
            this->keepStateBox1 = (gcnew System::Windows::Forms::CheckBox());
            this->keepStateBox2 = (gcnew System::Windows::Forms::CheckBox());
            this->keepStateBox3 = (gcnew System::Windows::Forms::CheckBox());
            this->keepStateBox4 = (gcnew System::Windows::Forms::CheckBox());
            this->label45 = (gcnew System::Windows::Forms::Label());
            this->fsKeepBox = (gcnew System::Windows::Forms::CheckBox());
            this->label43 = (gcnew System::Windows::Forms::Label());
            this->retryRadioButton = (gcnew System::Windows::Forms::RadioButton());
            this->latchRadioButton = (gcnew System::Windows::Forms::RadioButton());
            this->label42 = (gcnew System::Windows::Forms::Label());
            this->wbBlankBox = (gcnew System::Windows::Forms::ComboBox());
            this->label40 = (gcnew System::Windows::Forms::Label());
            this->rc1Box = (gcnew System::Windows::Forms::CheckBox());
            this->rc2Box = (gcnew System::Windows::Forms::CheckBox());
            this->rc3Box = (gcnew System::Windows::Forms::CheckBox());
            this->rc4Box = (gcnew System::Windows::Forms::CheckBox());
            this->label30 = (gcnew System::Windows::Forms::Label());
            this->latchDisableBox = (gcnew System::Windows::Forms::CheckBox());
            this->label29 = (gcnew System::Windows::Forms::Label());
            this->wbOnThreshBox = (gcnew System::Windows::Forms::ComboBox());
            this->label28 = (gcnew System::Windows::Forms::Label());
            this->rcbCheckBox = (gcnew System::Windows::Forms::CheckBox());
            this->label27 = (gcnew System::Windows::Forms::Label());
            this->label25 = (gcnew System::Windows::Forms::Label());
            this->wdTimeoutDurationBox = (gcnew System::Windows::Forms::ComboBox());
            this->wdEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->label24 = (gcnew System::Windows::Forms::Label());
            this->parallel34CheckBox = (gcnew System::Windows::Forms::CheckBox());
            this->parallel12CheckBox = (gcnew System::Windows::Forms::CheckBox());
            this->wbOffCurrrentBox = (gcnew System::Windows::Forms::ComboBox());
            this->label23 = (gcnew System::Windows::Forms::Label());
            this->label22 = (gcnew System::Windows::Forms::Label());
            this->groupBox5 = (gcnew System::Windows::Forms::GroupBox());
            this->uvloMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->wbOnMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->wbOffMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->vsShortMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->rcbMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->ilimMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->wdErrorMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->spiMaskBox = (gcnew System::Windows::Forms::CheckBox());
            this->label34 = (gcnew System::Windows::Forms::Label());
            this->shtVsCh1 = (gcnew System::Windows::Forms::CheckBox());
            this->shtVsCh2 = (gcnew System::Windows::Forms::CheckBox());
            this->label33 = (gcnew System::Windows::Forms::Label());
            this->shtVsCh3 = (gcnew System::Windows::Forms::CheckBox());
            this->shtVsCh4 = (gcnew System::Windows::Forms::CheckBox());
            this->wbOffCh1 = (gcnew System::Windows::Forms::CheckBox());
            this->wbOffCh2 = (gcnew System::Windows::Forms::CheckBox());
            this->label32 = (gcnew System::Windows::Forms::Label());
            this->wbOffCh3 = (gcnew System::Windows::Forms::CheckBox());
            this->wbOffCh4 = (gcnew System::Windows::Forms::CheckBox());
            this->wbOnCh1 = (gcnew System::Windows::Forms::CheckBox());
            this->wbOnCh2 = (gcnew System::Windows::Forms::CheckBox());
            this->label31 = (gcnew System::Windows::Forms::Label());
            this->wbOnCh3 = (gcnew System::Windows::Forms::CheckBox());
            this->wbOnCh4 = (gcnew System::Windows::Forms::CheckBox());
            this->groupBox4 = (gcnew System::Windows::Forms::GroupBox());
            this->label26 = (gcnew System::Windows::Forms::Label());
            this->inrushLimitBox = (gcnew System::Windows::Forms::ComboBox());
            this->label21 = (gcnew System::Windows::Forms::Label());
            this->ilimBehaviorBox = (gcnew System::Windows::Forms::ComboBox());
            this->label20 = (gcnew System::Windows::Forms::Label());
            this->separateIlimBox = (gcnew System::Windows::Forms::CheckBox());
            this->chan34CurrentLimitBox = (gcnew System::Windows::Forms::ComboBox());
            this->chan34DurationBox = (gcnew System::Windows::Forms::ComboBox());
            this->label17 = (gcnew System::Windows::Forms::Label());
            this->label19 = (gcnew System::Windows::Forms::Label());
            this->label18 = (gcnew System::Windows::Forms::Label());
            this->chan12CurrentLimitBox = (gcnew System::Windows::Forms::ComboBox());
            this->chan12DurationBox = (gcnew System::Windows::Forms::ComboBox());
            this->label16 = (gcnew System::Windows::Forms::Label());
            this->label15 = (gcnew System::Windows::Forms::Label());
            this->label14 = (gcnew System::Windows::Forms::Label());
            this->tabPage3 = (gcnew System::Windows::Forms::TabPage());
            this->label12 = (gcnew System::Windows::Forms::Label());
            this->label10 = (gcnew System::Windows::Forms::Label());
            this->commandBox = (gcnew System::Windows::Forms::TextBox());
            this->sendCommandButton = (gcnew System::Windows::Forms::Button());
            this->label8 = (gcnew System::Windows::Forms::Label());
            this->commandLogBox = (gcnew System::Windows::Forms::TextBox());
            this->tabPage4 = (gcnew System::Windows::Forms::TabPage());
            this->logTextBox = (gcnew System::Windows::Forms::TextBox());
            this->deviceSelectorCombo = (gcnew System::Windows::Forms::ComboBox());
            this->label1 = (gcnew System::Windows::Forms::Label());
            this->statusStrip1->SuspendLayout();
            this->menuStrip1->SuspendLayout();
            this->mainTabControl->SuspendLayout();
            this->tabPage1->SuspendLayout();
            this->groupBox3->SuspendLayout();
            this->tableLayoutPanel4->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox4))->BeginInit();
            this->tableLayoutPanel3->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox3))->BeginInit();
            this->tableLayoutPanel2->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox2))->BeginInit();
            this->tableLayoutPanel1->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox1))->BeginInit();
            this->groupBox2->SuspendLayout();
            this->groupBox1->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->senseChart))->BeginInit();
            this->tabPage5->SuspendLayout();
            this->groupBox10->SuspendLayout();
            this->tableLayoutPanel5->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh3))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh4))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh3))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh4))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh3))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh4))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh3))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh4))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh3))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh4))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh3))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh4))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh3))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh4))->BeginInit();
            this->groupBox9->SuspendLayout();
            this->groupBox8->SuspendLayout();
            this->tableLayoutPanel6->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->porFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->thermalFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->spiFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wdtFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->vddUVFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvWarnBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvFaultBox))->BeginInit();
            this->tabPage2->SuspendLayout();
            this->groupBox7->SuspendLayout();
            this->groupBox6->SuspendLayout();
            this->groupBox5->SuspendLayout();
            this->groupBox4->SuspendLayout();
            this->tabPage3->SuspendLayout();
            this->tabPage4->SuspendLayout();
            this->SuspendLayout();
            // 
            // statusStrip1
            // 
            this->statusStrip1->ImageScalingSize = System::Drawing::Size(24, 24);
            this->statusStrip1->Items->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(4) {
                this->toolStripStatusLabel1,
                    this->connectionLabel, this->inputVoltageLabel, this->inputVoltageValueLabel
            });
            this->statusStrip1->Location = System::Drawing::Point(0, 576);
            this->statusStrip1->Name = L"statusStrip1";
            this->statusStrip1->Padding = System::Windows::Forms::Padding(2, 0, 5, 0);
            this->statusStrip1->Size = System::Drawing::Size(834, 22);
            this->statusStrip1->TabIndex = 0;
            this->statusStrip1->Text = L"statusStrip1";
            // 
            // toolStripStatusLabel1
            // 
            this->toolStripStatusLabel1->Font = (gcnew System::Drawing::Font(L"Segoe UI", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->toolStripStatusLabel1->Name = L"toolStripStatusLabel1";
            this->toolStripStatusLabel1->Size = System::Drawing::Size(111, 17);
            this->toolStripStatusLabel1->Text = L"Connection Status:";
            // 
            // connectionLabel
            // 
            this->connectionLabel->ForeColor = System::Drawing::Color::Red;
            this->connectionLabel->Name = L"connectionLabel";
            this->connectionLabel->Size = System::Drawing::Size(79, 17);
            this->connectionLabel->Text = L"Disconnected";
            // 
            // inputVoltageLabel
            // 
            this->inputVoltageLabel->Font = (gcnew System::Drawing::Font(L"Segoe UI", 9, System::Drawing::FontStyle::Bold));
            this->inputVoltageLabel->ImageAlign = System::Drawing::ContentAlignment::MiddleRight;
            this->inputVoltageLabel->Name = L"inputVoltageLabel";
            this->inputVoltageLabel->Size = System::Drawing::Size(85, 17);
            this->inputVoltageLabel->Text = L"Input Voltage:";
            this->inputVoltageLabel->Visible = false;
            // 
            // inputVoltageValueLabel
            // 
            this->inputVoltageValueLabel->Name = L"inputVoltageValueLabel";
            this->inputVoltageValueLabel->Size = System::Drawing::Size(20, 17);
            this->inputVoltageValueLabel->Text = L"0V";
            this->inputVoltageValueLabel->Visible = false;
            this->inputVoltageValueLabel->Click += gcnew System::EventHandler(this, &ConfigurationGui::toolStripStatusLabel3_Click);
            // 
            // menuStrip1
            // 
            this->menuStrip1->ImageScalingSize = System::Drawing::Size(24, 24);
            this->menuStrip1->Items->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(3) {
                this->fileToolStripMenuItem,
                    this->toolsToolStripMenuItem, this->helpToolStripMenuItem
            });
            this->menuStrip1->Location = System::Drawing::Point(0, 0);
            this->menuStrip1->Name = L"menuStrip1";
            this->menuStrip1->Padding = System::Windows::Forms::Padding(4, 1, 0, 1);
            this->menuStrip1->Size = System::Drawing::Size(834, 24);
            this->menuStrip1->TabIndex = 1;
            this->menuStrip1->Text = L"menuStrip1";
            // 
            // fileToolStripMenuItem
            // 
            this->fileToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(3) {
                this->saveMenuItem,
                    this->loadConfigMenuItem, this->exitToolStripMenuItem1
            });
            this->fileToolStripMenuItem->Name = L"fileToolStripMenuItem";
            this->fileToolStripMenuItem->Size = System::Drawing::Size(37, 22);
            this->fileToolStripMenuItem->Text = L"File";
            // 
            // saveMenuItem
            // 
            this->saveMenuItem->Name = L"saveMenuItem";
            this->saveMenuItem->Size = System::Drawing::Size(177, 22);
            this->saveMenuItem->Text = L"Save Configuration";
            this->saveMenuItem->Click += gcnew System::EventHandler(this, &ConfigurationGui::saveMenuItem_Click);
            // 
            // loadConfigMenuItem
            // 
            this->loadConfigMenuItem->Name = L"loadConfigMenuItem";
            this->loadConfigMenuItem->Size = System::Drawing::Size(177, 22);
            this->loadConfigMenuItem->Text = L"Load Configuration";
            this->loadConfigMenuItem->Click += gcnew System::EventHandler(this, &ConfigurationGui::loadConfigMenuItem_Click);
            // 
            // exitToolStripMenuItem1
            // 
            this->exitToolStripMenuItem1->Name = L"exitToolStripMenuItem1";
            this->exitToolStripMenuItem1->Size = System::Drawing::Size(177, 22);
            this->exitToolStripMenuItem1->Text = L"Exit";
            this->exitToolStripMenuItem1->Click += gcnew System::EventHandler(this, &ConfigurationGui::exitToolStripMenuItem1_Click);
            // 
            // toolsToolStripMenuItem
            // 
            this->toolsToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(1) { this->enterDFUModeToolStripMenuItem });
            this->toolsToolStripMenuItem->Name = L"toolsToolStripMenuItem";
            this->toolsToolStripMenuItem->Size = System::Drawing::Size(46, 22);
            this->toolsToolStripMenuItem->Text = L"Tools";
            // 
            // enterDFUModeToolStripMenuItem
            // 
            this->enterDFUModeToolStripMenuItem->Name = L"enterDFUModeToolStripMenuItem";
            this->enterDFUModeToolStripMenuItem->Size = System::Drawing::Size(180, 22);
            this->enterDFUModeToolStripMenuItem->Text = L"Enter DFU mode";
            this->enterDFUModeToolStripMenuItem->Click += gcnew System::EventHandler(this, &ConfigurationGui::enterDFUModeToolStripMenuItem_Click);
            // 
            // helpToolStripMenuItem
            // 
            this->helpToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(1) { this->aboutSoftwareToolStripMenuItem });
            this->helpToolStripMenuItem->Name = L"helpToolStripMenuItem";
            this->helpToolStripMenuItem->Size = System::Drawing::Size(44, 22);
            this->helpToolStripMenuItem->Text = L"Help";
            // 
            // aboutSoftwareToolStripMenuItem
            // 
            this->aboutSoftwareToolStripMenuItem->Name = L"aboutSoftwareToolStripMenuItem";
            this->aboutSoftwareToolStripMenuItem->Size = System::Drawing::Size(180, 22);
            this->aboutSoftwareToolStripMenuItem->Text = L"User\'s Guide";
            this->aboutSoftwareToolStripMenuItem->Click += gcnew System::EventHandler(this, &ConfigurationGui::aboutSoftwareToolStripMenuItem_Click);
            // 
            // mainTabControl
            // 
            this->mainTabControl->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->mainTabControl->Controls->Add(this->tabPage1);
            this->mainTabControl->Controls->Add(this->tabPage5);
            this->mainTabControl->Controls->Add(this->tabPage2);
            this->mainTabControl->Controls->Add(this->tabPage3);
            this->mainTabControl->Controls->Add(this->tabPage4);
            this->mainTabControl->Location = System::Drawing::Point(8, 51);
            this->mainTabControl->Margin = System::Windows::Forms::Padding(2);
            this->mainTabControl->Name = L"mainTabControl";
            this->mainTabControl->SelectedIndex = 0;
            this->mainTabControl->Size = System::Drawing::Size(815, 523);
            this->mainTabControl->TabIndex = 2;
            this->mainTabControl->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::mainTabControl_SelectedIndexChanged);
            // 
            // tabPage1
            // 
            this->tabPage1->Controls->Add(this->groupBox3);
            this->tabPage1->Controls->Add(this->groupBox2);
            this->tabPage1->Controls->Add(this->groupBox1);
            this->tabPage1->Controls->Add(this->senseChart);
            this->tabPage1->Location = System::Drawing::Point(4, 22);
            this->tabPage1->Margin = System::Windows::Forms::Padding(2);
            this->tabPage1->Name = L"tabPage1";
            this->tabPage1->Padding = System::Windows::Forms::Padding(2);
            this->tabPage1->Size = System::Drawing::Size(807, 497);
            this->tabPage1->TabIndex = 0;
            this->tabPage1->Text = L"Command Center";
            this->tabPage1->UseVisualStyleBackColor = true;
            // 
            // groupBox3
            // 
            this->groupBox3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->groupBox3->AutoSizeMode = System::Windows::Forms::AutoSizeMode::GrowAndShrink;
            this->groupBox3->Controls->Add(this->tableLayoutPanel4);
            this->groupBox3->Controls->Add(this->tableLayoutPanel3);
            this->groupBox3->Controls->Add(this->tableLayoutPanel2);
            this->groupBox3->Controls->Add(this->tableLayoutPanel1);
            this->groupBox3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->groupBox3->Location = System::Drawing::Point(422, 304);
            this->groupBox3->Margin = System::Windows::Forms::Padding(2);
            this->groupBox3->Name = L"groupBox3";
            this->groupBox3->Padding = System::Windows::Forms::Padding(2);
            this->groupBox3->Size = System::Drawing::Size(383, 196);
            this->groupBox3->TabIndex = 5;
            this->groupBox3->TabStop = false;
            this->groupBox3->Text = L"Faults/Diagnostics";
            // 
            // tableLayoutPanel4
            // 
            this->tableLayoutPanel4->Anchor = System::Windows::Forms::AnchorStyles::Left;
            this->tableLayoutPanel4->ColumnCount = 1;
            this->tableLayoutPanel4->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                100)));
            this->tableLayoutPanel4->Controls->Add(this->label13, 0, 0);
            this->tableLayoutPanel4->Controls->Add(this->faultBox4, 0, 2);
            this->tableLayoutPanel4->Controls->Add(this->channelFourLabel, 0, 3);
            this->tableLayoutPanel4->Controls->Add(this->channelFourFaultLabel, 0, 1);
            this->tableLayoutPanel4->Location = System::Drawing::Point(290, 17);
            this->tableLayoutPanel4->Margin = System::Windows::Forms::Padding(2);
            this->tableLayoutPanel4->Name = L"tableLayoutPanel4";
            this->tableLayoutPanel4->RowCount = 4;
            this->tableLayoutPanel4->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 26.79426F)));
            this->tableLayoutPanel4->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel4->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 73.20574F)));
            this->tableLayoutPanel4->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel4->Size = System::Drawing::Size(90, 172);
            this->tableLayoutPanel4->TabIndex = 3;
            // 
            // label13
            // 
            this->label13->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label13->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label13->Location = System::Drawing::Point(2, 0);
            this->label13->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label13->Name = L"label13";
            this->label13->Size = System::Drawing::Size(86, 26);
            this->label13->TabIndex = 0;
            this->label13->Text = L"Channel 4";
            this->label13->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // faultBox4
            // 
            this->faultBox4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultBox4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"faultBox4.Image")));
            this->faultBox4->Location = System::Drawing::Point(2, 64);
            this->faultBox4->Margin = System::Windows::Forms::Padding(2);
            this->faultBox4->Name = L"faultBox4";
            this->faultBox4->Size = System::Drawing::Size(86, 69);
            this->faultBox4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->faultBox4->TabIndex = 1;
            this->faultBox4->TabStop = false;
            this->faultBox4->Click += gcnew System::EventHandler(this, &ConfigurationGui::faultBox1_Click_1);
            // 
            // channelFourLabel
            // 
            this->channelFourLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelFourLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->channelFourLabel->Location = System::Drawing::Point(2, 135);
            this->channelFourLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelFourLabel->Name = L"channelFourLabel";
            this->channelFourLabel->Size = System::Drawing::Size(86, 37);
            this->channelFourLabel->TabIndex = 2;
            this->channelFourLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // channelFourFaultLabel
            // 
            this->channelFourFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelFourFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            this->channelFourFaultLabel->Location = System::Drawing::Point(2, 26);
            this->channelFourFaultLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelFourFaultLabel->Name = L"channelFourFaultLabel";
            this->channelFourFaultLabel->Size = System::Drawing::Size(86, 36);
            this->channelFourFaultLabel->TabIndex = 3;
            this->channelFourFaultLabel->Text = L"No Fault";
            this->channelFourFaultLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tableLayoutPanel3
            // 
            this->tableLayoutPanel3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->tableLayoutPanel3->ColumnCount = 1;
            this->tableLayoutPanel3->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                100)));
            this->tableLayoutPanel3->Controls->Add(this->label11, 0, 0);
            this->tableLayoutPanel3->Controls->Add(this->faultBox3, 0, 2);
            this->tableLayoutPanel3->Controls->Add(this->channelThreeLabel, 0, 3);
            this->tableLayoutPanel3->Controls->Add(this->channelThreeFaultLabel, 0, 1);
            this->tableLayoutPanel3->Location = System::Drawing::Point(194, 18);
            this->tableLayoutPanel3->Margin = System::Windows::Forms::Padding(2);
            this->tableLayoutPanel3->Name = L"tableLayoutPanel3";
            this->tableLayoutPanel3->RowCount = 4;
            this->tableLayoutPanel3->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 26.79426F)));
            this->tableLayoutPanel3->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel3->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 73.20574F)));
            this->tableLayoutPanel3->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel3->Size = System::Drawing::Size(90, 172);
            this->tableLayoutPanel3->TabIndex = 2;
            // 
            // label11
            // 
            this->label11->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label11->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label11->Location = System::Drawing::Point(2, 0);
            this->label11->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label11->Name = L"label11";
            this->label11->Size = System::Drawing::Size(86, 26);
            this->label11->TabIndex = 0;
            this->label11->Text = L"Channel 3";
            this->label11->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // faultBox3
            // 
            this->faultBox3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultBox3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"faultBox3.Image")));
            this->faultBox3->Location = System::Drawing::Point(2, 64);
            this->faultBox3->Margin = System::Windows::Forms::Padding(2);
            this->faultBox3->Name = L"faultBox3";
            this->faultBox3->Size = System::Drawing::Size(86, 69);
            this->faultBox3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->faultBox3->TabIndex = 1;
            this->faultBox3->TabStop = false;
            this->faultBox3->Click += gcnew System::EventHandler(this, &ConfigurationGui::faultBox1_Click_1);
            // 
            // channelThreeLabel
            // 
            this->channelThreeLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelThreeLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->channelThreeLabel->Location = System::Drawing::Point(2, 135);
            this->channelThreeLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelThreeLabel->Name = L"channelThreeLabel";
            this->channelThreeLabel->Size = System::Drawing::Size(86, 37);
            this->channelThreeLabel->TabIndex = 2;
            this->channelThreeLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // channelThreeFaultLabel
            // 
            this->channelThreeFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelThreeFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            this->channelThreeFaultLabel->Location = System::Drawing::Point(2, 26);
            this->channelThreeFaultLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelThreeFaultLabel->Name = L"channelThreeFaultLabel";
            this->channelThreeFaultLabel->Size = System::Drawing::Size(86, 36);
            this->channelThreeFaultLabel->TabIndex = 3;
            this->channelThreeFaultLabel->Text = L"No Fault";
            this->channelThreeFaultLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tableLayoutPanel2
            // 
            this->tableLayoutPanel2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->tableLayoutPanel2->ColumnCount = 1;
            this->tableLayoutPanel2->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                100)));
            this->tableLayoutPanel2->Controls->Add(this->label9, 0, 0);
            this->tableLayoutPanel2->Controls->Add(this->faultBox2, 0, 2);
            this->tableLayoutPanel2->Controls->Add(this->channelTwoLabel, 0, 3);
            this->tableLayoutPanel2->Controls->Add(this->channelTwoFaultLabel, 0, 1);
            this->tableLayoutPanel2->Location = System::Drawing::Point(98, 19);
            this->tableLayoutPanel2->Margin = System::Windows::Forms::Padding(2);
            this->tableLayoutPanel2->Name = L"tableLayoutPanel2";
            this->tableLayoutPanel2->RowCount = 4;
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 26.79426F)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 73.20574F)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 20)));
            this->tableLayoutPanel2->Size = System::Drawing::Size(90, 172);
            this->tableLayoutPanel2->TabIndex = 1;
            // 
            // label9
            // 
            this->label9->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label9->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label9->Location = System::Drawing::Point(2, 0);
            this->label9->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label9->Name = L"label9";
            this->label9->Size = System::Drawing::Size(86, 26);
            this->label9->TabIndex = 0;
            this->label9->Text = L"Channel 2";
            this->label9->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // faultBox2
            // 
            this->faultBox2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultBox2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"faultBox2.Image")));
            this->faultBox2->Location = System::Drawing::Point(2, 64);
            this->faultBox2->Margin = System::Windows::Forms::Padding(2);
            this->faultBox2->Name = L"faultBox2";
            this->faultBox2->Size = System::Drawing::Size(86, 69);
            this->faultBox2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->faultBox2->TabIndex = 1;
            this->faultBox2->TabStop = false;
            this->faultBox2->Click += gcnew System::EventHandler(this, &ConfigurationGui::faultBox1_Click_1);
            // 
            // channelTwoLabel
            // 
            this->channelTwoLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelTwoLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->channelTwoLabel->Location = System::Drawing::Point(2, 135);
            this->channelTwoLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelTwoLabel->Name = L"channelTwoLabel";
            this->channelTwoLabel->Size = System::Drawing::Size(86, 37);
            this->channelTwoLabel->TabIndex = 2;
            this->channelTwoLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // channelTwoFaultLabel
            // 
            this->channelTwoFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelTwoFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            this->channelTwoFaultLabel->Location = System::Drawing::Point(2, 26);
            this->channelTwoFaultLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelTwoFaultLabel->Name = L"channelTwoFaultLabel";
            this->channelTwoFaultLabel->Size = System::Drawing::Size(86, 36);
            this->channelTwoFaultLabel->TabIndex = 3;
            this->channelTwoFaultLabel->Text = L"No Fault";
            this->channelTwoFaultLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tableLayoutPanel1
            // 
            this->tableLayoutPanel1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->tableLayoutPanel1->ColumnCount = 1;
            this->tableLayoutPanel1->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                100)));
            this->tableLayoutPanel1->Controls->Add(this->label7, 0, 0);
            this->tableLayoutPanel1->Controls->Add(this->faultBox1, 0, 2);
            this->tableLayoutPanel1->Controls->Add(this->channelOneLabel, 0, 3);
            this->tableLayoutPanel1->Controls->Add(this->channelOneFaultLabel, 0, 1);
            this->tableLayoutPanel1->Location = System::Drawing::Point(4, 20);
            this->tableLayoutPanel1->Margin = System::Windows::Forms::Padding(2);
            this->tableLayoutPanel1->Name = L"tableLayoutPanel1";
            this->tableLayoutPanel1->RowCount = 4;
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 26.79426F)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 73.20574F)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 36)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 20)));
            this->tableLayoutPanel1->Size = System::Drawing::Size(90, 172);
            this->tableLayoutPanel1->TabIndex = 0;
            // 
            // label7
            // 
            this->label7->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label7->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label7->Location = System::Drawing::Point(2, 0);
            this->label7->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label7->Name = L"label7";
            this->label7->Size = System::Drawing::Size(86, 26);
            this->label7->TabIndex = 0;
            this->label7->Text = L"Channel 1";
            this->label7->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // faultBox1
            // 
            this->faultBox1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultBox1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"faultBox1.Image")));
            this->faultBox1->Location = System::Drawing::Point(2, 64);
            this->faultBox1->Margin = System::Windows::Forms::Padding(2);
            this->faultBox1->Name = L"faultBox1";
            this->faultBox1->Size = System::Drawing::Size(86, 69);
            this->faultBox1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->faultBox1->TabIndex = 1;
            this->faultBox1->TabStop = false;
            this->faultBox1->Click += gcnew System::EventHandler(this, &ConfigurationGui::faultBox1_Click_1);
            // 
            // channelOneLabel
            // 
            this->channelOneLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelOneLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->channelOneLabel->Location = System::Drawing::Point(2, 135);
            this->channelOneLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelOneLabel->Name = L"channelOneLabel";
            this->channelOneLabel->Size = System::Drawing::Size(86, 37);
            this->channelOneLabel->TabIndex = 2;
            this->channelOneLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // channelOneFaultLabel
            // 
            this->channelOneFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelOneFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            this->channelOneFaultLabel->Location = System::Drawing::Point(2, 26);
            this->channelOneFaultLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->channelOneFaultLabel->Name = L"channelOneFaultLabel";
            this->channelOneFaultLabel->Size = System::Drawing::Size(86, 36);
            this->channelOneFaultLabel->TabIndex = 3;
            this->channelOneFaultLabel->Text = L"No Fault";
            this->channelOneFaultLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // groupBox2
            // 
            this->groupBox2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->groupBox2->Controls->Add(this->label6);
            this->groupBox2->Controls->Add(this->senseChannelAll);
            this->groupBox2->Controls->Add(this->maxSamplesBox);
            this->groupBox2->Controls->Add(this->label3);
            this->groupBox2->Controls->Add(this->senseChannelBox);
            this->groupBox2->Controls->Add(this->senseSourceSelBox);
            this->groupBox2->Controls->Add(this->label2);
            this->groupBox2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->groupBox2->Location = System::Drawing::Point(212, 304);
            this->groupBox2->Margin = System::Windows::Forms::Padding(2);
            this->groupBox2->Name = L"groupBox2";
            this->groupBox2->Padding = System::Windows::Forms::Padding(2);
            this->groupBox2->Size = System::Drawing::Size(206, 196);
            this->groupBox2->TabIndex = 4;
            this->groupBox2->TabStop = false;
            this->groupBox2->Text = L"Graph Settings";
            // 
            // label6
            // 
            this->label6->AutoSize = true;
            this->label6->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label6->Location = System::Drawing::Point(6, 70);
            this->label6->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label6->Name = L"label6";
            this->label6->Size = System::Drawing::Size(95, 13);
            this->label6->TabIndex = 9;
            this->label6->Text = L"Enable Sensing";
            // 
            // senseChannelAll
            // 
            this->senseChannelAll->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->senseChannelAll->AutoSize = true;
            this->senseChannelAll->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->senseChannelAll->Location = System::Drawing::Point(159, 70);
            this->senseChannelAll->Margin = System::Windows::Forms::Padding(2);
            this->senseChannelAll->Name = L"senseChannelAll";
            this->senseChannelAll->Size = System::Drawing::Size(37, 17);
            this->senseChannelAll->TabIndex = 8;
            this->senseChannelAll->Text = L"All";
            this->senseChannelAll->UseVisualStyleBackColor = true;
            this->senseChannelAll->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::senseChannelAll_CheckedChanged);
            // 
            // maxSamplesBox
            // 
            this->maxSamplesBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->maxSamplesBox->Location = System::Drawing::Point(89, 42);
            this->maxSamplesBox->Margin = System::Windows::Forms::Padding(2);
            this->maxSamplesBox->Name = L"maxSamplesBox";
            this->maxSamplesBox->Size = System::Drawing::Size(107, 20);
            this->maxSamplesBox->TabIndex = 4;
            this->maxSamplesBox->Text = L"50";
            // 
            // label3
            // 
            this->label3->AutoSize = true;
            this->label3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label3->Location = System::Drawing::Point(5, 42);
            this->label3->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label3->Name = L"label3";
            this->label3->Size = System::Drawing::Size(85, 13);
            this->label3->TabIndex = 3;
            this->label3->Text = L"Max Samples:";
            // 
            // senseChannelBox
            // 
            this->senseChannelBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->senseChannelBox->CheckOnClick = true;
            this->senseChannelBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->senseChannelBox->FormattingEnabled = true;
            this->senseChannelBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"Channel 1", L"Channel 2", L"Channel 3",
                    L"Channel 4"
            });
            this->senseChannelBox->Location = System::Drawing::Point(9, 97);
            this->senseChannelBox->Margin = System::Windows::Forms::Padding(2);
            this->senseChannelBox->Name = L"senseChannelBox";
            this->senseChannelBox->Size = System::Drawing::Size(188, 94);
            this->senseChannelBox->TabIndex = 2;
            this->senseChannelBox->ItemCheck += gcnew System::Windows::Forms::ItemCheckEventHandler(this, &ConfigurationGui::senseChannelBox_ItemCheck);
            // 
            // senseSourceSelBox
            // 
            this->senseSourceSelBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->senseSourceSelBox->FormattingEnabled = true;
            this->senseSourceSelBox->Items->AddRange(gcnew cli::array< System::Object^  >(3) { L"Load Current", L"FET Temperature", L"Output Voltage" });
            this->senseSourceSelBox->Location = System::Drawing::Point(89, 19);
            this->senseSourceSelBox->Margin = System::Windows::Forms::Padding(2);
            this->senseSourceSelBox->Name = L"senseSourceSelBox";
            this->senseSourceSelBox->Size = System::Drawing::Size(107, 21);
            this->senseSourceSelBox->TabIndex = 1;
            this->senseSourceSelBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::senseSourceSelBox_SelectedIndexChanged);
            // 
            // label2
            // 
            this->label2->AutoSize = true;
            this->label2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label2->Location = System::Drawing::Point(4, 19);
            this->label2->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label2->Name = L"label2";
            this->label2->Size = System::Drawing::Size(51, 13);
            this->label2->TabIndex = 0;
            this->label2->Text = L"Source:";
            // 
            // groupBox1
            // 
            this->groupBox1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->groupBox1->Controls->Add(this->toggleAllChannelsBox);
            this->groupBox1->Controls->Add(this->label5);
            this->groupBox1->Controls->Add(this->label4);
            this->groupBox1->Controls->Add(this->toggleAllLEDChannelsBox);
            this->groupBox1->Controls->Add(this->ledToggleBoxGroup);
            this->groupBox1->Controls->Add(this->chanEnableBoxGroup);
            this->groupBox1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->groupBox1->Location = System::Drawing::Point(2, 304);
            this->groupBox1->Margin = System::Windows::Forms::Padding(2);
            this->groupBox1->Name = L"groupBox1";
            this->groupBox1->Padding = System::Windows::Forms::Padding(2);
            this->groupBox1->Size = System::Drawing::Size(207, 196);
            this->groupBox1->TabIndex = 3;
            this->groupBox1->TabStop = false;
            this->groupBox1->Text = L"Channel/LED Enable";
            // 
            // toggleAllChannelsBox
            // 
            this->toggleAllChannelsBox->AutoSize = true;
            this->toggleAllChannelsBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->toggleAllChannelsBox->Location = System::Drawing::Point(154, 17);
            this->toggleAllChannelsBox->Margin = System::Windows::Forms::Padding(2);
            this->toggleAllChannelsBox->Name = L"toggleAllChannelsBox";
            this->toggleAllChannelsBox->Size = System::Drawing::Size(37, 17);
            this->toggleAllChannelsBox->TabIndex = 9;
            this->toggleAllChannelsBox->Text = L"All";
            this->toggleAllChannelsBox->UseVisualStyleBackColor = true;
            this->toggleAllChannelsBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::toggleAllChannelsBox_CheckedChanged);
            // 
            // label5
            // 
            this->label5->AutoSize = true;
            this->label5->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label5->Location = System::Drawing::Point(7, 17);
            this->label5->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label5->Name = L"label5";
            this->label5->Size = System::Drawing::Size(59, 13);
            this->label5->TabIndex = 8;
            this->label5->Text = L"Channels";
            // 
            // label4
            // 
            this->label4->AutoSize = true;
            this->label4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label4->Location = System::Drawing::Point(7, 105);
            this->label4->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label4->Name = L"label4";
            this->label4->Size = System::Drawing::Size(37, 13);
            this->label4->TabIndex = 7;
            this->label4->Text = L"LEDs";
            // 
            // toggleAllLEDChannelsBox
            // 
            this->toggleAllLEDChannelsBox->AutoSize = true;
            this->toggleAllLEDChannelsBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->toggleAllLEDChannelsBox->Location = System::Drawing::Point(154, 105);
            this->toggleAllLEDChannelsBox->Margin = System::Windows::Forms::Padding(2);
            this->toggleAllLEDChannelsBox->Name = L"toggleAllLEDChannelsBox";
            this->toggleAllLEDChannelsBox->Size = System::Drawing::Size(37, 17);
            this->toggleAllLEDChannelsBox->TabIndex = 6;
            this->toggleAllLEDChannelsBox->Text = L"All";
            this->toggleAllLEDChannelsBox->UseVisualStyleBackColor = true;
            this->toggleAllLEDChannelsBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::toggleAllLEDChannelsBox_CheckedChanged);
            // 
            // ledToggleBoxGroup
            // 
            this->ledToggleBoxGroup->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->ledToggleBoxGroup->CheckOnClick = true;
            this->ledToggleBoxGroup->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->ledToggleBoxGroup->FormattingEnabled = true;
            this->ledToggleBoxGroup->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"LED1", L"LED2", L"LED3", L"LED4", L"LED5",
                    L"LED6", L"LED7", L"LED8"
            });
            this->ledToggleBoxGroup->Location = System::Drawing::Point(9, 127);
            this->ledToggleBoxGroup->Margin = System::Windows::Forms::Padding(2);
            this->ledToggleBoxGroup->Name = L"ledToggleBoxGroup";
            this->ledToggleBoxGroup->ScrollAlwaysVisible = true;
            this->ledToggleBoxGroup->Size = System::Drawing::Size(181, 64);
            this->ledToggleBoxGroup->TabIndex = 1;
            this->ledToggleBoxGroup->ItemCheck += gcnew System::Windows::Forms::ItemCheckEventHandler(this, &ConfigurationGui::ledToggleBoxGroup_ItemCheck);
            // 
            // chanEnableBoxGroup
            // 
            this->chanEnableBoxGroup->CheckOnClick = true;
            this->chanEnableBoxGroup->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->chanEnableBoxGroup->FormattingEnabled = true;
            this->chanEnableBoxGroup->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"Channel 1", L"Channel 2", L"Channel 3",
                    L"Channel 4"
            });
            this->chanEnableBoxGroup->Location = System::Drawing::Point(10, 36);
            this->chanEnableBoxGroup->Margin = System::Windows::Forms::Padding(2);
            this->chanEnableBoxGroup->Name = L"chanEnableBoxGroup";
            this->chanEnableBoxGroup->Size = System::Drawing::Size(181, 64);
            this->chanEnableBoxGroup->TabIndex = 0;
            this->chanEnableBoxGroup->ItemCheck += gcnew System::Windows::Forms::ItemCheckEventHandler(this, &ConfigurationGui::checkedListBox1_ItemCheck);
            // 
            // senseChart
            // 
            this->senseChart->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            customLabel1->Text = L"Time";
            chartArea1->AxisX->CustomLabels->Add(customLabel1);
            chartArea1->AxisY->MinorGrid->Enabled = true;
            chartArea1->AxisY->MinorTickMark->Enabled = true;
            chartArea1->AxisY->Title = L"Current (A)";
            chartArea1->Name = L"ChartArea1";
            this->senseChart->ChartAreas->Add(chartArea1);
            legend1->Alignment = System::Drawing::StringAlignment::Center;
            legend1->Docking = System::Windows::Forms::DataVisualization::Charting::Docking::Bottom;
            legend1->Name = L"Legend1";
            this->senseChart->Legends->Add(legend1);
            this->senseChart->Location = System::Drawing::Point(2, 4);
            this->senseChart->Margin = System::Windows::Forms::Padding(2);
            this->senseChart->Name = L"senseChart";
            this->senseChart->Palette = System::Windows::Forms::DataVisualization::Charting::ChartColorPalette::EarthTones;
            series1->ChartArea = L"ChartArea1";
            series1->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series1->Enabled = false;
            series1->Legend = L"Legend1";
            series1->Name = L"Channel 1";
            series2->ChartArea = L"ChartArea1";
            series2->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series2->Enabled = false;
            series2->Legend = L"Legend1";
            series2->Name = L"Channel 2";
            series3->ChartArea = L"ChartArea1";
            series3->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series3->Enabled = false;
            series3->Legend = L"Legend1";
            series3->Name = L"Channel 3";
            series4->ChartArea = L"ChartArea1";
            series4->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series4->Enabled = false;
            series4->Legend = L"Legend1";
            series4->Name = L"Channel 4 ";
            this->senseChart->Series->Add(series1);
            this->senseChart->Series->Add(series2);
            this->senseChart->Series->Add(series3);
            this->senseChart->Series->Add(series4);
            this->senseChart->Size = System::Drawing::Size(806, 297);
            this->senseChart->TabIndex = 0;
            this->senseChart->Text = L"Current Sense Graph";
            title1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 11.25F, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            title1->Name = L"Title1";
            title1->Text = L"Current Sense Data";
            this->senseChart->Titles->Add(title1);
            // 
            // tabPage5
            // 
            this->tabPage5->Controls->Add(this->clearAllStatsButton);
            this->tabPage5->Controls->Add(this->manualUpdateButton);
            this->tabPage5->Controls->Add(this->faultUpdateStatus);
            this->tabPage5->Controls->Add(this->label46);
            this->tabPage5->Controls->Add(this->groupBox10);
            this->tabPage5->Controls->Add(this->groupBox9);
            this->tabPage5->Controls->Add(this->groupBox8);
            this->tabPage5->Location = System::Drawing::Point(4, 22);
            this->tabPage5->Name = L"tabPage5";
            this->tabPage5->Size = System::Drawing::Size(807, 497);
            this->tabPage5->TabIndex = 4;
            this->tabPage5->Text = L"Fault View";
            this->tabPage5->UseVisualStyleBackColor = true;
            // 
            // clearAllStatsButton
            // 
            this->clearAllStatsButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->clearAllStatsButton->Location = System::Drawing::Point(405, 467);
            this->clearAllStatsButton->Margin = System::Windows::Forms::Padding(2);
            this->clearAllStatsButton->Name = L"clearAllStatsButton";
            this->clearAllStatsButton->Size = System::Drawing::Size(159, 23);
            this->clearAllStatsButton->TabIndex = 7;
            this->clearAllStatsButton->Text = L"Clear All Stats";
            this->clearAllStatsButton->UseVisualStyleBackColor = true;
            this->clearAllStatsButton->Click += gcnew System::EventHandler(this, &ConfigurationGui::clearAllStatsButton_Click);
            // 
            // manualUpdateButton
            // 
            this->manualUpdateButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->manualUpdateButton->Enabled = false;
            this->manualUpdateButton->Location = System::Drawing::Point(236, 467);
            this->manualUpdateButton->Margin = System::Windows::Forms::Padding(2);
            this->manualUpdateButton->Name = L"manualUpdateButton";
            this->manualUpdateButton->Size = System::Drawing::Size(161, 23);
            this->manualUpdateButton->TabIndex = 6;
            this->manualUpdateButton->Text = L"Manual Update";
            this->manualUpdateButton->UseVisualStyleBackColor = true;
            this->manualUpdateButton->Click += gcnew System::EventHandler(this, &ConfigurationGui::manualUpdateButton_Click);
            // 
            // faultUpdateStatus
            // 
            this->faultUpdateStatus->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->faultUpdateStatus->FormattingEnabled = true;
            this->faultUpdateStatus->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"Automatic", L"Manual" });
            this->faultUpdateStatus->Location = System::Drawing::Point(110, 467);
            this->faultUpdateStatus->Margin = System::Windows::Forms::Padding(2);
            this->faultUpdateStatus->Name = L"faultUpdateStatus";
            this->faultUpdateStatus->Size = System::Drawing::Size(121, 21);
            this->faultUpdateStatus->TabIndex = 5;
            this->faultUpdateStatus->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::faultUpdateStatus_SelectedIndexChanged);
            // 
            // label46
            // 
            this->label46->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->label46->AutoSize = true;
            this->label46->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label46->Location = System::Drawing::Point(8, 470);
            this->label46->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label46->Name = L"label46";
            this->label46->Size = System::Drawing::Size(100, 13);
            this->label46->TabIndex = 4;
            this->label46->Text = L"Update Setting: ";
            // 
            // groupBox10
            // 
            this->groupBox10->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->groupBox10->Controls->Add(this->tableLayoutPanel5);
            this->groupBox10->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->groupBox10->Location = System::Drawing::Point(7, 99);
            this->groupBox10->Margin = System::Windows::Forms::Padding(2);
            this->groupBox10->Name = L"groupBox10";
            this->groupBox10->Padding = System::Windows::Forms::Padding(2);
            this->groupBox10->Size = System::Drawing::Size(562, 364);
            this->groupBox10->TabIndex = 3;
            this->groupBox10->TabStop = false;
            this->groupBox10->Text = L"Channel Faults";
            // 
            // tableLayoutPanel5
            // 
            this->tableLayoutPanel5->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tableLayoutPanel5->AutoSize = true;
            this->tableLayoutPanel5->ColumnCount = 5;
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Absolute,
                133)));
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel5->Controls->Add(this->label54, 1, 0);
            this->tableLayoutPanel5->Controls->Add(this->label55, 2, 0);
            this->tableLayoutPanel5->Controls->Add(this->label56, 3, 0);
            this->tableLayoutPanel5->Controls->Add(this->label57, 4, 0);
            this->tableLayoutPanel5->Controls->Add(this->label58, 0, 1);
            this->tableLayoutPanel5->Controls->Add(this->label59, 0, 2);
            this->tableLayoutPanel5->Controls->Add(this->label60, 0, 3);
            this->tableLayoutPanel5->Controls->Add(this->label61, 0, 4);
            this->tableLayoutPanel5->Controls->Add(this->shtsFaultBoxCh1, 1, 1);
            this->tableLayoutPanel5->Controls->Add(this->shtsFaultBoxCh2, 2, 1);
            this->tableLayoutPanel5->Controls->Add(this->shtsFaultBoxCh3, 3, 1);
            this->tableLayoutPanel5->Controls->Add(this->shtsFaultBoxCh4, 4, 1);
            this->tableLayoutPanel5->Controls->Add(this->wbOffFaultCh1, 1, 2);
            this->tableLayoutPanel5->Controls->Add(this->wbOffFaultCh2, 2, 2);
            this->tableLayoutPanel5->Controls->Add(this->wbOffFaultCh3, 3, 2);
            this->tableLayoutPanel5->Controls->Add(this->wbOffFaultCh4, 4, 2);
            this->tableLayoutPanel5->Controls->Add(this->wbOnFaultCh1, 1, 3);
            this->tableLayoutPanel5->Controls->Add(this->wbOnFaultCh2, 2, 3);
            this->tableLayoutPanel5->Controls->Add(this->wbOnFaultCh3, 3, 3);
            this->tableLayoutPanel5->Controls->Add(this->wbOnFaultCh4, 4, 3);
            this->tableLayoutPanel5->Controls->Add(this->ilimFaultBoxCh1, 1, 4);
            this->tableLayoutPanel5->Controls->Add(this->ilimFaultBoxCh2, 2, 4);
            this->tableLayoutPanel5->Controls->Add(this->ilimFaultBoxCh3, 3, 4);
            this->tableLayoutPanel5->Controls->Add(this->ilimFaultBoxCh4, 4, 4);
            this->tableLayoutPanel5->Controls->Add(this->label62, 0, 5);
            this->tableLayoutPanel5->Controls->Add(this->tsdFaultBoxCh1, 1, 5);
            this->tableLayoutPanel5->Controls->Add(this->tsdFaultBoxCh2, 2, 5);
            this->tableLayoutPanel5->Controls->Add(this->tsdFaultBoxCh3, 3, 5);
            this->tableLayoutPanel5->Controls->Add(this->tsdFaultBoxCh4, 4, 5);
            this->tableLayoutPanel5->Controls->Add(this->label63, 0, 6);
            this->tableLayoutPanel5->Controls->Add(this->tWarnBoxCh1, 1, 6);
            this->tableLayoutPanel5->Controls->Add(this->tWarnBoxCh2, 2, 6);
            this->tableLayoutPanel5->Controls->Add(this->tWarnBoxCh3, 3, 6);
            this->tableLayoutPanel5->Controls->Add(this->tWarnBoxCh4, 4, 6);
            this->tableLayoutPanel5->Controls->Add(this->label64, 0, 7);
            this->tableLayoutPanel5->Controls->Add(this->rvsrBoxCh1, 1, 7);
            this->tableLayoutPanel5->Controls->Add(this->rvsrBoxCh2, 2, 7);
            this->tableLayoutPanel5->Controls->Add(this->rvsrBoxCh3, 3, 7);
            this->tableLayoutPanel5->Controls->Add(this->rvsrBoxCh4, 4, 7);
            this->tableLayoutPanel5->Location = System::Drawing::Point(4, 16);
            this->tableLayoutPanel5->Margin = System::Windows::Forms::Padding(2);
            this->tableLayoutPanel5->Name = L"tableLayoutPanel5";
            this->tableLayoutPanel5->RowCount = 8;
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle()));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 14.28571F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 14.28572F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 14.28572F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 14.28572F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 14.28572F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 14.28572F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 14.28572F)));
            this->tableLayoutPanel5->Size = System::Drawing::Size(549, 250);
            this->tableLayoutPanel5->TabIndex = 0;
            // 
            // label54
            // 
            this->label54->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label54->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label54->Location = System::Drawing::Point(146, 0);
            this->label54->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label54->Name = L"label54";
            this->label54->Size = System::Drawing::Size(78, 26);
            this->label54->TabIndex = 5;
            this->label54->Text = L"Channel 1";
            this->label54->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label55
            // 
            this->label55->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label55->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label55->Location = System::Drawing::Point(250, 0);
            this->label55->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label55->Name = L"label55";
            this->label55->Size = System::Drawing::Size(78, 26);
            this->label55->TabIndex = 6;
            this->label55->Text = L"Channel 2";
            this->label55->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label56
            // 
            this->label56->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label56->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label56->Location = System::Drawing::Point(354, 0);
            this->label56->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label56->Name = L"label56";
            this->label56->Size = System::Drawing::Size(78, 26);
            this->label56->TabIndex = 7;
            this->label56->Text = L"Channel 3";
            this->label56->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label57
            // 
            this->label57->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label57->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label57->Location = System::Drawing::Point(458, 0);
            this->label57->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label57->Name = L"label57";
            this->label57->Size = System::Drawing::Size(78, 26);
            this->label57->TabIndex = 8;
            this->label57->Text = L"Channel 4";
            this->label57->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label58
            // 
            this->label58->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label58->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label58->Location = System::Drawing::Point(2, 26);
            this->label58->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label58->Name = L"label58";
            this->label58->Size = System::Drawing::Size(129, 31);
            this->label58->TabIndex = 18;
            this->label58->Text = L"Short-to-Supply:";
            this->label58->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label59
            // 
            this->label59->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label59->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label59->Location = System::Drawing::Point(2, 57);
            this->label59->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label59->Name = L"label59";
            this->label59->Size = System::Drawing::Size(129, 32);
            this->label59->TabIndex = 19;
            this->label59->Text = L"Wirebreak (off):";
            this->label59->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label60
            // 
            this->label60->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label60->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label60->Location = System::Drawing::Point(2, 89);
            this->label60->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label60->Name = L"label60";
            this->label60->Size = System::Drawing::Size(129, 32);
            this->label60->TabIndex = 20;
            this->label60->Text = L"Wirebreak (on):";
            this->label60->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label61
            // 
            this->label61->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label61->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label61->Location = System::Drawing::Point(2, 121);
            this->label61->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label61->Name = L"label61";
            this->label61->Size = System::Drawing::Size(129, 32);
            this->label61->TabIndex = 21;
            this->label61->Text = L"Current Limit:";
            this->label61->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // shtsFaultBoxCh1
            // 
            this->shtsFaultBoxCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->shtsFaultBoxCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"shtsFaultBoxCh1.Image")));
            this->shtsFaultBoxCh1->Location = System::Drawing::Point(135, 28);
            this->shtsFaultBoxCh1->Margin = System::Windows::Forms::Padding(2);
            this->shtsFaultBoxCh1->Name = L"shtsFaultBoxCh1";
            this->shtsFaultBoxCh1->Size = System::Drawing::Size(100, 27);
            this->shtsFaultBoxCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->shtsFaultBoxCh1->TabIndex = 22;
            this->shtsFaultBoxCh1->TabStop = false;
            this->shtsFaultBoxCh1->Click += gcnew System::EventHandler(this, &ConfigurationGui::shtsFaultBoxCh1_Click);
            // 
            // shtsFaultBoxCh2
            // 
            this->shtsFaultBoxCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->shtsFaultBoxCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"shtsFaultBoxCh2.Image")));
            this->shtsFaultBoxCh2->Location = System::Drawing::Point(239, 28);
            this->shtsFaultBoxCh2->Margin = System::Windows::Forms::Padding(2);
            this->shtsFaultBoxCh2->Name = L"shtsFaultBoxCh2";
            this->shtsFaultBoxCh2->Size = System::Drawing::Size(100, 27);
            this->shtsFaultBoxCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->shtsFaultBoxCh2->TabIndex = 23;
            this->shtsFaultBoxCh2->TabStop = false;
            this->shtsFaultBoxCh2->Click += gcnew System::EventHandler(this, &ConfigurationGui::shtsFaultBoxCh2_Click);
            // 
            // shtsFaultBoxCh3
            // 
            this->shtsFaultBoxCh3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->shtsFaultBoxCh3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"shtsFaultBoxCh3.Image")));
            this->shtsFaultBoxCh3->Location = System::Drawing::Point(343, 28);
            this->shtsFaultBoxCh3->Margin = System::Windows::Forms::Padding(2);
            this->shtsFaultBoxCh3->Name = L"shtsFaultBoxCh3";
            this->shtsFaultBoxCh3->Size = System::Drawing::Size(100, 27);
            this->shtsFaultBoxCh3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->shtsFaultBoxCh3->TabIndex = 24;
            this->shtsFaultBoxCh3->TabStop = false;
            this->shtsFaultBoxCh3->Click += gcnew System::EventHandler(this, &ConfigurationGui::shtsFaultBoxCh3_Click);
            // 
            // shtsFaultBoxCh4
            // 
            this->shtsFaultBoxCh4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->shtsFaultBoxCh4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"shtsFaultBoxCh4.Image")));
            this->shtsFaultBoxCh4->Location = System::Drawing::Point(447, 28);
            this->shtsFaultBoxCh4->Margin = System::Windows::Forms::Padding(2);
            this->shtsFaultBoxCh4->Name = L"shtsFaultBoxCh4";
            this->shtsFaultBoxCh4->Size = System::Drawing::Size(100, 27);
            this->shtsFaultBoxCh4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->shtsFaultBoxCh4->TabIndex = 25;
            this->shtsFaultBoxCh4->TabStop = false;
            this->shtsFaultBoxCh4->Click += gcnew System::EventHandler(this, &ConfigurationGui::shtsFaultBoxCh4_Click);
            // 
            // wbOffFaultCh1
            // 
            this->wbOffFaultCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOffFaultCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOffFaultCh1.Image")));
            this->wbOffFaultCh1->Location = System::Drawing::Point(135, 59);
            this->wbOffFaultCh1->Margin = System::Windows::Forms::Padding(2);
            this->wbOffFaultCh1->Name = L"wbOffFaultCh1";
            this->wbOffFaultCh1->Size = System::Drawing::Size(100, 28);
            this->wbOffFaultCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOffFaultCh1->TabIndex = 26;
            this->wbOffFaultCh1->TabStop = false;
            this->wbOffFaultCh1->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOffFaultCh1_Click);
            // 
            // wbOffFaultCh2
            // 
            this->wbOffFaultCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOffFaultCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOffFaultCh2.Image")));
            this->wbOffFaultCh2->Location = System::Drawing::Point(239, 59);
            this->wbOffFaultCh2->Margin = System::Windows::Forms::Padding(2);
            this->wbOffFaultCh2->Name = L"wbOffFaultCh2";
            this->wbOffFaultCh2->Size = System::Drawing::Size(100, 28);
            this->wbOffFaultCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOffFaultCh2->TabIndex = 27;
            this->wbOffFaultCh2->TabStop = false;
            this->wbOffFaultCh2->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOffFaultCh2_Click);
            // 
            // wbOffFaultCh3
            // 
            this->wbOffFaultCh3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOffFaultCh3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOffFaultCh3.Image")));
            this->wbOffFaultCh3->Location = System::Drawing::Point(343, 59);
            this->wbOffFaultCh3->Margin = System::Windows::Forms::Padding(2);
            this->wbOffFaultCh3->Name = L"wbOffFaultCh3";
            this->wbOffFaultCh3->Size = System::Drawing::Size(100, 28);
            this->wbOffFaultCh3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOffFaultCh3->TabIndex = 28;
            this->wbOffFaultCh3->TabStop = false;
            this->wbOffFaultCh3->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOffFaultCh3_Click);
            // 
            // wbOffFaultCh4
            // 
            this->wbOffFaultCh4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOffFaultCh4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOffFaultCh4.Image")));
            this->wbOffFaultCh4->Location = System::Drawing::Point(447, 59);
            this->wbOffFaultCh4->Margin = System::Windows::Forms::Padding(2);
            this->wbOffFaultCh4->Name = L"wbOffFaultCh4";
            this->wbOffFaultCh4->Size = System::Drawing::Size(100, 28);
            this->wbOffFaultCh4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOffFaultCh4->TabIndex = 29;
            this->wbOffFaultCh4->TabStop = false;
            this->wbOffFaultCh4->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOffFaultCh4_Click);
            // 
            // wbOnFaultCh1
            // 
            this->wbOnFaultCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOnFaultCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOnFaultCh1.Image")));
            this->wbOnFaultCh1->Location = System::Drawing::Point(135, 91);
            this->wbOnFaultCh1->Margin = System::Windows::Forms::Padding(2);
            this->wbOnFaultCh1->Name = L"wbOnFaultCh1";
            this->wbOnFaultCh1->Size = System::Drawing::Size(100, 28);
            this->wbOnFaultCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOnFaultCh1->TabIndex = 30;
            this->wbOnFaultCh1->TabStop = false;
            this->wbOnFaultCh1->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOnFaultCh1_Click);
            // 
            // wbOnFaultCh2
            // 
            this->wbOnFaultCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOnFaultCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOnFaultCh2.Image")));
            this->wbOnFaultCh2->Location = System::Drawing::Point(239, 91);
            this->wbOnFaultCh2->Margin = System::Windows::Forms::Padding(2);
            this->wbOnFaultCh2->Name = L"wbOnFaultCh2";
            this->wbOnFaultCh2->Size = System::Drawing::Size(100, 28);
            this->wbOnFaultCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOnFaultCh2->TabIndex = 31;
            this->wbOnFaultCh2->TabStop = false;
            this->wbOnFaultCh2->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOnFaultCh2_Click);
            // 
            // wbOnFaultCh3
            // 
            this->wbOnFaultCh3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOnFaultCh3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOnFaultCh3.Image")));
            this->wbOnFaultCh3->Location = System::Drawing::Point(343, 91);
            this->wbOnFaultCh3->Margin = System::Windows::Forms::Padding(2);
            this->wbOnFaultCh3->Name = L"wbOnFaultCh3";
            this->wbOnFaultCh3->Size = System::Drawing::Size(100, 28);
            this->wbOnFaultCh3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOnFaultCh3->TabIndex = 32;
            this->wbOnFaultCh3->TabStop = false;
            this->wbOnFaultCh3->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOnFaultCh3_Click);
            // 
            // wbOnFaultCh4
            // 
            this->wbOnFaultCh4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOnFaultCh4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wbOnFaultCh4.Image")));
            this->wbOnFaultCh4->Location = System::Drawing::Point(447, 91);
            this->wbOnFaultCh4->Margin = System::Windows::Forms::Padding(2);
            this->wbOnFaultCh4->Name = L"wbOnFaultCh4";
            this->wbOnFaultCh4->Size = System::Drawing::Size(100, 28);
            this->wbOnFaultCh4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wbOnFaultCh4->TabIndex = 33;
            this->wbOnFaultCh4->TabStop = false;
            this->wbOnFaultCh4->Click += gcnew System::EventHandler(this, &ConfigurationGui::wbOnFaultCh4_Click);
            // 
            // ilimFaultBoxCh1
            // 
            this->ilimFaultBoxCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->ilimFaultBoxCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"ilimFaultBoxCh1.Image")));
            this->ilimFaultBoxCh1->Location = System::Drawing::Point(135, 123);
            this->ilimFaultBoxCh1->Margin = System::Windows::Forms::Padding(2);
            this->ilimFaultBoxCh1->Name = L"ilimFaultBoxCh1";
            this->ilimFaultBoxCh1->Size = System::Drawing::Size(100, 28);
            this->ilimFaultBoxCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->ilimFaultBoxCh1->TabIndex = 34;
            this->ilimFaultBoxCh1->TabStop = false;
            this->ilimFaultBoxCh1->Click += gcnew System::EventHandler(this, &ConfigurationGui::ilimFaultBoxCh1_Click);
            // 
            // ilimFaultBoxCh2
            // 
            this->ilimFaultBoxCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->ilimFaultBoxCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"ilimFaultBoxCh2.Image")));
            this->ilimFaultBoxCh2->Location = System::Drawing::Point(239, 123);
            this->ilimFaultBoxCh2->Margin = System::Windows::Forms::Padding(2);
            this->ilimFaultBoxCh2->Name = L"ilimFaultBoxCh2";
            this->ilimFaultBoxCh2->Size = System::Drawing::Size(100, 28);
            this->ilimFaultBoxCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->ilimFaultBoxCh2->TabIndex = 35;
            this->ilimFaultBoxCh2->TabStop = false;
            this->ilimFaultBoxCh2->Click += gcnew System::EventHandler(this, &ConfigurationGui::ilimFaultBoxCh2_Click);
            // 
            // ilimFaultBoxCh3
            // 
            this->ilimFaultBoxCh3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->ilimFaultBoxCh3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"ilimFaultBoxCh3.Image")));
            this->ilimFaultBoxCh3->Location = System::Drawing::Point(343, 123);
            this->ilimFaultBoxCh3->Margin = System::Windows::Forms::Padding(2);
            this->ilimFaultBoxCh3->Name = L"ilimFaultBoxCh3";
            this->ilimFaultBoxCh3->Size = System::Drawing::Size(100, 28);
            this->ilimFaultBoxCh3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->ilimFaultBoxCh3->TabIndex = 36;
            this->ilimFaultBoxCh3->TabStop = false;
            this->ilimFaultBoxCh3->Click += gcnew System::EventHandler(this, &ConfigurationGui::ilimFaultBoxCh3_Click);
            // 
            // ilimFaultBoxCh4
            // 
            this->ilimFaultBoxCh4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->ilimFaultBoxCh4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"ilimFaultBoxCh4.Image")));
            this->ilimFaultBoxCh4->Location = System::Drawing::Point(447, 123);
            this->ilimFaultBoxCh4->Margin = System::Windows::Forms::Padding(2);
            this->ilimFaultBoxCh4->Name = L"ilimFaultBoxCh4";
            this->ilimFaultBoxCh4->Size = System::Drawing::Size(100, 28);
            this->ilimFaultBoxCh4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->ilimFaultBoxCh4->TabIndex = 37;
            this->ilimFaultBoxCh4->TabStop = false;
            this->ilimFaultBoxCh4->Click += gcnew System::EventHandler(this, &ConfigurationGui::ilimFaultBoxCh4_Click);
            // 
            // label62
            // 
            this->label62->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label62->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label62->Location = System::Drawing::Point(2, 153);
            this->label62->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label62->Name = L"label62";
            this->label62->Size = System::Drawing::Size(129, 32);
            this->label62->TabIndex = 38;
            this->label62->Text = L"Thermal Shutdown:";
            this->label62->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tsdFaultBoxCh1
            // 
            this->tsdFaultBoxCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tsdFaultBoxCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tsdFaultBoxCh1.Image")));
            this->tsdFaultBoxCh1->Location = System::Drawing::Point(135, 155);
            this->tsdFaultBoxCh1->Margin = System::Windows::Forms::Padding(2);
            this->tsdFaultBoxCh1->Name = L"tsdFaultBoxCh1";
            this->tsdFaultBoxCh1->Size = System::Drawing::Size(100, 28);
            this->tsdFaultBoxCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tsdFaultBoxCh1->TabIndex = 39;
            this->tsdFaultBoxCh1->TabStop = false;
            this->tsdFaultBoxCh1->Click += gcnew System::EventHandler(this, &ConfigurationGui::tsdFaultBoxCh1_Click);
            // 
            // tsdFaultBoxCh2
            // 
            this->tsdFaultBoxCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tsdFaultBoxCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tsdFaultBoxCh2.Image")));
            this->tsdFaultBoxCh2->Location = System::Drawing::Point(239, 155);
            this->tsdFaultBoxCh2->Margin = System::Windows::Forms::Padding(2);
            this->tsdFaultBoxCh2->Name = L"tsdFaultBoxCh2";
            this->tsdFaultBoxCh2->Size = System::Drawing::Size(100, 28);
            this->tsdFaultBoxCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tsdFaultBoxCh2->TabIndex = 40;
            this->tsdFaultBoxCh2->TabStop = false;
            this->tsdFaultBoxCh2->Click += gcnew System::EventHandler(this, &ConfigurationGui::tsdFaultBoxCh2_Click);
            // 
            // tsdFaultBoxCh3
            // 
            this->tsdFaultBoxCh3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tsdFaultBoxCh3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tsdFaultBoxCh3.Image")));
            this->tsdFaultBoxCh3->Location = System::Drawing::Point(343, 155);
            this->tsdFaultBoxCh3->Margin = System::Windows::Forms::Padding(2);
            this->tsdFaultBoxCh3->Name = L"tsdFaultBoxCh3";
            this->tsdFaultBoxCh3->Size = System::Drawing::Size(100, 28);
            this->tsdFaultBoxCh3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tsdFaultBoxCh3->TabIndex = 41;
            this->tsdFaultBoxCh3->TabStop = false;
            this->tsdFaultBoxCh3->Click += gcnew System::EventHandler(this, &ConfigurationGui::tsdFaultBoxCh3_Click);
            // 
            // tsdFaultBoxCh4
            // 
            this->tsdFaultBoxCh4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tsdFaultBoxCh4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tsdFaultBoxCh4.Image")));
            this->tsdFaultBoxCh4->Location = System::Drawing::Point(447, 155);
            this->tsdFaultBoxCh4->Margin = System::Windows::Forms::Padding(2);
            this->tsdFaultBoxCh4->Name = L"tsdFaultBoxCh4";
            this->tsdFaultBoxCh4->Size = System::Drawing::Size(100, 28);
            this->tsdFaultBoxCh4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tsdFaultBoxCh4->TabIndex = 42;
            this->tsdFaultBoxCh4->TabStop = false;
            this->tsdFaultBoxCh4->Click += gcnew System::EventHandler(this, &ConfigurationGui::tsdFaultBoxCh4_Click);
            // 
            // label63
            // 
            this->label63->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label63->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label63->Location = System::Drawing::Point(2, 185);
            this->label63->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label63->Name = L"label63";
            this->label63->Size = System::Drawing::Size(129, 32);
            this->label63->TabIndex = 43;
            this->label63->Text = L"Thermal Warning:";
            this->label63->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tWarnBoxCh1
            // 
            this->tWarnBoxCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tWarnBoxCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tWarnBoxCh1.Image")));
            this->tWarnBoxCh1->Location = System::Drawing::Point(135, 187);
            this->tWarnBoxCh1->Margin = System::Windows::Forms::Padding(2);
            this->tWarnBoxCh1->Name = L"tWarnBoxCh1";
            this->tWarnBoxCh1->Size = System::Drawing::Size(100, 28);
            this->tWarnBoxCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tWarnBoxCh1->TabIndex = 44;
            this->tWarnBoxCh1->TabStop = false;
            this->tWarnBoxCh1->Click += gcnew System::EventHandler(this, &ConfigurationGui::tWarnBoxCh1_Click);
            // 
            // tWarnBoxCh2
            // 
            this->tWarnBoxCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tWarnBoxCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tWarnBoxCh2.Image")));
            this->tWarnBoxCh2->Location = System::Drawing::Point(239, 187);
            this->tWarnBoxCh2->Margin = System::Windows::Forms::Padding(2);
            this->tWarnBoxCh2->Name = L"tWarnBoxCh2";
            this->tWarnBoxCh2->Size = System::Drawing::Size(100, 28);
            this->tWarnBoxCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tWarnBoxCh2->TabIndex = 45;
            this->tWarnBoxCh2->TabStop = false;
            this->tWarnBoxCh2->Click += gcnew System::EventHandler(this, &ConfigurationGui::tWarnBoxCh2_Click);
            // 
            // tWarnBoxCh3
            // 
            this->tWarnBoxCh3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tWarnBoxCh3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tWarnBoxCh3.Image")));
            this->tWarnBoxCh3->Location = System::Drawing::Point(343, 187);
            this->tWarnBoxCh3->Margin = System::Windows::Forms::Padding(2);
            this->tWarnBoxCh3->Name = L"tWarnBoxCh3";
            this->tWarnBoxCh3->Size = System::Drawing::Size(100, 28);
            this->tWarnBoxCh3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tWarnBoxCh3->TabIndex = 46;
            this->tWarnBoxCh3->TabStop = false;
            this->tWarnBoxCh3->Click += gcnew System::EventHandler(this, &ConfigurationGui::tWarnBoxCh3_Click);
            // 
            // tWarnBoxCh4
            // 
            this->tWarnBoxCh4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tWarnBoxCh4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tWarnBoxCh4.Image")));
            this->tWarnBoxCh4->Location = System::Drawing::Point(447, 187);
            this->tWarnBoxCh4->Margin = System::Windows::Forms::Padding(2);
            this->tWarnBoxCh4->Name = L"tWarnBoxCh4";
            this->tWarnBoxCh4->Size = System::Drawing::Size(100, 28);
            this->tWarnBoxCh4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tWarnBoxCh4->TabIndex = 47;
            this->tWarnBoxCh4->TabStop = false;
            this->tWarnBoxCh4->Click += gcnew System::EventHandler(this, &ConfigurationGui::tWarnBoxCh4_Click);
            // 
            // label64
            // 
            this->label64->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label64->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label64->Location = System::Drawing::Point(2, 217);
            this->label64->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label64->Name = L"label64";
            this->label64->Size = System::Drawing::Size(129, 33);
            this->label64->TabIndex = 48;
            this->label64->Text = L"Reverse Current:";
            this->label64->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // rvsrBoxCh1
            // 
            this->rvsrBoxCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->rvsrBoxCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"rvsrBoxCh1.Image")));
            this->rvsrBoxCh1->Location = System::Drawing::Point(135, 219);
            this->rvsrBoxCh1->Margin = System::Windows::Forms::Padding(2);
            this->rvsrBoxCh1->Name = L"rvsrBoxCh1";
            this->rvsrBoxCh1->Size = System::Drawing::Size(100, 29);
            this->rvsrBoxCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->rvsrBoxCh1->TabIndex = 49;
            this->rvsrBoxCh1->TabStop = false;
            this->rvsrBoxCh1->Click += gcnew System::EventHandler(this, &ConfigurationGui::rvsrBoxCh1_Click);
            // 
            // rvsrBoxCh2
            // 
            this->rvsrBoxCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->rvsrBoxCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"rvsrBoxCh2.Image")));
            this->rvsrBoxCh2->Location = System::Drawing::Point(239, 219);
            this->rvsrBoxCh2->Margin = System::Windows::Forms::Padding(2);
            this->rvsrBoxCh2->Name = L"rvsrBoxCh2";
            this->rvsrBoxCh2->Size = System::Drawing::Size(100, 29);
            this->rvsrBoxCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->rvsrBoxCh2->TabIndex = 50;
            this->rvsrBoxCh2->TabStop = false;
            this->rvsrBoxCh2->Click += gcnew System::EventHandler(this, &ConfigurationGui::rvsrBoxCh2_Click);
            // 
            // rvsrBoxCh3
            // 
            this->rvsrBoxCh3->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->rvsrBoxCh3->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"rvsrBoxCh3.Image")));
            this->rvsrBoxCh3->Location = System::Drawing::Point(343, 219);
            this->rvsrBoxCh3->Margin = System::Windows::Forms::Padding(2);
            this->rvsrBoxCh3->Name = L"rvsrBoxCh3";
            this->rvsrBoxCh3->Size = System::Drawing::Size(100, 29);
            this->rvsrBoxCh3->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->rvsrBoxCh3->TabIndex = 51;
            this->rvsrBoxCh3->TabStop = false;
            this->rvsrBoxCh3->Click += gcnew System::EventHandler(this, &ConfigurationGui::rvsrBoxCh3_Click);
            // 
            // rvsrBoxCh4
            // 
            this->rvsrBoxCh4->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->rvsrBoxCh4->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"rvsrBoxCh4.Image")));
            this->rvsrBoxCh4->Location = System::Drawing::Point(447, 219);
            this->rvsrBoxCh4->Margin = System::Windows::Forms::Padding(2);
            this->rvsrBoxCh4->Name = L"rvsrBoxCh4";
            this->rvsrBoxCh4->Size = System::Drawing::Size(100, 29);
            this->rvsrBoxCh4->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->rvsrBoxCh4->TabIndex = 52;
            this->rvsrBoxCh4->TabStop = false;
            this->rvsrBoxCh4->Click += gcnew System::EventHandler(this, &ConfigurationGui::rvsrBoxCh4_Click);
            // 
            // groupBox9
            // 
            this->groupBox9->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Right));
            this->groupBox9->Controls->Add(this->label67);
            this->groupBox9->Controls->Add(this->label65);
            this->groupBox9->Controls->Add(this->currentFaultLabelStatus);
            this->groupBox9->Controls->Add(this->label71);
            this->groupBox9->Controls->Add(this->dateFaultLabel);
            this->groupBox9->Controls->Add(this->numberFaultLabel);
            this->groupBox9->Controls->Add(this->faultDescriptionLabel);
            this->groupBox9->Controls->Add(this->faultNameLabel);
            this->groupBox9->Controls->Add(this->label66);
            this->groupBox9->Controls->Add(this->resetStatButton);
            this->groupBox9->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->groupBox9->Location = System::Drawing::Point(573, 3);
            this->groupBox9->Margin = System::Windows::Forms::Padding(2);
            this->groupBox9->MinimumSize = System::Drawing::Size(234, 494);
            this->groupBox9->Name = L"groupBox9";
            this->groupBox9->Padding = System::Windows::Forms::Padding(2);
            this->groupBox9->Size = System::Drawing::Size(234, 494);
            this->groupBox9->TabIndex = 2;
            this->groupBox9->TabStop = false;
            this->groupBox9->Text = L"Statistics";
            // 
            // label67
            // 
            this->label67->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label67->Location = System::Drawing::Point(9, 169);
            this->label67->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label67->Name = L"label67";
            this->label67->Size = System::Drawing::Size(92, 20);
            this->label67->TabIndex = 32;
            this->label67->Text = L"Last Faulted:";
            this->label67->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // label65
            // 
            this->label65->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label65->Location = System::Drawing::Point(9, 143);
            this->label65->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label65->Name = L"label65";
            this->label65->Size = System::Drawing::Size(155, 20);
            this->label65->TabIndex = 31;
            this->label65->Text = L"Number of Times Faulted:";
            this->label65->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // currentFaultLabelStatus
            // 
            this->currentFaultLabelStatus->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->currentFaultLabelStatus->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->currentFaultLabelStatus->Location = System::Drawing::Point(103, 122);
            this->currentFaultLabelStatus->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->currentFaultLabelStatus->Name = L"currentFaultLabelStatus";
            this->currentFaultLabelStatus->Size = System::Drawing::Size(127, 17);
            this->currentFaultLabelStatus->TabIndex = 30;
            // 
            // label71
            // 
            this->label71->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label71->Location = System::Drawing::Point(9, 119);
            this->label71->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label71->Name = L"label71";
            this->label71->Size = System::Drawing::Size(104, 20);
            this->label71->TabIndex = 29;
            this->label71->Text = L"Current Status: ";
            this->label71->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // dateFaultLabel
            // 
            this->dateFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->dateFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->dateFaultLabel->Location = System::Drawing::Point(100, 172);
            this->dateFaultLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->dateFaultLabel->Name = L"dateFaultLabel";
            this->dateFaultLabel->Size = System::Drawing::Size(125, 20);
            this->dateFaultLabel->TabIndex = 28;
            // 
            // numberFaultLabel
            // 
            this->numberFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->numberFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->numberFaultLabel->Location = System::Drawing::Point(166, 144);
            this->numberFaultLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->numberFaultLabel->Name = L"numberFaultLabel";
            this->numberFaultLabel->Size = System::Drawing::Size(62, 26);
            this->numberFaultLabel->TabIndex = 27;
            // 
            // faultDescriptionLabel
            // 
            this->faultDescriptionLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultDescriptionLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->faultDescriptionLabel->Location = System::Drawing::Point(7, 68);
            this->faultDescriptionLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->faultDescriptionLabel->Name = L"faultDescriptionLabel";
            this->faultDescriptionLabel->Size = System::Drawing::Size(223, 51);
            this->faultDescriptionLabel->TabIndex = 26;
            // 
            // faultNameLabel
            // 
            this->faultNameLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->faultNameLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->faultNameLabel->Location = System::Drawing::Point(7, 18);
            this->faultNameLabel->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->faultNameLabel->Name = L"faultNameLabel";
            this->faultNameLabel->Size = System::Drawing::Size(223, 30);
            this->faultNameLabel->TabIndex = 22;
            this->faultNameLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label66
            // 
            this->label66->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label66->Location = System::Drawing::Point(8, 48);
            this->label66->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label66->Name = L"label66";
            this->label66->Size = System::Drawing::Size(83, 20);
            this->label66->TabIndex = 21;
            this->label66->Text = L"Description: ";
            this->label66->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // resetStatButton
            // 
            this->resetStatButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->resetStatButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->resetStatButton->Location = System::Drawing::Point(4, 462);
            this->resetStatButton->Margin = System::Windows::Forms::Padding(2);
            this->resetStatButton->Name = L"resetStatButton";
            this->resetStatButton->Size = System::Drawing::Size(226, 23);
            this->resetStatButton->TabIndex = 8;
            this->resetStatButton->Text = L"Reset Statistic";
            this->resetStatButton->UseVisualStyleBackColor = true;
            this->resetStatButton->Click += gcnew System::EventHandler(this, &ConfigurationGui::resetStatButton_Click);
            // 
            // groupBox8
            // 
            this->groupBox8->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->groupBox8->Controls->Add(this->tableLayoutPanel6);
            this->groupBox8->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->groupBox8->Location = System::Drawing::Point(1, 3);
            this->groupBox8->Margin = System::Windows::Forms::Padding(2);
            this->groupBox8->Name = L"groupBox8";
            this->groupBox8->Padding = System::Windows::Forms::Padding(2);
            this->groupBox8->Size = System::Drawing::Size(568, 92);
            this->groupBox8->TabIndex = 1;
            this->groupBox8->TabStop = false;
            this->groupBox8->Text = L"Global Faults";
            // 
            // tableLayoutPanel6
            // 
            this->tableLayoutPanel6->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tableLayoutPanel6->ColumnCount = 7;
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                14.28571F)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                14.28571F)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                14.28571F)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                14.28571F)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                14.28571F)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                14.28571F)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                14.28571F)));
            this->tableLayoutPanel6->Controls->Add(this->label53, 0, 1);
            this->tableLayoutPanel6->Controls->Add(this->porFaultBox, 0, 0);
            this->tableLayoutPanel6->Controls->Add(this->thermalFaultBox, 1, 0);
            this->tableLayoutPanel6->Controls->Add(this->spiFaultBox, 2, 0);
            this->tableLayoutPanel6->Controls->Add(this->label49, 2, 1);
            this->tableLayoutPanel6->Controls->Add(this->label50, 2, 1);
            this->tableLayoutPanel6->Controls->Add(this->label47, 1, 1);
            this->tableLayoutPanel6->Controls->Add(this->wdtFaultBox, 3, 0);
            this->tableLayoutPanel6->Controls->Add(this->vddUVFaultBox, 4, 0);
            this->tableLayoutPanel6->Controls->Add(this->label51, 4, 1);
            this->tableLayoutPanel6->Controls->Add(this->uvWarnBox, 5, 0);
            this->tableLayoutPanel6->Controls->Add(this->label52, 5, 1);
            this->tableLayoutPanel6->Controls->Add(this->uvFaultBox, 6, 0);
            this->tableLayoutPanel6->Controls->Add(this->label48, 6, 1);
            this->tableLayoutPanel6->Location = System::Drawing::Point(4, 16);
            this->tableLayoutPanel6->Margin = System::Windows::Forms::Padding(2);
            this->tableLayoutPanel6->Name = L"tableLayoutPanel6";
            this->tableLayoutPanel6->RowCount = 2;
            this->tableLayoutPanel6->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 50)));
            this->tableLayoutPanel6->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 50)));
            this->tableLayoutPanel6->Size = System::Drawing::Size(559, 66);
            this->tableLayoutPanel6->TabIndex = 0;
            // 
            // label53
            // 
            this->label53->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label53->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label53->Location = System::Drawing::Point(13, 33);
            this->label53->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label53->Name = L"label53";
            this->label53->Size = System::Drawing::Size(53, 33);
            this->label53->TabIndex = 17;
            this->label53->Text = L"POR";
            this->label53->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // porFaultBox
            // 
            this->porFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->porFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"porFaultBox.Image")));
            this->porFaultBox->Location = System::Drawing::Point(2, 2);
            this->porFaultBox->Margin = System::Windows::Forms::Padding(2);
            this->porFaultBox->Name = L"porFaultBox";
            this->porFaultBox->Size = System::Drawing::Size(75, 29);
            this->porFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->porFaultBox->TabIndex = 5;
            this->porFaultBox->TabStop = false;
            this->porFaultBox->Click += gcnew System::EventHandler(this, &ConfigurationGui::porFaultBox_Click);
            // 
            // thermalFaultBox
            // 
            this->thermalFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->thermalFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"thermalFaultBox.Image")));
            this->thermalFaultBox->Location = System::Drawing::Point(81, 2);
            this->thermalFaultBox->Margin = System::Windows::Forms::Padding(2);
            this->thermalFaultBox->Name = L"thermalFaultBox";
            this->thermalFaultBox->Size = System::Drawing::Size(75, 29);
            this->thermalFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->thermalFaultBox->TabIndex = 7;
            this->thermalFaultBox->TabStop = false;
            this->thermalFaultBox->Click += gcnew System::EventHandler(this, &ConfigurationGui::thermalFaultBox_Click);
            // 
            // spiFaultBox
            // 
            this->spiFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->spiFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"spiFaultBox.Image")));
            this->spiFaultBox->Location = System::Drawing::Point(160, 2);
            this->spiFaultBox->Margin = System::Windows::Forms::Padding(2);
            this->spiFaultBox->Name = L"spiFaultBox";
            this->spiFaultBox->Size = System::Drawing::Size(75, 29);
            this->spiFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->spiFaultBox->TabIndex = 8;
            this->spiFaultBox->TabStop = false;
            this->spiFaultBox->Click += gcnew System::EventHandler(this, &ConfigurationGui::spiFaultBox_Click);
            // 
            // label49
            // 
            this->label49->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label49->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label49->Location = System::Drawing::Point(160, 33);
            this->label49->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label49->Name = L"label49";
            this->label49->Size = System::Drawing::Size(75, 33);
            this->label49->TabIndex = 9;
            this->label49->Text = L"SPI Error";
            this->label49->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label50
            // 
            this->label50->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label50->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label50->Location = System::Drawing::Point(239, 33);
            this->label50->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label50->Name = L"label50";
            this->label50->Size = System::Drawing::Size(75, 33);
            this->label50->TabIndex = 10;
            this->label50->Text = L"Watchdog Error";
            this->label50->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label47
            // 
            this->label47->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label47->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label47->Location = System::Drawing::Point(81, 33);
            this->label47->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label47->Name = L"label47";
            this->label47->Size = System::Drawing::Size(75, 33);
            this->label47->TabIndex = 4;
            this->label47->Text = L"Thermal Warning";
            this->label47->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // wdtFaultBox
            // 
            this->wdtFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wdtFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wdtFaultBox.Image")));
            this->wdtFaultBox->Location = System::Drawing::Point(239, 2);
            this->wdtFaultBox->Margin = System::Windows::Forms::Padding(2);
            this->wdtFaultBox->Name = L"wdtFaultBox";
            this->wdtFaultBox->Size = System::Drawing::Size(75, 29);
            this->wdtFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wdtFaultBox->TabIndex = 11;
            this->wdtFaultBox->TabStop = false;
            this->wdtFaultBox->Click += gcnew System::EventHandler(this, &ConfigurationGui::wdtFaultBox_Click);
            // 
            // vddUVFaultBox
            // 
            this->vddUVFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->vddUVFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"vddUVFaultBox.Image")));
            this->vddUVFaultBox->Location = System::Drawing::Point(318, 2);
            this->vddUVFaultBox->Margin = System::Windows::Forms::Padding(2);
            this->vddUVFaultBox->Name = L"vddUVFaultBox";
            this->vddUVFaultBox->Size = System::Drawing::Size(75, 29);
            this->vddUVFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->vddUVFaultBox->TabIndex = 12;
            this->vddUVFaultBox->TabStop = false;
            this->vddUVFaultBox->Click += gcnew System::EventHandler(this, &ConfigurationGui::vddUVFaultBox_Click);
            // 
            // label51
            // 
            this->label51->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label51->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label51->Location = System::Drawing::Point(318, 33);
            this->label51->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label51->Name = L"label51";
            this->label51->Size = System::Drawing::Size(75, 33);
            this->label51->TabIndex = 13;
            this->label51->Text = L"VDD UVLO";
            this->label51->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // uvWarnBox
            // 
            this->uvWarnBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->uvWarnBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"uvWarnBox.Image")));
            this->uvWarnBox->Location = System::Drawing::Point(397, 2);
            this->uvWarnBox->Margin = System::Windows::Forms::Padding(2);
            this->uvWarnBox->Name = L"uvWarnBox";
            this->uvWarnBox->Size = System::Drawing::Size(75, 29);
            this->uvWarnBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->uvWarnBox->TabIndex = 14;
            this->uvWarnBox->TabStop = false;
            this->uvWarnBox->Click += gcnew System::EventHandler(this, &ConfigurationGui::uvWarnBox_Click);
            // 
            // label52
            // 
            this->label52->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label52->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label52->Location = System::Drawing::Point(397, 33);
            this->label52->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label52->Name = L"label52";
            this->label52->Size = System::Drawing::Size(75, 33);
            this->label52->TabIndex = 15;
            this->label52->Text = L"Undervoltage Warning";
            this->label52->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // uvFaultBox
            // 
            this->uvFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->uvFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"uvFaultBox.Image")));
            this->uvFaultBox->Location = System::Drawing::Point(476, 2);
            this->uvFaultBox->Margin = System::Windows::Forms::Padding(2);
            this->uvFaultBox->Name = L"uvFaultBox";
            this->uvFaultBox->Size = System::Drawing::Size(81, 29);
            this->uvFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->uvFaultBox->TabIndex = 16;
            this->uvFaultBox->TabStop = false;
            this->uvFaultBox->Click += gcnew System::EventHandler(this, &ConfigurationGui::uvFaultBox_Click);
            // 
            // label48
            // 
            this->label48->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->label48->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label48->Location = System::Drawing::Point(477, 33);
            this->label48->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label48->Name = L"label48";
            this->label48->Size = System::Drawing::Size(79, 33);
            this->label48->TabIndex = 6;
            this->label48->Text = L"Undervoltage Fault";
            this->label48->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tabPage2
            // 
            this->tabPage2->Controls->Add(this->groupBox7);
            this->tabPage2->Controls->Add(this->groupBox6);
            this->tabPage2->Controls->Add(this->groupBox5);
            this->tabPage2->Controls->Add(this->groupBox4);
            this->tabPage2->Location = System::Drawing::Point(4, 22);
            this->tabPage2->Margin = System::Windows::Forms::Padding(2);
            this->tabPage2->Name = L"tabPage2";
            this->tabPage2->Padding = System::Windows::Forms::Padding(2);
            this->tabPage2->Size = System::Drawing::Size(807, 497);
            this->tabPage2->TabIndex = 1;
            this->tabPage2->Text = L"Device Settings";
            this->tabPage2->UseVisualStyleBackColor = true;
            // 
            // groupBox7
            // 
            this->groupBox7->Controls->Add(this->label39);
            this->groupBox7->Controls->Add(this->adcTempEanableBox);
            this->groupBox7->Controls->Add(this->adcOutVoltageEnableBox);
            this->groupBox7->Controls->Add(this->adcInVoltageEnableBox);
            this->groupBox7->Controls->Add(this->adcCurEnableBox);
            this->groupBox7->Controls->Add(this->label41);
            this->groupBox7->Controls->Add(this->adcEnableBox);
            this->groupBox7->Controls->Add(this->curDisBox1);
            this->groupBox7->Controls->Add(this->curDisBox2);
            this->groupBox7->Controls->Add(this->label38);
            this->groupBox7->Controls->Add(this->curDisBox3);
            this->groupBox7->Controls->Add(this->curDisBox4);
            this->groupBox7->Controls->Add(this->voutDisBox1);
            this->groupBox7->Controls->Add(this->voutDisBox2);
            this->groupBox7->Controls->Add(this->label37);
            this->groupBox7->Controls->Add(this->voutDisBox3);
            this->groupBox7->Controls->Add(this->voutDisBox4);
            this->groupBox7->Controls->Add(this->tsnsDisBox1);
            this->groupBox7->Controls->Add(this->tsnsDisBox2);
            this->groupBox7->Controls->Add(this->label36);
            this->groupBox7->Controls->Add(this->tsnsDisBox3);
            this->groupBox7->Controls->Add(this->tsnsDisBox4);
            this->groupBox7->Controls->Add(this->label35);
            this->groupBox7->Controls->Add(this->greater800mABox);
            this->groupBox7->Controls->Add(this->less800mABox);
            this->groupBox7->Controls->Add(this->label44);
            this->groupBox7->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->groupBox7->Location = System::Drawing::Point(350, 317);
            this->groupBox7->Name = L"groupBox7";
            this->groupBox7->Size = System::Drawing::Size(452, 175);
            this->groupBox7->TabIndex = 66;
            this->groupBox7->TabStop = false;
            this->groupBox7->Text = L"Sensing";
            // 
            // label39
            // 
            this->label39->AutoSize = true;
            this->label39->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label39->Location = System::Drawing::Point(6, 46);
            this->label39->Name = L"label39";
            this->label39->Size = System::Drawing::Size(102, 13);
            this->label39->TabIndex = 130;
            this->label39->Text = L"Conversion Enable: ";
            // 
            // adcTempEanableBox
            // 
            this->adcTempEanableBox->AutoSize = true;
            this->adcTempEanableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->adcTempEanableBox->Location = System::Drawing::Point(350, 46);
            this->adcTempEanableBox->Name = L"adcTempEanableBox";
            this->adcTempEanableBox->Size = System::Drawing::Size(86, 17);
            this->adcTempEanableBox->TabIndex = 129;
            this->adcTempEanableBox->Text = L"Temperature";
            this->adcTempEanableBox->UseVisualStyleBackColor = true;
            this->adcTempEanableBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::adcTempEanableBox_CheckedChanged);
            // 
            // adcOutVoltageEnableBox
            // 
            this->adcOutVoltageEnableBox->AutoSize = true;
            this->adcOutVoltageEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->adcOutVoltageEnableBox->Location = System::Drawing::Point(260, 46);
            this->adcOutVoltageEnableBox->Name = L"adcOutVoltageEnableBox";
            this->adcOutVoltageEnableBox->Size = System::Drawing::Size(82, 17);
            this->adcOutVoltageEnableBox->TabIndex = 128;
            this->adcOutVoltageEnableBox->Text = L"Out Voltage";
            this->adcOutVoltageEnableBox->UseVisualStyleBackColor = true;
            this->adcOutVoltageEnableBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::adcOutVoltageEnableBox_CheckedChanged);
            // 
            // adcInVoltageEnableBox
            // 
            this->adcInVoltageEnableBox->AutoSize = true;
            this->adcInVoltageEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->adcInVoltageEnableBox->Location = System::Drawing::Point(180, 46);
            this->adcInVoltageEnableBox->Name = L"adcInVoltageEnableBox";
            this->adcInVoltageEnableBox->Size = System::Drawing::Size(74, 17);
            this->adcInVoltageEnableBox->TabIndex = 127;
            this->adcInVoltageEnableBox->Text = L"In Voltage";
            this->adcInVoltageEnableBox->UseVisualStyleBackColor = true;
            this->adcInVoltageEnableBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::adcInVoltageEnableBox_CheckedChanged);
            // 
            // adcCurEnableBox
            // 
            this->adcCurEnableBox->AutoSize = true;
            this->adcCurEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->adcCurEnableBox->Location = System::Drawing::Point(114, 46);
            this->adcCurEnableBox->Name = L"adcCurEnableBox";
            this->adcCurEnableBox->Size = System::Drawing::Size(60, 17);
            this->adcCurEnableBox->TabIndex = 126;
            this->adcCurEnableBox->Text = L"Current";
            this->adcCurEnableBox->UseVisualStyleBackColor = true;
            this->adcCurEnableBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::adcCurEnableBox_CheckedChanged);
            // 
            // label41
            // 
            this->label41->AutoSize = true;
            this->label41->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label41->Location = System::Drawing::Point(6, 23);
            this->label41->Name = L"label41";
            this->label41->Size = System::Drawing::Size(68, 13);
            this->label41->TabIndex = 125;
            this->label41->Text = L"ADC Enable:";
            // 
            // adcEnableBox
            // 
            this->adcEnableBox->AutoSize = true;
            this->adcEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->adcEnableBox->Location = System::Drawing::Point(81, 23);
            this->adcEnableBox->Name = L"adcEnableBox";
            this->adcEnableBox->Size = System::Drawing::Size(15, 14);
            this->adcEnableBox->TabIndex = 124;
            this->adcEnableBox->UseVisualStyleBackColor = true;
            this->adcEnableBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::adcEnableBox_CheckedChanged);
            // 
            // curDisBox1
            // 
            this->curDisBox1->AutoSize = true;
            this->curDisBox1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->curDisBox1->Location = System::Drawing::Point(130, 151);
            this->curDisBox1->Name = L"curDisBox1";
            this->curDisBox1->Size = System::Drawing::Size(32, 17);
            this->curDisBox1->TabIndex = 121;
            this->curDisBox1->Text = L"1";
            this->curDisBox1->UseVisualStyleBackColor = true;
            this->curDisBox1->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::curDisBox1_CheckedChanged);
            // 
            // curDisBox2
            // 
            this->curDisBox2->AutoSize = true;
            this->curDisBox2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->curDisBox2->Location = System::Drawing::Point(168, 151);
            this->curDisBox2->Name = L"curDisBox2";
            this->curDisBox2->Size = System::Drawing::Size(32, 17);
            this->curDisBox2->TabIndex = 120;
            this->curDisBox2->Text = L"2";
            this->curDisBox2->UseVisualStyleBackColor = true;
            this->curDisBox2->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::curDisBox2_CheckedChanged);
            // 
            // label38
            // 
            this->label38->AutoSize = true;
            this->label38->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label38->Location = System::Drawing::Point(6, 151);
            this->label38->Name = L"label38";
            this->label38->Size = System::Drawing::Size(71, 13);
            this->label38->TabIndex = 117;
            this->label38->Text = L"Load Current:";
            // 
            // curDisBox3
            // 
            this->curDisBox3->AutoSize = true;
            this->curDisBox3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->curDisBox3->Location = System::Drawing::Point(206, 151);
            this->curDisBox3->Name = L"curDisBox3";
            this->curDisBox3->Size = System::Drawing::Size(32, 17);
            this->curDisBox3->TabIndex = 119;
            this->curDisBox3->Text = L"3";
            this->curDisBox3->UseVisualStyleBackColor = true;
            this->curDisBox3->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::curDisBox3_CheckedChanged);
            // 
            // curDisBox4
            // 
            this->curDisBox4->AutoSize = true;
            this->curDisBox4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->curDisBox4->Location = System::Drawing::Point(244, 151);
            this->curDisBox4->Name = L"curDisBox4";
            this->curDisBox4->Size = System::Drawing::Size(32, 17);
            this->curDisBox4->TabIndex = 118;
            this->curDisBox4->Text = L"4";
            this->curDisBox4->UseVisualStyleBackColor = true;
            this->curDisBox4->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::curDisBox4_CheckedChanged);
            // 
            // voutDisBox1
            // 
            this->voutDisBox1->AutoSize = true;
            this->voutDisBox1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->voutDisBox1->Location = System::Drawing::Point(130, 130);
            this->voutDisBox1->Name = L"voutDisBox1";
            this->voutDisBox1->Size = System::Drawing::Size(32, 17);
            this->voutDisBox1->TabIndex = 116;
            this->voutDisBox1->Text = L"1";
            this->voutDisBox1->UseVisualStyleBackColor = true;
            this->voutDisBox1->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::voutDisBox1_CheckedChanged);
            // 
            // voutDisBox2
            // 
            this->voutDisBox2->AutoSize = true;
            this->voutDisBox2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->voutDisBox2->Location = System::Drawing::Point(168, 130);
            this->voutDisBox2->Name = L"voutDisBox2";
            this->voutDisBox2->Size = System::Drawing::Size(32, 17);
            this->voutDisBox2->TabIndex = 115;
            this->voutDisBox2->Text = L"2";
            this->voutDisBox2->UseVisualStyleBackColor = true;
            this->voutDisBox2->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::voutDisBox2_CheckedChanged);
            // 
            // label37
            // 
            this->label37->AutoSize = true;
            this->label37->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label37->Location = System::Drawing::Point(6, 130);
            this->label37->Name = L"label37";
            this->label37->Size = System::Drawing::Size(81, 13);
            this->label37->TabIndex = 112;
            this->label37->Text = L"Output Voltage:";
            // 
            // voutDisBox3
            // 
            this->voutDisBox3->AutoSize = true;
            this->voutDisBox3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->voutDisBox3->Location = System::Drawing::Point(206, 130);
            this->voutDisBox3->Name = L"voutDisBox3";
            this->voutDisBox3->Size = System::Drawing::Size(32, 17);
            this->voutDisBox3->TabIndex = 114;
            this->voutDisBox3->Text = L"3";
            this->voutDisBox3->UseVisualStyleBackColor = true;
            this->voutDisBox3->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::voutDisBox3_CheckedChanged);
            // 
            // voutDisBox4
            // 
            this->voutDisBox4->AutoSize = true;
            this->voutDisBox4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->voutDisBox4->Location = System::Drawing::Point(244, 130);
            this->voutDisBox4->Name = L"voutDisBox4";
            this->voutDisBox4->Size = System::Drawing::Size(32, 17);
            this->voutDisBox4->TabIndex = 113;
            this->voutDisBox4->Text = L"4";
            this->voutDisBox4->UseVisualStyleBackColor = true;
            this->voutDisBox4->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::voutDisBox4_CheckedChanged);
            // 
            // tsnsDisBox1
            // 
            this->tsnsDisBox1->AutoSize = true;
            this->tsnsDisBox1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->tsnsDisBox1->Location = System::Drawing::Point(130, 109);
            this->tsnsDisBox1->Name = L"tsnsDisBox1";
            this->tsnsDisBox1->Size = System::Drawing::Size(32, 17);
            this->tsnsDisBox1->TabIndex = 111;
            this->tsnsDisBox1->Text = L"1";
            this->tsnsDisBox1->UseVisualStyleBackColor = true;
            this->tsnsDisBox1->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::tsnsDisBox1_CheckedChanged);
            // 
            // tsnsDisBox2
            // 
            this->tsnsDisBox2->AutoSize = true;
            this->tsnsDisBox2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->tsnsDisBox2->Location = System::Drawing::Point(168, 109);
            this->tsnsDisBox2->Name = L"tsnsDisBox2";
            this->tsnsDisBox2->Size = System::Drawing::Size(32, 17);
            this->tsnsDisBox2->TabIndex = 110;
            this->tsnsDisBox2->Text = L"2";
            this->tsnsDisBox2->UseVisualStyleBackColor = true;
            this->tsnsDisBox2->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::tsnsDisBox2_CheckedChanged);
            // 
            // label36
            // 
            this->label36->AutoSize = true;
            this->label36->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label36->Location = System::Drawing::Point(6, 110);
            this->label36->Name = L"label36";
            this->label36->Size = System::Drawing::Size(113, 13);
            this->label36->TabIndex = 107;
            this->label36->Text = L"Junction Temperature:";
            // 
            // tsnsDisBox3
            // 
            this->tsnsDisBox3->AutoSize = true;
            this->tsnsDisBox3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->tsnsDisBox3->Location = System::Drawing::Point(206, 109);
            this->tsnsDisBox3->Name = L"tsnsDisBox3";
            this->tsnsDisBox3->Size = System::Drawing::Size(32, 17);
            this->tsnsDisBox3->TabIndex = 109;
            this->tsnsDisBox3->Text = L"3";
            this->tsnsDisBox3->UseVisualStyleBackColor = true;
            this->tsnsDisBox3->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::tsnsDisBox3_CheckedChanged);
            // 
            // tsnsDisBox4
            // 
            this->tsnsDisBox4->AutoSize = true;
            this->tsnsDisBox4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->tsnsDisBox4->Location = System::Drawing::Point(244, 109);
            this->tsnsDisBox4->Name = L"tsnsDisBox4";
            this->tsnsDisBox4->Size = System::Drawing::Size(32, 17);
            this->tsnsDisBox4->TabIndex = 108;
            this->tsnsDisBox4->Text = L"4";
            this->tsnsDisBox4->UseVisualStyleBackColor = true;
            this->tsnsDisBox4->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::tsnsDisBox4_CheckedChanged);
            // 
            // label35
            // 
            this->label35->AutoSize = true;
            this->label35->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label35->Location = System::Drawing::Point(4, 90);
            this->label35->Name = L"label35";
            this->label35->Size = System::Drawing::Size(96, 13);
            this->label35->TabIndex = 106;
            this->label35->Text = L"Sense Sources:";
            // 
            // greater800mABox
            // 
            this->greater800mABox->AutoSize = true;
            this->greater800mABox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->greater800mABox->Location = System::Drawing::Point(201, 71);
            this->greater800mABox->Name = L"greater800mABox";
            this->greater800mABox->Size = System::Drawing::Size(67, 17);
            this->greater800mABox->TabIndex = 54;
            this->greater800mABox->TabStop = true;
            this->greater800mABox->Text = L"> 800mA";
            this->greater800mABox->UseVisualStyleBackColor = true;
            // 
            // less800mABox
            // 
            this->less800mABox->AutoSize = true;
            this->less800mABox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->less800mABox->Location = System::Drawing::Point(122, 71);
            this->less800mABox->Name = L"less800mABox";
            this->less800mABox->Size = System::Drawing::Size(73, 17);
            this->less800mABox->TabIndex = 53;
            this->less800mABox->TabStop = true;
            this->less800mABox->Text = L"<= 800mA";
            this->less800mABox->UseVisualStyleBackColor = true;
            this->less800mABox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::less800mABox_CheckedChanged);
            // 
            // label44
            // 
            this->label44->AutoSize = true;
            this->label44->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label44->Location = System::Drawing::Point(4, 71);
            this->label44->Name = L"label44";
            this->label44->Size = System::Drawing::Size(112, 13);
            this->label44->TabIndex = 52;
            this->label44->Text = L"Current Sense Range:";
            // 
            // groupBox6
            // 
            this->groupBox6->Controls->Add(this->keepStateBox1);
            this->groupBox6->Controls->Add(this->keepStateBox2);
            this->groupBox6->Controls->Add(this->keepStateBox3);
            this->groupBox6->Controls->Add(this->keepStateBox4);
            this->groupBox6->Controls->Add(this->label45);
            this->groupBox6->Controls->Add(this->fsKeepBox);
            this->groupBox6->Controls->Add(this->label43);
            this->groupBox6->Controls->Add(this->retryRadioButton);
            this->groupBox6->Controls->Add(this->latchRadioButton);
            this->groupBox6->Controls->Add(this->label42);
            this->groupBox6->Controls->Add(this->wbBlankBox);
            this->groupBox6->Controls->Add(this->label40);
            this->groupBox6->Controls->Add(this->rc1Box);
            this->groupBox6->Controls->Add(this->rc2Box);
            this->groupBox6->Controls->Add(this->rc3Box);
            this->groupBox6->Controls->Add(this->rc4Box);
            this->groupBox6->Controls->Add(this->label30);
            this->groupBox6->Controls->Add(this->latchDisableBox);
            this->groupBox6->Controls->Add(this->label29);
            this->groupBox6->Controls->Add(this->wbOnThreshBox);
            this->groupBox6->Controls->Add(this->label28);
            this->groupBox6->Controls->Add(this->rcbCheckBox);
            this->groupBox6->Controls->Add(this->label27);
            this->groupBox6->Controls->Add(this->label25);
            this->groupBox6->Controls->Add(this->wdTimeoutDurationBox);
            this->groupBox6->Controls->Add(this->wdEnableBox);
            this->groupBox6->Controls->Add(this->label24);
            this->groupBox6->Controls->Add(this->parallel34CheckBox);
            this->groupBox6->Controls->Add(this->parallel12CheckBox);
            this->groupBox6->Controls->Add(this->wbOffCurrrentBox);
            this->groupBox6->Controls->Add(this->label23);
            this->groupBox6->Controls->Add(this->label22);
            this->groupBox6->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->groupBox6->Location = System::Drawing::Point(350, 6);
            this->groupBox6->Name = L"groupBox6";
            this->groupBox6->Size = System::Drawing::Size(452, 310);
            this->groupBox6->TabIndex = 2;
            this->groupBox6->TabStop = false;
            this->groupBox6->Text = L"Device Settings";
            // 
            // keepStateBox1
            // 
            this->keepStateBox1->AutoSize = true;
            this->keepStateBox1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->keepStateBox1->Location = System::Drawing::Point(179, 206);
            this->keepStateBox1->Name = L"keepStateBox1";
            this->keepStateBox1->Size = System::Drawing::Size(32, 17);
            this->keepStateBox1->TabIndex = 77;
            this->keepStateBox1->Text = L"1";
            this->keepStateBox1->UseVisualStyleBackColor = true;
            this->keepStateBox1->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::keepStateBox1_CheckedChanged);
            // 
            // keepStateBox2
            // 
            this->keepStateBox2->AutoSize = true;
            this->keepStateBox2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->keepStateBox2->Location = System::Drawing::Point(217, 206);
            this->keepStateBox2->Name = L"keepStateBox2";
            this->keepStateBox2->Size = System::Drawing::Size(32, 17);
            this->keepStateBox2->TabIndex = 76;
            this->keepStateBox2->Text = L"2";
            this->keepStateBox2->UseVisualStyleBackColor = true;
            this->keepStateBox2->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::keepStateBox2_CheckedChanged);
            // 
            // keepStateBox3
            // 
            this->keepStateBox3->AutoSize = true;
            this->keepStateBox3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->keepStateBox3->Location = System::Drawing::Point(255, 206);
            this->keepStateBox3->Name = L"keepStateBox3";
            this->keepStateBox3->Size = System::Drawing::Size(32, 17);
            this->keepStateBox3->TabIndex = 75;
            this->keepStateBox3->Text = L"3";
            this->keepStateBox3->UseVisualStyleBackColor = true;
            this->keepStateBox3->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::keepStateBox3_CheckedChanged);
            // 
            // keepStateBox4
            // 
            this->keepStateBox4->AutoSize = true;
            this->keepStateBox4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->keepStateBox4->Location = System::Drawing::Point(293, 206);
            this->keepStateBox4->Name = L"keepStateBox4";
            this->keepStateBox4->Size = System::Drawing::Size(32, 17);
            this->keepStateBox4->TabIndex = 74;
            this->keepStateBox4->Text = L"4";
            this->keepStateBox4->UseVisualStyleBackColor = true;
            this->keepStateBox4->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::keepStateBox4_CheckedChanged);
            // 
            // label45
            // 
            this->label45->AutoSize = true;
            this->label45->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label45->Location = System::Drawing::Point(6, 206);
            this->label45->Name = L"label45";
            this->label45->Size = System::Drawing::Size(167, 13);
            this->label45->TabIndex = 73;
            this->label45->Text = L"Default Watchdog Channel State:";
            // 
            // fsKeepBox
            // 
            this->fsKeepBox->AutoSize = true;
            this->fsKeepBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->fsKeepBox->Location = System::Drawing::Point(124, 184);
            this->fsKeepBox->Name = L"fsKeepBox";
            this->fsKeepBox->Size = System::Drawing::Size(59, 17);
            this->fsKeepBox->TabIndex = 72;
            this->fsKeepBox->Text = L"Enable";
            this->fsKeepBox->UseVisualStyleBackColor = true;
            this->fsKeepBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::fsKeepBox_CheckedChanged);
            // 
            // label43
            // 
            this->label43->AutoSize = true;
            this->label43->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label43->Location = System::Drawing::Point(6, 184);
            this->label43->Name = L"label43";
            this->label43->Size = System::Drawing::Size(116, 13);
            this->label43->TabIndex = 71;
            this->label43->Text = L"Watchdog State Keep:";
            // 
            // retryRadioButton
            // 
            this->retryRadioButton->AutoSize = true;
            this->retryRadioButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->retryRadioButton->Location = System::Drawing::Point(272, 108);
            this->retryRadioButton->Name = L"retryRadioButton";
            this->retryRadioButton->Size = System::Drawing::Size(75, 17);
            this->retryRadioButton->TabIndex = 70;
            this->retryRadioButton->TabStop = true;
            this->retryRadioButton->Text = L"Auto-Retry";
            this->retryRadioButton->UseVisualStyleBackColor = true;
            // 
            // latchRadioButton
            // 
            this->latchRadioButton->AutoSize = true;
            this->latchRadioButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->latchRadioButton->Location = System::Drawing::Point(193, 108);
            this->latchRadioButton->Name = L"latchRadioButton";
            this->latchRadioButton->Size = System::Drawing::Size(64, 17);
            this->latchRadioButton->TabIndex = 69;
            this->latchRadioButton->TabStop = true;
            this->latchRadioButton->Text = L"Latched";
            this->latchRadioButton->UseVisualStyleBackColor = true;
            this->latchRadioButton->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::latchRadioButton_CheckedChanged);
            // 
            // label42
            // 
            this->label42->AutoSize = true;
            this->label42->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label42->Location = System::Drawing::Point(6, 108);
            this->label42->Name = L"label42";
            this->label42->Size = System::Drawing::Size(130, 13);
            this->label42->TabIndex = 68;
            this->label42->Text = L"Thermal Shutdown Retry: ";
            // 
            // wbBlankBox
            // 
            this->wbBlankBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbBlankBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbBlankBox->FormattingEnabled = true;
            this->wbBlankBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"0.4ms", L"1.0ms", L"2.0ms", L"4.0ms" });
            this->wbBlankBox->Location = System::Drawing::Point(193, 76);
            this->wbBlankBox->Name = L"wbBlankBox";
            this->wbBlankBox->Size = System::Drawing::Size(253, 21);
            this->wbBlankBox->TabIndex = 67;
            this->wbBlankBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbBlankBox_SelectedIndexChanged);
            // 
            // label40
            // 
            this->label40->AutoSize = true;
            this->label40->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label40->Location = System::Drawing::Point(6, 78);
            this->label40->Name = L"label40";
            this->label40->Size = System::Drawing::Size(133, 13);
            this->label40->TabIndex = 66;
            this->label40->Text = L"Wire Break Blanking Time:";
            // 
            // rc1Box
            // 
            this->rc1Box->AutoSize = true;
            this->rc1Box->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->rc1Box->Location = System::Drawing::Point(224, 254);
            this->rc1Box->Name = L"rc1Box";
            this->rc1Box->Size = System::Drawing::Size(32, 17);
            this->rc1Box->TabIndex = 65;
            this->rc1Box->Text = L"1";
            this->rc1Box->UseVisualStyleBackColor = true;
            this->rc1Box->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::rc1Box_CheckedChanged);
            // 
            // rc2Box
            // 
            this->rc2Box->AutoSize = true;
            this->rc2Box->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->rc2Box->Location = System::Drawing::Point(262, 254);
            this->rc2Box->Name = L"rc2Box";
            this->rc2Box->Size = System::Drawing::Size(32, 17);
            this->rc2Box->TabIndex = 64;
            this->rc2Box->Text = L"2";
            this->rc2Box->UseVisualStyleBackColor = true;
            this->rc2Box->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::rc2Box_CheckedChanged);
            // 
            // rc3Box
            // 
            this->rc3Box->AutoSize = true;
            this->rc3Box->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->rc3Box->Location = System::Drawing::Point(300, 254);
            this->rc3Box->Name = L"rc3Box";
            this->rc3Box->Size = System::Drawing::Size(32, 17);
            this->rc3Box->TabIndex = 63;
            this->rc3Box->Text = L"3";
            this->rc3Box->UseVisualStyleBackColor = true;
            this->rc3Box->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::rc3Box_CheckedChanged);
            // 
            // rc4Box
            // 
            this->rc4Box->AutoSize = true;
            this->rc4Box->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->rc4Box->Location = System::Drawing::Point(338, 254);
            this->rc4Box->Name = L"rc4Box";
            this->rc4Box->Size = System::Drawing::Size(32, 17);
            this->rc4Box->TabIndex = 62;
            this->rc4Box->Text = L"4";
            this->rc4Box->UseVisualStyleBackColor = true;
            this->rc4Box->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::rc4Box_CheckedChanged);
            // 
            // label30
            // 
            this->label30->AutoSize = true;
            this->label30->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label30->Location = System::Drawing::Point(6, 254);
            this->label30->Name = L"label30";
            this->label30->Size = System::Drawing::Size(209, 13);
            this->label30->TabIndex = 61;
            this->label30->Text = L"Reverse Current Blocking Channel Enable:";
            // 
            // latchDisableBox
            // 
            this->latchDisableBox->AutoSize = true;
            this->latchDisableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->latchDisableBox->Location = System::Drawing::Point(103, 278);
            this->latchDisableBox->Name = L"latchDisableBox";
            this->latchDisableBox->Size = System::Drawing::Size(65, 17);
            this->latchDisableBox->TabIndex = 60;
            this->latchDisableBox->Text = L"Enabled";
            this->latchDisableBox->UseVisualStyleBackColor = true;
            this->latchDisableBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::latchDisableBox_CheckedChanged);
            // 
            // label29
            // 
            this->label29->AutoSize = true;
            this->label29->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label29->Location = System::Drawing::Point(6, 278);
            this->label29->Name = L"label29";
            this->label29->Size = System::Drawing::Size(95, 13);
            this->label29->TabIndex = 59;
            this->label29->Text = L"Fault Bit Latching: ";
            // 
            // wbOnThreshBox
            // 
            this->wbOnThreshBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOnThreshBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOnThreshBox->FormattingEnabled = true;
            this->wbOnThreshBox->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"0.32mA", L"0.62mA", L"0.96mA", L"1.28mA",
                    L"1.60mA", L"1.92mA", L"2.24mA", L"2.56mA"
            });
            this->wbOnThreshBox->Location = System::Drawing::Point(193, 47);
            this->wbOnThreshBox->Name = L"wbOnThreshBox";
            this->wbOnThreshBox->Size = System::Drawing::Size(253, 21);
            this->wbOnThreshBox->TabIndex = 58;
            this->wbOnThreshBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOnThreshBox_SelectedIndexChanged);
            // 
            // label28
            // 
            this->label28->AutoSize = true;
            this->label28->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label28->Location = System::Drawing::Point(6, 49);
            this->label28->Name = L"label28";
            this->label28->Size = System::Drawing::Size(134, 13);
            this->label28->TabIndex = 57;
            this->label28->Text = L"Wire Break (on) Threshold:";
            // 
            // rcbCheckBox
            // 
            this->rcbCheckBox->AutoSize = true;
            this->rcbCheckBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->rcbCheckBox->Location = System::Drawing::Point(180, 230);
            this->rcbCheckBox->Name = L"rcbCheckBox";
            this->rcbCheckBox->Size = System::Drawing::Size(65, 17);
            this->rcbCheckBox->TabIndex = 56;
            this->rcbCheckBox->Text = L"Enabled";
            this->rcbCheckBox->UseVisualStyleBackColor = true;
            this->rcbCheckBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::rcbCheckBox_CheckedChanged);
            // 
            // label27
            // 
            this->label27->AutoSize = true;
            this->label27->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label27->Location = System::Drawing::Point(6, 230);
            this->label27->Name = L"label27";
            this->label27->Size = System::Drawing::Size(165, 13);
            this->label27->TabIndex = 55;
            this->label27->Text = L"Reverse Current Blocking (RCB): ";
            // 
            // label25
            // 
            this->label25->AutoSize = true;
            this->label25->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label25->Location = System::Drawing::Point(137, 158);
            this->label25->Name = L"label25";
            this->label25->Size = System::Drawing::Size(50, 13);
            this->label25->TabIndex = 51;
            this->label25->Text = L"Duration:";
            // 
            // wdTimeoutDurationBox
            // 
            this->wdTimeoutDurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wdTimeoutDurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->wdTimeoutDurationBox->FormattingEnabled = true;
            this->wdTimeoutDurationBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"400us timeout", L"400ms timeout",
                    L"800ms timeout", L"1200ms timeout"
            });
            this->wdTimeoutDurationBox->Location = System::Drawing::Point(193, 156);
            this->wdTimeoutDurationBox->Name = L"wdTimeoutDurationBox";
            this->wdTimeoutDurationBox->Size = System::Drawing::Size(253, 21);
            this->wdTimeoutDurationBox->TabIndex = 50;
            this->wdTimeoutDurationBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::wdTimeoutDurationBox_SelectedIndexChanged);
            // 
            // wdEnableBox
            // 
            this->wdEnableBox->AutoSize = true;
            this->wdEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wdEnableBox->Location = System::Drawing::Point(72, 158);
            this->wdEnableBox->Name = L"wdEnableBox";
            this->wdEnableBox->Size = System::Drawing::Size(59, 17);
            this->wdEnableBox->TabIndex = 49;
            this->wdEnableBox->Text = L"Enable";
            this->wdEnableBox->UseVisualStyleBackColor = true;
            this->wdEnableBox->CheckStateChanged += gcnew System::EventHandler(this, &ConfigurationGui::wdEnableBox_CheckStateChanged);
            // 
            // label24
            // 
            this->label24->AutoSize = true;
            this->label24->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label24->Location = System::Drawing::Point(6, 158);
            this->label24->Name = L"label24";
            this->label24->Size = System::Drawing::Size(60, 13);
            this->label24->TabIndex = 48;
            this->label24->Text = L"Watchdog:";
            // 
            // parallel34CheckBox
            // 
            this->parallel34CheckBox->AutoSize = true;
            this->parallel34CheckBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->parallel34CheckBox->Location = System::Drawing::Point(174, 133);
            this->parallel34CheckBox->Name = L"parallel34CheckBox";
            this->parallel34CheckBox->Size = System::Drawing::Size(62, 17);
            this->parallel34CheckBox->TabIndex = 47;
            this->parallel34CheckBox->Text = L"3 and 4";
            this->parallel34CheckBox->UseVisualStyleBackColor = true;
            this->parallel34CheckBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::parallel34CheckBox_CheckedChanged);
            // 
            // parallel12CheckBox
            // 
            this->parallel12CheckBox->AutoSize = true;
            this->parallel12CheckBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->parallel12CheckBox->Location = System::Drawing::Point(106, 133);
            this->parallel12CheckBox->Name = L"parallel12CheckBox";
            this->parallel12CheckBox->Size = System::Drawing::Size(62, 17);
            this->parallel12CheckBox->TabIndex = 46;
            this->parallel12CheckBox->Text = L"1 and 2";
            this->parallel12CheckBox->UseVisualStyleBackColor = true;
            this->parallel12CheckBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::parallel12CheckBox_CheckedChanged);
            // 
            // wbOffCurrrentBox
            // 
            this->wbOffCurrrentBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOffCurrrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->wbOffCurrrentBox->FormattingEnabled = true;
            this->wbOffCurrrentBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"50uA", L"100uA", L"200uA", L"500uA" });
            this->wbOffCurrrentBox->Location = System::Drawing::Point(193, 19);
            this->wbOffCurrrentBox->Name = L"wbOffCurrrentBox";
            this->wbOffCurrrentBox->Size = System::Drawing::Size(253, 21);
            this->wbOffCurrrentBox->TabIndex = 45;
            this->wbOffCurrrentBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOffCurrrentBox_SelectedIndexChanged);
            // 
            // label23
            // 
            this->label23->AutoSize = true;
            this->label23->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label23->Location = System::Drawing::Point(6, 134);
            this->label23->Name = L"label23";
            this->label23->Size = System::Drawing::Size(94, 13);
            this->label23->TabIndex = 44;
            this->label23->Text = L"Parallel Channels: ";
            // 
            // label22
            // 
            this->label22->AutoSize = true;
            this->label22->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label22->Location = System::Drawing::Point(6, 21);
            this->label22->Name = L"label22";
            this->label22->Size = System::Drawing::Size(159, 13);
            this->label22->TabIndex = 43;
            this->label22->Text = L"Wire Break (off) Pull-up Current: ";
            // 
            // groupBox5
            // 
            this->groupBox5->Controls->Add(this->uvloMaskBox);
            this->groupBox5->Controls->Add(this->wbOnMaskBox);
            this->groupBox5->Controls->Add(this->wbOffMaskBox);
            this->groupBox5->Controls->Add(this->vsShortMaskBox);
            this->groupBox5->Controls->Add(this->rcbMaskBox);
            this->groupBox5->Controls->Add(this->ilimMaskBox);
            this->groupBox5->Controls->Add(this->wdErrorMaskBox);
            this->groupBox5->Controls->Add(this->spiMaskBox);
            this->groupBox5->Controls->Add(this->label34);
            this->groupBox5->Controls->Add(this->shtVsCh1);
            this->groupBox5->Controls->Add(this->shtVsCh2);
            this->groupBox5->Controls->Add(this->label33);
            this->groupBox5->Controls->Add(this->shtVsCh3);
            this->groupBox5->Controls->Add(this->shtVsCh4);
            this->groupBox5->Controls->Add(this->wbOffCh1);
            this->groupBox5->Controls->Add(this->wbOffCh2);
            this->groupBox5->Controls->Add(this->label32);
            this->groupBox5->Controls->Add(this->wbOffCh3);
            this->groupBox5->Controls->Add(this->wbOffCh4);
            this->groupBox5->Controls->Add(this->wbOnCh1);
            this->groupBox5->Controls->Add(this->wbOnCh2);
            this->groupBox5->Controls->Add(this->label31);
            this->groupBox5->Controls->Add(this->wbOnCh3);
            this->groupBox5->Controls->Add(this->wbOnCh4);
            this->groupBox5->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->groupBox5->Location = System::Drawing::Point(6, 232);
            this->groupBox5->Name = L"groupBox5";
            this->groupBox5->Size = System::Drawing::Size(338, 260);
            this->groupBox5->TabIndex = 1;
            this->groupBox5->TabStop = false;
            this->groupBox5->Text = L"Fault/Diagnostics";
            // 
            // uvloMaskBox
            // 
            this->uvloMaskBox->AutoSize = true;
            this->uvloMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->uvloMaskBox->Location = System::Drawing::Point(106, 161);
            this->uvloMaskBox->Name = L"uvloMaskBox";
            this->uvloMaskBox->Size = System::Drawing::Size(94, 17);
            this->uvloMaskBox->TabIndex = 87;
            this->uvloMaskBox->Text = L"Under Voltage";
            this->uvloMaskBox->UseVisualStyleBackColor = true;
            this->uvloMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::uvloMaskBox_CheckedChanged);
            // 
            // wbOnMaskBox
            // 
            this->wbOnMaskBox->AutoSize = true;
            this->wbOnMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOnMaskBox->Location = System::Drawing::Point(5, 161);
            this->wbOnMaskBox->Name = L"wbOnMaskBox";
            this->wbOnMaskBox->Size = System::Drawing::Size(96, 17);
            this->wbOnMaskBox->TabIndex = 86;
            this->wbOnMaskBox->Text = L"Wire Break On";
            this->wbOnMaskBox->UseVisualStyleBackColor = true;
            this->wbOnMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOnMaskBox_CheckedChanged);
            // 
            // wbOffMaskBox
            // 
            this->wbOffMaskBox->AutoSize = true;
            this->wbOffMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOffMaskBox->Location = System::Drawing::Point(194, 138);
            this->wbOffMaskBox->Name = L"wbOffMaskBox";
            this->wbOffMaskBox->Size = System::Drawing::Size(96, 17);
            this->wbOffMaskBox->TabIndex = 85;
            this->wbOffMaskBox->Text = L"Wire Break Off";
            this->wbOffMaskBox->UseVisualStyleBackColor = true;
            this->wbOffMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOffMaskBox_CheckedChanged);
            // 
            // vsShortMaskBox
            // 
            this->vsShortMaskBox->AutoSize = true;
            this->vsShortMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->vsShortMaskBox->Location = System::Drawing::Point(114, 138);
            this->vsShortMaskBox->Name = L"vsShortMaskBox";
            this->vsShortMaskBox->Size = System::Drawing::Size(80, 17);
            this->vsShortMaskBox->TabIndex = 84;
            this->vsShortMaskBox->Text = L"Short-to-VS";
            this->vsShortMaskBox->UseVisualStyleBackColor = true;
            this->vsShortMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::vsShortMaskBox_CheckedChanged);
            // 
            // rcbMaskBox
            // 
            this->rcbMaskBox->AutoSize = true;
            this->rcbMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->rcbMaskBox->Location = System::Drawing::Point(5, 138);
            this->rcbMaskBox->Name = L"rcbMaskBox";
            this->rcbMaskBox->Size = System::Drawing::Size(103, 17);
            this->rcbMaskBox->TabIndex = 83;
            this->rcbMaskBox->Text = L"Reverse Current";
            this->rcbMaskBox->UseVisualStyleBackColor = true;
            this->rcbMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::rcbMaskBox_CheckedChanged);
            // 
            // ilimMaskBox
            // 
            this->ilimMaskBox->AutoSize = true;
            this->ilimMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->ilimMaskBox->Location = System::Drawing::Point(186, 115);
            this->ilimMaskBox->Name = L"ilimMaskBox";
            this->ilimMaskBox->Size = System::Drawing::Size(84, 17);
            this->ilimMaskBox->TabIndex = 82;
            this->ilimMaskBox->Text = L"Current Limit";
            this->ilimMaskBox->UseVisualStyleBackColor = true;
            this->ilimMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::ilimMaskBox_CheckedChanged);
            // 
            // wdErrorMaskBox
            // 
            this->wdErrorMaskBox->AutoSize = true;
            this->wdErrorMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wdErrorMaskBox->Location = System::Drawing::Point(79, 115);
            this->wdErrorMaskBox->Name = L"wdErrorMaskBox";
            this->wdErrorMaskBox->Size = System::Drawing::Size(101, 17);
            this->wdErrorMaskBox->TabIndex = 81;
            this->wdErrorMaskBox->Text = L"Watchdog Error";
            this->wdErrorMaskBox->UseVisualStyleBackColor = true;
            this->wdErrorMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wdErrorMaskBox_CheckedChanged);
            // 
            // spiMaskBox
            // 
            this->spiMaskBox->AutoSize = true;
            this->spiMaskBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->spiMaskBox->Location = System::Drawing::Point(5, 115);
            this->spiMaskBox->Name = L"spiMaskBox";
            this->spiMaskBox->Size = System::Drawing::Size(68, 17);
            this->spiMaskBox->TabIndex = 80;
            this->spiMaskBox->Text = L"SPI Error";
            this->spiMaskBox->UseVisualStyleBackColor = true;
            this->spiMaskBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::spiMaskBox_CheckedChanged);
            // 
            // label34
            // 
            this->label34->AutoSize = true;
            this->label34->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label34->Location = System::Drawing::Point(4, 95);
            this->label34->Name = L"label34";
            this->label34->Size = System::Drawing::Size(90, 13);
            this->label34->TabIndex = 20;
            this->label34->Text = L"Fault Masking:";
            // 
            // shtVsCh1
            // 
            this->shtVsCh1->AutoSize = true;
            this->shtVsCh1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->shtVsCh1->Location = System::Drawing::Point(128, 67);
            this->shtVsCh1->Name = L"shtVsCh1";
            this->shtVsCh1->Size = System::Drawing::Size(32, 17);
            this->shtVsCh1->TabIndex = 79;
            this->shtVsCh1->Text = L"1";
            this->shtVsCh1->UseVisualStyleBackColor = true;
            this->shtVsCh1->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::shtVsCh1_CheckedChanged);
            // 
            // shtVsCh2
            // 
            this->shtVsCh2->AutoSize = true;
            this->shtVsCh2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->shtVsCh2->Location = System::Drawing::Point(166, 67);
            this->shtVsCh2->Name = L"shtVsCh2";
            this->shtVsCh2->Size = System::Drawing::Size(32, 17);
            this->shtVsCh2->TabIndex = 78;
            this->shtVsCh2->Text = L"2";
            this->shtVsCh2->UseVisualStyleBackColor = true;
            this->shtVsCh2->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::shtVsCh2_CheckedChanged);
            // 
            // label33
            // 
            this->label33->AutoSize = true;
            this->label33->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label33->Location = System::Drawing::Point(4, 68);
            this->label33->Name = L"label33";
            this->label33->Size = System::Drawing::Size(100, 13);
            this->label33->TabIndex = 75;
            this->label33->Text = L"Short-to-VS Enable:";
            // 
            // shtVsCh3
            // 
            this->shtVsCh3->AutoSize = true;
            this->shtVsCh3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->shtVsCh3->Location = System::Drawing::Point(204, 67);
            this->shtVsCh3->Name = L"shtVsCh3";
            this->shtVsCh3->Size = System::Drawing::Size(32, 17);
            this->shtVsCh3->TabIndex = 77;
            this->shtVsCh3->Text = L"3";
            this->shtVsCh3->UseVisualStyleBackColor = true;
            this->shtVsCh3->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::shtVsCh3_CheckedChanged);
            // 
            // shtVsCh4
            // 
            this->shtVsCh4->AutoSize = true;
            this->shtVsCh4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->shtVsCh4->Location = System::Drawing::Point(242, 67);
            this->shtVsCh4->Name = L"shtVsCh4";
            this->shtVsCh4->Size = System::Drawing::Size(32, 17);
            this->shtVsCh4->TabIndex = 76;
            this->shtVsCh4->Text = L"4";
            this->shtVsCh4->UseVisualStyleBackColor = true;
            this->shtVsCh4->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::shtVsCh4_CheckedChanged);
            // 
            // wbOffCh1
            // 
            this->wbOffCh1->AutoSize = true;
            this->wbOffCh1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOffCh1->Location = System::Drawing::Point(128, 44);
            this->wbOffCh1->Name = L"wbOffCh1";
            this->wbOffCh1->Size = System::Drawing::Size(32, 17);
            this->wbOffCh1->TabIndex = 74;
            this->wbOffCh1->Text = L"1";
            this->wbOffCh1->UseVisualStyleBackColor = true;
            this->wbOffCh1->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOffCh1_CheckedChanged);
            // 
            // wbOffCh2
            // 
            this->wbOffCh2->AutoSize = true;
            this->wbOffCh2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOffCh2->Location = System::Drawing::Point(166, 44);
            this->wbOffCh2->Name = L"wbOffCh2";
            this->wbOffCh2->Size = System::Drawing::Size(32, 17);
            this->wbOffCh2->TabIndex = 73;
            this->wbOffCh2->Text = L"2";
            this->wbOffCh2->UseVisualStyleBackColor = true;
            this->wbOffCh2->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOffCh2_CheckedChanged);
            // 
            // label32
            // 
            this->label32->AutoSize = true;
            this->label32->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label32->Location = System::Drawing::Point(4, 45);
            this->label32->Name = L"label32";
            this->label32->Size = System::Drawing::Size(118, 13);
            this->label32->TabIndex = 70;
            this->label32->Text = L"Wirebreak (Off) Enable:";
            // 
            // wbOffCh3
            // 
            this->wbOffCh3->AutoSize = true;
            this->wbOffCh3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOffCh3->Location = System::Drawing::Point(204, 44);
            this->wbOffCh3->Name = L"wbOffCh3";
            this->wbOffCh3->Size = System::Drawing::Size(32, 17);
            this->wbOffCh3->TabIndex = 72;
            this->wbOffCh3->Text = L"3";
            this->wbOffCh3->UseVisualStyleBackColor = true;
            this->wbOffCh3->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOffCh3_CheckedChanged);
            // 
            // wbOffCh4
            // 
            this->wbOffCh4->AutoSize = true;
            this->wbOffCh4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOffCh4->Location = System::Drawing::Point(242, 44);
            this->wbOffCh4->Name = L"wbOffCh4";
            this->wbOffCh4->Size = System::Drawing::Size(32, 17);
            this->wbOffCh4->TabIndex = 71;
            this->wbOffCh4->Text = L"4";
            this->wbOffCh4->UseVisualStyleBackColor = true;
            this->wbOffCh4->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOffCh4_CheckedChanged);
            // 
            // wbOnCh1
            // 
            this->wbOnCh1->AutoSize = true;
            this->wbOnCh1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOnCh1->Location = System::Drawing::Point(128, 21);
            this->wbOnCh1->Name = L"wbOnCh1";
            this->wbOnCh1->Size = System::Drawing::Size(32, 17);
            this->wbOnCh1->TabIndex = 69;
            this->wbOnCh1->Text = L"1";
            this->wbOnCh1->UseVisualStyleBackColor = true;
            this->wbOnCh1->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOnCh1_CheckedChanged);
            // 
            // wbOnCh2
            // 
            this->wbOnCh2->AutoSize = true;
            this->wbOnCh2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOnCh2->Location = System::Drawing::Point(166, 21);
            this->wbOnCh2->Name = L"wbOnCh2";
            this->wbOnCh2->Size = System::Drawing::Size(32, 17);
            this->wbOnCh2->TabIndex = 68;
            this->wbOnCh2->Text = L"2";
            this->wbOnCh2->UseVisualStyleBackColor = true;
            this->wbOnCh2->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOnCh2_CheckedChanged);
            // 
            // label31
            // 
            this->label31->AutoSize = true;
            this->label31->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label31->Location = System::Drawing::Point(5, 22);
            this->label31->Name = L"label31";
            this->label31->Size = System::Drawing::Size(118, 13);
            this->label31->TabIndex = 62;
            this->label31->Text = L"Wirebreak (On) Enable:";
            // 
            // wbOnCh3
            // 
            this->wbOnCh3->AutoSize = true;
            this->wbOnCh3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOnCh3->Location = System::Drawing::Point(204, 21);
            this->wbOnCh3->Name = L"wbOnCh3";
            this->wbOnCh3->Size = System::Drawing::Size(32, 17);
            this->wbOnCh3->TabIndex = 67;
            this->wbOnCh3->Text = L"3";
            this->wbOnCh3->UseVisualStyleBackColor = true;
            this->wbOnCh3->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOnCh3_CheckedChanged);
            // 
            // wbOnCh4
            // 
            this->wbOnCh4->AutoSize = true;
            this->wbOnCh4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOnCh4->Location = System::Drawing::Point(242, 21);
            this->wbOnCh4->Name = L"wbOnCh4";
            this->wbOnCh4->Size = System::Drawing::Size(32, 17);
            this->wbOnCh4->TabIndex = 66;
            this->wbOnCh4->Text = L"4";
            this->wbOnCh4->UseVisualStyleBackColor = true;
            this->wbOnCh4->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::wbOnCh4_CheckedChanged);
            // 
            // groupBox4
            // 
            this->groupBox4->Controls->Add(this->label26);
            this->groupBox4->Controls->Add(this->inrushLimitBox);
            this->groupBox4->Controls->Add(this->label21);
            this->groupBox4->Controls->Add(this->ilimBehaviorBox);
            this->groupBox4->Controls->Add(this->label20);
            this->groupBox4->Controls->Add(this->separateIlimBox);
            this->groupBox4->Controls->Add(this->chan34CurrentLimitBox);
            this->groupBox4->Controls->Add(this->chan34DurationBox);
            this->groupBox4->Controls->Add(this->label17);
            this->groupBox4->Controls->Add(this->label19);
            this->groupBox4->Controls->Add(this->label18);
            this->groupBox4->Controls->Add(this->chan12CurrentLimitBox);
            this->groupBox4->Controls->Add(this->chan12DurationBox);
            this->groupBox4->Controls->Add(this->label16);
            this->groupBox4->Controls->Add(this->label15);
            this->groupBox4->Controls->Add(this->label14);
            this->groupBox4->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->groupBox4->Location = System::Drawing::Point(6, 6);
            this->groupBox4->Name = L"groupBox4";
            this->groupBox4->Size = System::Drawing::Size(338, 220);
            this->groupBox4->TabIndex = 0;
            this->groupBox4->TabStop = false;
            this->groupBox4->Text = L"Current Limit";
            // 
            // label26
            // 
            this->label26->AutoSize = true;
            this->label26->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label26->Location = System::Drawing::Point(7, 139);
            this->label26->Name = L"label26";
            this->label26->Size = System::Drawing::Size(57, 13);
            this->label26->TabIndex = 20;
            this->label26->Text = L"Settings:";
            // 
            // inrushLimitBox
            // 
            this->inrushLimitBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->inrushLimitBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->inrushLimitBox->FormattingEnabled = true;
            this->inrushLimitBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"Current limit 1x level during \"duration\"",
                    L"Current limit 2x level during \"duration\"", L"Current limit 0.5x level during \"duration\"", L"Current limit fixed 2.6A during \"duration\""
            });
            this->inrushLimitBox->Location = System::Drawing::Point(87, 185);
            this->inrushLimitBox->Name = L"inrushLimitBox";
            this->inrushLimitBox->Size = System::Drawing::Size(243, 21);
            this->inrushLimitBox->TabIndex = 19;
            this->inrushLimitBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::inrushLimitBox_SelectedIndexChanged);
            // 
            // label21
            // 
            this->label21->AutoSize = true;
            this->label21->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label21->Location = System::Drawing::Point(7, 187);
            this->label21->Name = L"label21";
            this->label21->Size = System::Drawing::Size(63, 13);
            this->label21->TabIndex = 18;
            this->label21->Text = L"Inrush Limit:";
            // 
            // ilimBehaviorBox
            // 
            this->ilimBehaviorBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->ilimBehaviorBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->ilimBehaviorBox->FormattingEnabled = true;
            this->ilimBehaviorBox->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"Inrush current clamping", L"Inrush before FET shutoff" });
            this->ilimBehaviorBox->Location = System::Drawing::Point(87, 156);
            this->ilimBehaviorBox->Name = L"ilimBehaviorBox";
            this->ilimBehaviorBox->Size = System::Drawing::Size(243, 21);
            this->ilimBehaviorBox->TabIndex = 17;
            this->ilimBehaviorBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::ilimBehaviorBox_SelectedIndexChanged);
            // 
            // label20
            // 
            this->label20->AutoSize = true;
            this->label20->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label20->Location = System::Drawing::Point(7, 158);
            this->label20->Name = L"label20";
            this->label20->Size = System::Drawing::Size(52, 13);
            this->label20->TabIndex = 16;
            this->label20->Text = L"Behavior:";
            // 
            // separateIlimBox
            // 
            this->separateIlimBox->AutoSize = true;
            this->separateIlimBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->separateIlimBox->Location = System::Drawing::Point(119, 81);
            this->separateIlimBox->Name = L"separateIlimBox";
            this->separateIlimBox->Size = System::Drawing::Size(155, 17);
            this->separateIlimBox->TabIndex = 15;
            this->separateIlimBox->Text = L"Use Separate Currrent Limit";
            this->separateIlimBox->UseVisualStyleBackColor = true;
            this->separateIlimBox->CheckedChanged += gcnew System::EventHandler(this, &ConfigurationGui::separateIlimBox_CheckedChanged);
            // 
            // chan34CurrentLimitBox
            // 
            this->chan34CurrentLimitBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chan34CurrentLimitBox->FormattingEnabled = true;
            this->chan34CurrentLimitBox->Items->AddRange(gcnew cli::array< System::Object^  >(16) {
                L"0.3A", L"0.4A", L"0.5A", L"0.6A",
                    L"0.7A", L"0.8A", L"0.9A", L"1.0A", L"1.2A", L"1.4A", L"1.6A", L"1.8A", L"2.0A", L"2.2A", L"2.4A", L"2.6A"
            });
            this->chan34CurrentLimitBox->Location = System::Drawing::Point(42, 105);
            this->chan34CurrentLimitBox->Name = L"chan34CurrentLimitBox";
            this->chan34CurrentLimitBox->Size = System::Drawing::Size(119, 21);
            this->chan34CurrentLimitBox->TabIndex = 14;
            this->chan34CurrentLimitBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::chan34CurrentLimitBox_SelectedIndexChanged);
            // 
            // chan34DurationBox
            // 
            this->chan34DurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chan34DurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chan34DurationBox->FormattingEnabled = true;
            this->chan34DurationBox->Items->AddRange(gcnew cli::array< System::Object^  >(16) {
                L"0ms", L"2ms", L"4ms", L"6ms", L"8ms",
                    L"10ms", L"12ms", L"16ms", L"20ms", L"24ms", L"28ms", L"32ms", L"40ms", L"48ms", L"56ms", L"65ms"
            });
            this->chan34DurationBox->Location = System::Drawing::Point(224, 105);
            this->chan34DurationBox->Name = L"chan34DurationBox";
            this->chan34DurationBox->Size = System::Drawing::Size(106, 21);
            this->chan34DurationBox->TabIndex = 13;
            this->chan34DurationBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::chan34DurationBox_SelectedIndexChanged);
            // 
            // label17
            // 
            this->label17->AutoSize = true;
            this->label17->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label17->Location = System::Drawing::Point(168, 107);
            this->label17->Name = L"label17";
            this->label17->Size = System::Drawing::Size(50, 13);
            this->label17->TabIndex = 12;
            this->label17->Text = L"Duration:";
            // 
            // label19
            // 
            this->label19->AutoSize = true;
            this->label19->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label19->Location = System::Drawing::Point(5, 107);
            this->label19->Name = L"label19";
            this->label19->Size = System::Drawing::Size(31, 13);
            this->label19->TabIndex = 11;
            this->label19->Text = L"Limit:";
            // 
            // label18
            // 
            this->label18->AutoSize = true;
            this->label18->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label18->Location = System::Drawing::Point(7, 82);
            this->label18->Name = L"label18";
            this->label18->Size = System::Drawing::Size(110, 13);
            this->label18->TabIndex = 10;
            this->label18->Text = L"Channels 3 and 4:";
            // 
            // chan12CurrentLimitBox
            // 
            this->chan12CurrentLimitBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chan12CurrentLimitBox->FormattingEnabled = true;
            this->chan12CurrentLimitBox->Items->AddRange(gcnew cli::array< System::Object^  >(16) {
                L"0.3A", L"0.4A", L"0.5A", L"0.6A",
                    L"0.7A", L"0.8A", L"0.9A", L"1.0A", L"1.2A", L"1.4A", L"1.6A", L"1.8A", L"2.0A", L"2.2A", L"2.4A", L"2.6A"
            });
            this->chan12CurrentLimitBox->Location = System::Drawing::Point(42, 47);
            this->chan12CurrentLimitBox->Name = L"chan12CurrentLimitBox";
            this->chan12CurrentLimitBox->Size = System::Drawing::Size(119, 21);
            this->chan12CurrentLimitBox->TabIndex = 9;
            this->chan12CurrentLimitBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::chan12CurrentLimitBox_SelectedIndexChanged);
            // 
            // chan12DurationBox
            // 
            this->chan12DurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chan12DurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chan12DurationBox->FormattingEnabled = true;
            this->chan12DurationBox->Items->AddRange(gcnew cli::array< System::Object^  >(16) {
                L"0ms", L"2ms", L"4ms", L"6ms", L"8ms",
                    L"10ms", L"12ms", L"16ms", L"20ms", L"24ms", L"28ms", L"32ms", L"40ms", L"48ms", L"56ms", L"65ms"
            });
            this->chan12DurationBox->Location = System::Drawing::Point(226, 47);
            this->chan12DurationBox->Name = L"chan12DurationBox";
            this->chan12DurationBox->Size = System::Drawing::Size(106, 21);
            this->chan12DurationBox->TabIndex = 8;
            this->chan12DurationBox->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::chan12DurationBox_SelectedIndexChanged);
            // 
            // label16
            // 
            this->label16->AutoSize = true;
            this->label16->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label16->Location = System::Drawing::Point(170, 49);
            this->label16->Name = L"label16";
            this->label16->Size = System::Drawing::Size(50, 13);
            this->label16->TabIndex = 4;
            this->label16->Text = L"Duration:";
            // 
            // label15
            // 
            this->label15->AutoSize = true;
            this->label15->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label15->Location = System::Drawing::Point(7, 49);
            this->label15->Name = L"label15";
            this->label15->Size = System::Drawing::Size(31, 13);
            this->label15->TabIndex = 2;
            this->label15->Text = L"Limit:";
            // 
            // label14
            // 
            this->label14->AutoSize = true;
            this->label14->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label14->Location = System::Drawing::Point(7, 24);
            this->label14->Name = L"label14";
            this->label14->Size = System::Drawing::Size(110, 13);
            this->label14->TabIndex = 0;
            this->label14->Text = L"Channels 1 and 2:";
            // 
            // tabPage3
            // 
            this->tabPage3->Controls->Add(this->label12);
            this->tabPage3->Controls->Add(this->label10);
            this->tabPage3->Controls->Add(this->commandBox);
            this->tabPage3->Controls->Add(this->sendCommandButton);
            this->tabPage3->Controls->Add(this->label8);
            this->tabPage3->Controls->Add(this->commandLogBox);
            this->tabPage3->Location = System::Drawing::Point(4, 22);
            this->tabPage3->Margin = System::Windows::Forms::Padding(2);
            this->tabPage3->Name = L"tabPage3";
            this->tabPage3->Size = System::Drawing::Size(807, 497);
            this->tabPage3->TabIndex = 2;
            this->tabPage3->Text = L"Console Writer";
            this->tabPage3->UseVisualStyleBackColor = true;
            // 
            // label12
            // 
            this->label12->AutoSize = true;
            this->label12->Location = System::Drawing::Point(20, 48);
            this->label12->Name = L"label12";
            this->label12->Size = System::Drawing::Size(146, 13);
            this->label12->TabIndex = 7;
            this->label12->Text = L"2) READ <REG_NUM_HEX>";
            // 
            // label10
            // 
            this->label10->AutoSize = true;
            this->label10->Location = System::Drawing::Point(20, 31);
            this->label10->Name = L"label10";
            this->label10->Size = System::Drawing::Size(227, 13);
            this->label10->TabIndex = 6;
            this->label10->Text = L"1) WRITE <REG_NUM_HEX> <VALUE HEX>";
            // 
            // commandBox
            // 
            this->commandBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->commandBox->Location = System::Drawing::Point(4, 470);
            this->commandBox->Name = L"commandBox";
            this->commandBox->Size = System::Drawing::Size(719, 20);
            this->commandBox->TabIndex = 5;
            this->commandBox->KeyDown += gcnew System::Windows::Forms::KeyEventHandler(this, &ConfigurationGui::commandBox_KeyDown);
            // 
            // sendCommandButton
            // 
            this->sendCommandButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->sendCommandButton->Location = System::Drawing::Point(729, 470);
            this->sendCommandButton->Name = L"sendCommandButton";
            this->sendCommandButton->Size = System::Drawing::Size(75, 23);
            this->sendCommandButton->TabIndex = 4;
            this->sendCommandButton->Text = L"Send";
            this->sendCommandButton->UseVisualStyleBackColor = true;
            this->sendCommandButton->Click += gcnew System::EventHandler(this, &ConfigurationGui::sendCommandButton_Click);
            // 
            // label8
            // 
            this->label8->AutoSize = true;
            this->label8->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->label8->Location = System::Drawing::Point(6, 10);
            this->label8->Name = L"label8";
            this->label8->Size = System::Drawing::Size(83, 15);
            this->label8->TabIndex = 3;
            this->label8->Text = L"Commands:";
            // 
            // commandLogBox
            // 
            this->commandLogBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->commandLogBox->Location = System::Drawing::Point(3, 71);
            this->commandLogBox->Multiline = true;
            this->commandLogBox->Name = L"commandLogBox";
            this->commandLogBox->ReadOnly = true;
            this->commandLogBox->ScrollBars = System::Windows::Forms::ScrollBars::Vertical;
            this->commandLogBox->Size = System::Drawing::Size(801, 392);
            this->commandLogBox->TabIndex = 2;
            // 
            // tabPage4
            // 
            this->tabPage4->Controls->Add(this->logTextBox);
            this->tabPage4->Location = System::Drawing::Point(4, 22);
            this->tabPage4->Margin = System::Windows::Forms::Padding(2);
            this->tabPage4->Name = L"tabPage4";
            this->tabPage4->Size = System::Drawing::Size(807, 497);
            this->tabPage4->TabIndex = 3;
            this->tabPage4->Text = L"Log";
            this->tabPage4->UseVisualStyleBackColor = true;
            // 
            // logTextBox
            // 
            this->logTextBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->logTextBox->Location = System::Drawing::Point(4, 4);
            this->logTextBox->Multiline = true;
            this->logTextBox->Name = L"logTextBox";
            this->logTextBox->ReadOnly = true;
            this->logTextBox->ScrollBars = System::Windows::Forms::ScrollBars::Vertical;
            this->logTextBox->Size = System::Drawing::Size(800, 490);
            this->logTextBox->TabIndex = 0;
            // 
            // deviceSelectorCombo
            // 
            this->deviceSelectorCombo->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->deviceSelectorCombo->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->deviceSelectorCombo->FormattingEnabled = true;
            this->deviceSelectorCombo->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"Device #1 (Addr: 0x02)", L"Device #2 (Addr: 0x05)" });
            this->deviceSelectorCombo->Location = System::Drawing::Point(67, 26);
            this->deviceSelectorCombo->Margin = System::Windows::Forms::Padding(2);
            this->deviceSelectorCombo->Name = L"deviceSelectorCombo";
            this->deviceSelectorCombo->Size = System::Drawing::Size(756, 21);
            this->deviceSelectorCombo->TabIndex = 2;
            this->deviceSelectorCombo->SelectedIndexChanged += gcnew System::EventHandler(this, &ConfigurationGui::deviceSelectorCombo_SelectedIndexChanged);
            // 
            // label1
            // 
            this->label1->AutoSize = true;
            this->label1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->label1->Location = System::Drawing::Point(9, 29);
            this->label1->Margin = System::Windows::Forms::Padding(2, 0, 2, 0);
            this->label1->Name = L"label1";
            this->label1->Size = System::Drawing::Size(54, 15);
            this->label1->TabIndex = 1;
            this->label1->Text = L"Device:";
            // 
            // ConfigurationGui
            // 
            this->AutoScaleDimensions = System::Drawing::SizeF(6, 13);
            this->AutoScaleMode = System::Windows::Forms::AutoScaleMode::Font;
            this->ClientSize = System::Drawing::Size(834, 598);
            this->Controls->Add(this->mainTabControl);
            this->Controls->Add(this->statusStrip1);
            this->Controls->Add(this->menuStrip1);
            this->Controls->Add(this->label1);
            this->Controls->Add(this->deviceSelectorCombo);
            this->Icon = (cli::safe_cast<System::Drawing::Icon^>(resources->GetObject(L"$this.Icon")));
            this->MainMenuStrip = this->menuStrip1;
            this->Margin = System::Windows::Forms::Padding(2, 1, 2, 1);
            this->MinimumSize = System::Drawing::Size(839, 597);
            this->Name = L"ConfigurationGui";
            this->Text = L"TSP274C65 Configurator v1.0.0";
            this->FormClosing += gcnew System::Windows::Forms::FormClosingEventHandler(this, &ConfigurationGui::ConfigurationGui_FormClosing);
            this->Load += gcnew System::EventHandler(this, &ConfigurationGui::SelectElementForm_Load);
            this->statusStrip1->ResumeLayout(false);
            this->statusStrip1->PerformLayout();
            this->menuStrip1->ResumeLayout(false);
            this->menuStrip1->PerformLayout();
            this->mainTabControl->ResumeLayout(false);
            this->tabPage1->ResumeLayout(false);
            this->groupBox3->ResumeLayout(false);
            this->tableLayoutPanel4->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox4))->EndInit();
            this->tableLayoutPanel3->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox3))->EndInit();
            this->tableLayoutPanel2->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox2))->EndInit();
            this->tableLayoutPanel1->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox1))->EndInit();
            this->groupBox2->ResumeLayout(false);
            this->groupBox2->PerformLayout();
            this->groupBox1->ResumeLayout(false);
            this->groupBox1->PerformLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->senseChart))->EndInit();
            this->tabPage5->ResumeLayout(false);
            this->tabPage5->PerformLayout();
            this->groupBox10->ResumeLayout(false);
            this->groupBox10->PerformLayout();
            this->tableLayoutPanel5->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh3))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtsFaultBoxCh4))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh3))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOffFaultCh4))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh3))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wbOnFaultCh4))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh3))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimFaultBoxCh4))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh3))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdFaultBoxCh4))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh3))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tWarnBoxCh4))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh3))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->rvsrBoxCh4))->EndInit();
            this->groupBox9->ResumeLayout(false);
            this->groupBox8->ResumeLayout(false);
            this->tableLayoutPanel6->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->porFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->thermalFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->spiFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wdtFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->vddUVFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvWarnBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvFaultBox))->EndInit();
            this->tabPage2->ResumeLayout(false);
            this->groupBox7->ResumeLayout(false);
            this->groupBox7->PerformLayout();
            this->groupBox6->ResumeLayout(false);
            this->groupBox6->PerformLayout();
            this->groupBox5->ResumeLayout(false);
            this->groupBox5->PerformLayout();
            this->groupBox4->ResumeLayout(false);
            this->groupBox4->PerformLayout();
            this->tabPage3->ResumeLayout(false);
            this->tabPage3->PerformLayout();
            this->tabPage4->ResumeLayout(false);
            this->tabPage4->PerformLayout();
            this->ResumeLayout(false);
            this->PerformLayout();

        }
#pragma endregion

    /* Variables */
    private:
    ParameterizedThreadStart^ connThreadStart;
    ParameterizedThreadStart^ senseThreadStart;
    ParameterizedThreadStart^ faultThreadStart;
    Thread^ connThread;
    Thread^ senseThread;
    Thread^ faultThread;
    HSSCommunicationManager^ commManager;
    uint8_t curDataFormat = TPS274C65_CURRENT_OFFSET;
    Image^ redButton;
    Image^ greenButton;
    private: CondorConfiguration^ condorConfig1;
    private: CondorConfiguration^ condorConfig2;
    private: static const UINT8 UNIT_1_ADDR = 0x02;
    private: static const UINT8 UNIT_2_ADDR = 0x05;
    private: static bool dontRunEvents = false;
    public: static System::Collections::Generic::Queue<uint8_t> connQueue;
    public: static bool isShuttingDown = false;
    private: HWND messageWindow;
    private: String^ curSenseUnit  = "A";
    private: String^ magicFileWord = "TPS274C65CONFIGURATOR";
    public: bool isCurrentSenseEnabled = false;
    private: static bool manualUpdateEnabled = false;

    /* Functions */
    public: void updateConnectionStatus();
    private: System::Void SelectElementForm_Load(System::Object^ sender, System::EventArgs^ e);
    private: static void connectionThreadFunction(Object^ obj);
    private: delegate void UpdateConfigCallback(bool updateDevice);
    private: delegate void UpdateConnnectionCallback();
    private: delegate void UpdateFaultCallback(CondorConfiguration^ curConfig);
    private: delegate void UpdateSenseCallback(tHSSReceiveTransaction^ cmd);
    private: HSSDeviceReceiveFinished^ recHandler;
    private: static uint8_t curSelectedDevice = 0;
    private: static void faultReadFunctionThread(Object^ obj);
    void tps274c65configurator::ConfigurationGui::logMessageToWindow(String^ str, ... array<Object^>^ args);
    void handleRawReadResponse(sHSSReceiveTransaction^ trans);
    private: static void senseReadFunctionThread(Object^ obj);
    private: CondorConfiguration^ getCurrentCondorConfig();

    private: System::Void ConfigurationGui_FormClosing(System::Object^ sender, System::Windows::Forms::FormClosingEventArgs^ e)
    {
        isShuttingDown = true;

        /* Waiting for the threads to end */
        while (connThread->IsAlive || senseThread->IsAlive);

        /* Removing the receive handler delegate */
        commManager->hssReceiveBufferDelegate -= recHandler;
    }

    private: System::Void checkedListBox1_ItemCheck(System::Object^ sender, System::Windows::Forms::ItemCheckEventArgs^ e);
    private: void updateEnable(uint8_t addr, System::Windows::Forms::ItemCheckEventArgs^ e);
    private: System::Void toggleAllChannelsBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: void updateFaultGuiFromConfig(CondorConfiguration^ curConfig);
    private: System::Void ledToggleBoxGroup_ItemCheck(System::Object^ sender, System::Windows::Forms::ItemCheckEventArgs^ e);
    private: System::Void toggleAllLEDChannelsBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: void updateMainGUIFromSelection(void);
    private: System::Void deviceSelectorCombo_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: void bufferReceiveEventHandler(tHSSReceiveTransaction^ cmd);
    private: System::Void updateGuiFromConfig(bool updateDevice);
    private: System::Void senseChannelBox_ItemCheck(System::Object^ sender, System::Windows::Forms::ItemCheckEventArgs^ e);
    private: float convertRawADCValue(uint8_t rawValue, uint8_t format);
    private: void updateCurrentSenseGUI(tHSSReceiveTransaction^ cmd);
    private: System::Void senseChannelAll_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void senseSourceSelBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void mainTabControl_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chan12CurrentLimitBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chan12DurationBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chan34CurrentLimitBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chan34DurationBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void separateIlimBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void ilimBehaviorBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void inrushLimitBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOnCh1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOnCh2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOnCh3_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOnCh4_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOffCh1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOffCh2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOffCh3_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOffCh4_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shtVsCh1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shtVsCh2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shtVsCh3_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shtVsCh4_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void spiMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wdErrorMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void ilimMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void rcbMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void vsShortMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOffMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOnMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void uvloMaskBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOffCurrrentBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOnThreshBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbBlankBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void latchRadioButton_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void parallel12CheckBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void parallel34CheckBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wdEnableBox_CheckStateChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wdTimeoutDurationBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void fsKeepBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void rcbCheckBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void rc1Box_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void rc2Box_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void rc3Box_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void rc4Box_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void latchDisableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcCurEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcInVoltageEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcOutVoltageEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcTempEanableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void less800mABox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void tsnsDisBox1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void tsnsDisBox2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void tsnsDisBox3_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void tsnsDisBox4_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void voutDisBox1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void voutDisBox2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void voutDisBox3_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void voutDisBox4_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void curDisBox1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void curDisBox2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void curDisBox3_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void curDisBox4_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void keepStateBox1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void keepStateBox2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void keepStateBox3_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void keepStateBox4_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: int char2int(char input);
    private: void hex2bin(const char* src, uint8_t* target);
    private: System::Void sendCommandButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void commandBox_KeyDown(System::Object^ sender, System::Windows::Forms::KeyEventArgs^ e);


    /* All of the faults of the system */
    HSSFault^ porFault = gcnew HSSFault("Power on Reset (POR)", "Indicative of whether a power on reset has occurred.");
    HSSFault^ uvFault = gcnew HSSFault("Supply Undervoltage Fault", "Set if the device has seen an undervoltage supply fault.");
    HSSFault^ uvWarnFault = gcnew HSSFault("Supply Undervoltage Warning", "Set if the supply voltage is under the undervoltage warning.");
    HSSFault^ tsdFault = gcnew HSSFault("Chip Thermal Shutdown Fault", "Set if the chip thermal warning is triggered at any time.");
    HSSFault^ spiFault = gcnew HSSFault("SPI Communication Error", "Set by SPI communication error either from format, clock, or CRC errors.");
    HSSFault^ wdFault = gcnew HSSFault("SPI Watchdog Fault", "Set when watchdog timeout on SPI read or write occurs.");
    HSSFault^ vdduvloFault = gcnew HSSFault("VDD Undervoltage Lockout (UVLO)", "Set if the VDD supply is below the UVLO threshold at any time.");
    HSSFault^ sht1Fault = gcnew HSSFault("Short-to-Supply Fault (CH1)", "Supply (VS) has been detected to be shorted on output of channel 1.");
    HSSFault^ sht2Fault = gcnew HSSFault("Short-to-Supply Fault (CH2)", "Supply (VS) has been detected to be shorted on output of channel 2.");
    HSSFault^ sht3Fault = gcnew HSSFault("Short-to-Supply Fault (CH3)", "Supply (VS) has been detected to be shorted on output of channel 3.");
    HSSFault^ sht4Fault = gcnew HSSFault("Short-to-Supply Fault (CH4)", "Supply (VS) has been detected to be shorted on output of channel 4.");
    HSSFault^ wbOff1Fault = gcnew HSSFault("Wirebreak Off Fault (CH1)", "No load is detected on channel 1 (off-state)");
    HSSFault^ wbOff2Fault = gcnew HSSFault("Wirebreak Off Fault (CH2)", "No load is detected on channel 2 (off-state)");
    HSSFault^ wbOff3Fault = gcnew HSSFault("Wirebreak Off Fault (CH3)", "No load is detected on channel 3 (off-state)");
    HSSFault^ wbOff4Fault = gcnew HSSFault("Wirebreak Off Fault (CH4)", "No load is detected on channel 4 (off-state)");
    HSSFault^ wbOn1Fault = gcnew HSSFault("Wirebreak On Fault (CH1)", "No load is detected on channel 1 (on-state)");
    HSSFault^ wbOn2Fault = gcnew HSSFault("Wirebreak On Fault (CH2)", "No load is detected on channel 2 (on-state)");
    HSSFault^ wbOn3Fault = gcnew HSSFault("Wirebreak On Fault (CH3)", "No load is detected on channel 3 (on-state)");
    HSSFault^ wbOn4Fault = gcnew HSSFault("Wirebreak On Fault (CH4)", "No load is detected on channel 4 (on-state)");
    HSSFault^ ilim1Fault = gcnew HSSFault("Current Limit Fault (CH1)", "Set if a current limit has been hit on channel 1.");
    HSSFault^ ilim2Fault = gcnew HSSFault("Current Limit Fault (CH2)", "Set if a current limit has been hit on channel 2.");
    HSSFault^ ilim3Fault = gcnew HSSFault("Current Limit Fault (CH3)", "Set if a current limit has been hit on channel 3.");
    HSSFault^ ilim4Fault = gcnew HSSFault("Current Limit Fault (CH4)", "Set if a current limit has been hit on channel 4.");
    HSSFault^ tsd1Fault = gcnew HSSFault("Thermal Shutdown (CH1)", "The junction temperature of channel 1 has been exceeded and the channels has been shut off.");
    HSSFault^ tsd2Fault = gcnew HSSFault("Thermal Shutdown (CH2)", "The junction temperature of channel 2 has been exceeded and the channels has been shut off.");
    HSSFault^ tsd3Fault = gcnew HSSFault("Thermal Shutdown (CH3)", "The junction temperature of channel 3 has been exceeded and the channels has been shut off.");
    HSSFault^ tsd4Fault = gcnew HSSFault("Thermal Shutdown (CH4)", "The junction temperature of channel 4 has been exceeded and the channels has been shut off.");
    HSSFault^ tw1Fault = gcnew HSSFault("Thermal Warning (CH1)", "The junction temperature of channel 1 has triggered a thermal warning.");
    HSSFault^ tw2Fault = gcnew HSSFault("Thermal Warning (CH2)", "The junction temperature of channel 2 has triggered a thermal warning.");
    HSSFault^ tw3Fault = gcnew HSSFault("Thermal Warning (CH3)", "The junction temperature of channel 3 has triggered a thermal warning.");
    HSSFault^ tw4Fault = gcnew HSSFault("Thermal Warning (CH4)", "The junction temperature of channel 4 has triggered a thermal warning.");
    HSSFault^ rvsr1Fault = gcnew HSSFault("Reverse Current Fault (CH1)", "Triggers if reverse current has been detected and blocked on channel 1.");
    HSSFault^ rvsr2Fault = gcnew HSSFault("Reverse Current Fault (CH2)", "Triggers if reverse current has been detected and blocked on channel 2.");
    HSSFault^ rvsr3Fault = gcnew HSSFault("Reverse Current Fault (CH3)", "Triggers if reverse current has been detected and blocked on channel 3.");
    HSSFault^ rvsr4Fault = gcnew HSSFault("Reverse Current Fault (CH4)", "Triggers if reverse current has been detected and blocked on channel 4.");

    HSSFault^ curFault = porFault;

private: System::Void porFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void uvFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void uvWarnBox_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void handleFaultClick(HSSFault^ fault);
private: System::Void resetStatButton_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void thermalFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void spiFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wdtFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void vddUVFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void shtsFaultBoxCh1_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void shtsFaultBoxCh2_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void shtsFaultBoxCh3_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void shtsFaultBoxCh4_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOffFaultCh1_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOffFaultCh2_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOffFaultCh3_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOffFaultCh4_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOnFaultCh1_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOnFaultCh2_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOnFaultCh3_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void wbOnFaultCh4_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void ilimFaultBoxCh1_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void ilimFaultBoxCh2_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void ilimFaultBoxCh3_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void ilimFaultBoxCh4_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tsdFaultBoxCh1_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tsdFaultBoxCh2_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tsdFaultBoxCh3_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tsdFaultBoxCh4_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tWarnBoxCh1_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tWarnBoxCh2_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tWarnBoxCh3_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void tWarnBoxCh4_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void rvsrBoxCh1_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void rvsrBoxCh2_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void rvsrBoxCh3_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void rvsrBoxCh4_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void clearAllStatsButton_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void faultUpdateStatus_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
private: System::Void manualUpdateButton_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void saveMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void loadConfigMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
       System::Void rawWriteFromConfig(CondorConfiguration^ conf);
private: System::Void toolStripStatusLabel3_Click(System::Object^ sender, System::EventArgs^ e) {
}
private: System::Void aboutSoftwareToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
private: System::Void faultBox1_Click_1(System::Object^ sender, System::EventArgs^ e);
private: System::Void exitToolStripMenuItem1_Click(System::Object^ sender, System::EventArgs^ e) 
{
    Application::Exit();
}
private: System::Void enterDFUModeToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
};
}
